# Detect the distribution in use
%global __despace head -n 1 | tr -d '[:space:]' | sed -e 's/[(].*[)]//g'
%global __lower4 cut -c 1-4 | tr '[:upper:]' '[:lower:]'
%global __distfile %([ -f /etc/SuSE-release ] && echo /etc/SuSE-release || echo /etc/redhat-release)
%global __distinit %(sed -e 's/ release .*//' -e 's/\\([A-Za-z]\\)[^ ]*/\\1/g' %{__distfile} | %{__despace} | %{__lower4})
%global __distvers %(sed -e 's/.* release \\([^. ]*\\).*/\\1/' %{__distfile} | %{__despace})
# Identify Alma, CentOS, CentOS Stream and Rocky Linux as rhel
%if "%{__distinit}" == "a" || "%{__distinit}" == "c" || "%{__distinit}" == "cl" || "%{__distinit}" == "cs" || "%{__distinit}" == "rl"
%global __distinit rhel
%endif
# Dist tag for Fedora is still "fc"
%if "%{__distinit}" == "f"
%global __distinit fc
%endif

# Define prerel for betas, release candidates etc.
#global prerel	rc7

# Remember to bump dovecot_release and sieve_release with every release
%global dovecot_epoch 1
%global dovecot_version 2.3.21
%global dovecot_release %{?prerel:0.}3.0%{?prerel:.%{prerel}}.cf.%{__distinit}%{__distvers}
%global sieve_epoch 3
%global sieve_version 0.5.21
%global sieve_release 3.0.cf.%{__distinit}%{__distvers}
%global manage_sieve_epoch %{sieve_epoch}
%global manage_sieve_version %{sieve_version}
%global manage_sieve_release %{sieve_release}

# %%make_build only defined from EL-7, F-21 onwards
%{!?make_build:%global make_build make %{_smp_mflags} V=1}

# Use libsodium from Fedora 25 but not EL-9
%if "%{__distinit}" == "fc" && %{__distvers} >= 25
%global have_libsodium 1
%endif
%if "%{__distinit}" == "rhel" && %{__distvers} >= 7 && %{__distvers} < 9
%global have_libsodium 1
%endif

# Use libicu from Fedora 32
%if "%{__distinit}" == "fc" && %{__distvers} >= 32
%global have_libicu 1
%endif
%if "%{__distinit}" == "rhel" && %{__distvers} >= 8
%global have_libicu 1
%endif

# Use OpenSSL HMAC from Fedora 32
%if "%{__distinit}" == "fc" && %{__distvers} >= 32
%global downstream_hmac_patch 1
%endif
%if "%{__distinit}" == "rhel" && %{__distvers} >= 8
%global downstream_hmac_patch 1
%endif

# Use libzstd from Fedora 34
%if "%{__distinit}" == "fc" && %{__distvers} >= 34
%global have_libzstd 1
%endif
%if "%{__distinit}" == "rhel" && %{__distvers} >= 8
%global have_libzstd 1
%endif

# Use system crypto policy from Fedora 21
%if "%{__distinit}" == "fc" && %{__distvers} >= 21
%global system_crypto_policy 1
%endif
%if "%{__distinit}" == "rhel" && %{__distvers} >= 8
%global system_crypto_policy 1
%endif

# Use multilib-rpm-config from Fedora 22
%if "%{__distinit}" == "fc" && %{__distvers} >= 22
%global have_multilib_rpm_config 1
%endif
%if "%{__distinit}" == "rhel"
%global have_multilib_rpm_config 1
%endif

# Use systemd ProtectSystem=full from Fedora 22
%if "%{__distinit}" == "fc" && %{__distvers} >= 22
%global systemd_protect_system 1
%endif
%if "%{__distinit}" == "rhel" && %{__distvers} >= 8
%global systemd_protect_system 1
%endif

# mysql-devel replaced by mariadb-connector-c-devel from Fedora 28 onwards
%if ( "%{__distinit}" == "fc" && %{__distvers} < 28 ) || ( "%{__distinit}" == "rhel" && %{__distvers} < 8 )
%global mysql_devel mysql-devel
%else
%global mysql_devel mariadb-connector-c-devel
%endif

# postgresql-devel replaced by libpq-devel from Fedora 29 onwards
%if ( "%{__distinit}" == "fc" && %{__distvers} < 29 ) || ( "%{__distinit}" == "rhel" && %{__distvers} < 8 )
%global postgresql_devel postgresql-devel
%else
%global postgresql_devel libpq-devel
%endif

# Don't build with tcp_wrappers support from Fedora 28 onwards
# Also note that rpcgen was moved from glibc-common to its own package in the same timeframe
%if "%{__distinit}" == "fc" && %{__distvers} < 28
%global tcp_wrappers_support 1
%endif
%if "%{__distinit}" == "rhel" && %{__distvers} < 8
%global tcp_wrappers_support 1
%endif

# Add lz4, libexttextcat and libstemmer support from Fedora 32 onwards
# (note: libexttextcat is not included from Fedora 40, along with lucene)
%if "%{__distinit}" == "fc" && %{__distvers} >= 32
%global lz4_support 1
%global libexttextcat_support 1
%global libstemmer_support 1
%endif

# Include lua support from Fedora 38 onwards
%if "%{__distinit}" == "fc" && %{__distvers} >= 38
%global lua_support 1
%endif

# Don't build with lucene support from Fedora 40 onwards
%if "%{__distinit}" == "fc" && %{__distvers} < 40
%global lucene_support 1
%endif
%if "%{__distinit}" == "rhel" && %{__distvers} < 10
%global lucene_support 1
%endif

# Move to unversioned documentation directories from F-20
# https://fedoraproject.org/wiki/Changes/UnversionedDocdirs
%{!?_pkgdocdir:%global _pkgdocdir %{_docdir}/%{name}-%{version}}

# Flag file used during package updates
%global restart_flag /run/dovecot/dovecot-restart-after-rpm-install

# Pigeonhole tarball name / directory that it unpacks to
%global pigeonhole_dir dovecot-2.3-pigeonhole-%{sieve_version}

Summary:	Dovecot IMAP server
Name:		dovecot
Epoch:		%{dovecot_epoch}
Version:	%{dovecot_version}
Release:	%{dovecot_release}
# dovecot itself is MIT, a few sources are PD, pigeonhole is LGPLv2
License:	MIT AND LGPL-2.1-only
URL:		https://www.dovecot.org/
Source0:	https://dovecot.org/releases/2.3/dovecot-%{dovecot_version}%{?prerel:.%{prerel}}.tar.gz
Source1:	https://pigeonhole.dovecot.org/releases/2.3/%{pigeonhole_dir}.tar.gz
Source2:	dovecot.pam

# Cope with /run on tmpfs
Source10:	dovecot.tmpfilesd

# Our own
Source14:	dovecot.conf.5

# Wait for network
Patch6:		dovecot-2.3.15-waitonline.patch

# Fedora patches
Patch1:		dovecot-2.0-defaultconfig.patch
Patch2:		dovecot-1.0.beta2-mkcert-permissions.patch
Patch15:	dovecot-2.3.15-bigkey.patch
Patch16:	dovecot-2.3.18-opensslhmac.patch
Patch17:	dovecot-2.3.21-fixvalcond.patch
Patch20:	dovecot-2.3.14-opensslv3.patch
Patch21:	dovecot-2.3.19.1-7bad6a24.patch
Patch23:	dovecot-2.3.20-nolibotp.patch

# Local patches
Patch500:	dovecot-2.2.27-SSLDIR.patch
Patch501:	dovecot-2.3.2-selinux.patch
Patch505:	dovecot-ce-2.3.0-crypto-policy.patch
Patch507:	dovecot-2.3.2-systemd_wo_protectsystem.patch

# Build requirements
BuildRequires:	bzip2-devel
%if 0%{?lucene_support}
BuildRequires:	clucene-core-devel >= 2.3
%endif
BuildRequires:	coreutils
BuildRequires:	expat-devel
BuildRequires:	findutils
BuildRequires:	gcc
BuildRequires:	gcc-c++
BuildRequires:	krb5-devel >= 1.3
BuildRequires:	libcap-devel
BuildRequires:	libcurl-devel
%if 0%{?libexttextcat_support} && 0%{?lucene_support}
BuildRequires:	libexttextcat-devel
%endif
%if 0%{?have_libicu}
BuildRequires:	libicu-devel
%endif
%if 0%{?have_libsodium}
BuildRequires:	libsodium-devel >= 1.0.13
%endif
%if 0%{?libstemmer_support}
BuildRequires:	libstemmer-devel
%endif
BuildRequires:	libtirpc-devel
%if ! 0%{?tcp_wrappers_support}
BuildRequires:	libxcrypt-devel
%endif
%if 0%{?have_libzstd}
BuildRequires:	libzstd-devel
%endif
%if 0%{?lua_support}
BuildRequires:	lua-devel
%endif
%if 0%{?lz4_support}
BuildRequires:	lz4-devel
%endif
%if 0%{?have_multilib_rpm_config}
BuildRequires:	multilib-rpm-config
%endif
BuildRequires:	%{mysql_devel}
BuildRequires:	openldap-devel
BuildRequires:	openssl-devel >= 1.0.1
BuildRequires:	pam-devel
BuildRequires:	perl-interpreter
BuildRequires:	pkgconfig
BuildRequires:	%{postgresql_devel}
BuildRequires:	quota-devel
%if ! 0%{?tcp_wrappers_support}
BuildRequires:	rpcgen
%endif
BuildRequires:	sed
BuildRequires:	sqlite-devel
BuildRequires:	systemd
BuildRequires:	systemd-devel
%if 0%{?tcp_wrappers_support}
BuildRequires:	tcp_wrappers-devel
%endif
BuildRequires:	xz-devel
BuildRequires:	zlib-devel

# For autoreconf
%if 0%{?downstream_hmac_patch}
BuildRequires:	autoconf, automake, gettext-devel, libtool
%endif

# openssl needed for mkcert.sh
Requires:	openssl
# systemd needed for systemd-units, systemctl
Requires:	systemd

# Scriptlet dependencies
Requires(postun): systemd
Requires(pre):	shadow-utils
Requires(post): coreutils openssl

# Avoid doc-file dependencies and provides
%global __requires_exclude_from ^%{_docdir}
%global __provides_exclude_from ^%{_docdir}

%global docdir %{_pkgdocdir}
%global dovecot_uid 97
%global dovecot_gid 97

%description
Dovecot is an IMAP server for Linux/UNIX-like systems, written with security
primarily in mind. It also contains a small POP3 server. It supports mail
in either maildir or mbox formats.

%package devel
Summary:	Headers and configuration script needed for building plug-ins
Requires:	dovecot = %{dovecot_epoch}:%{dovecot_version}-%{dovecot_release}
# The devel package needs to require the same packages as the main package buildrequires
Requires:	bzip2-devel
%if 0%{?lucene_support}
Requires:	clucene-core-devel >= 2.3
%endif
Requires:	expat-devel
Requires:	gcc-c++
Requires:	krb5-devel >= 1.3
Requires:	libcap-devel
Requires:	libcurl-devel
%if 0%{?libexttextcat_support} && 0%{?lucene_support}
Requires:	libexttextcat-devel
%endif
%if 0%{?have_libicu}
Requires:	libicu-devel
%endif
%if 0%{?have_libsodium}
Requires:	libsodium-devel >= 1.0.13
%endif
%if 0%{?libstemmer_support}
Requires:	libstemmer-devel
%endif
Requires:	libtirpc-devel
%if ! 0%{?tcp_wrappers_support}
Requires:	libxcrypt-devel
%endif
%if 0%{?have_libzstd}
Requires:	libzstd-devel
%endif
%if 0%{?lz4_support}
Requires:	lz4-devel
%endif
Requires:	%{mysql_devel}
Requires:	openldap-devel
Requires:	openssl-devel >= 1.0.1
Requires:	pam-devel
Requires:	%{postgresql_devel}
Requires:	quota-devel
Requires:	sqlite-devel
Requires:	systemd-devel
%if 0%{?tcp_wrappers_support}
Requires:	tcp_wrappers-devel
%endif
Requires:	xz-devel
Requires:	zlib-devel

%description devel
This package provides header files and configuration scripts required for
building plug-ins for the dovecot IMAP/POP3 server.

%package pigeonhole
Summary:	Sieve and Managesieve plug-in for dovecot
URL:		http://pigeonhole.dovecot.org/
License:	MIT AND LGPL-2.1-only
Requires:	dovecot = %{dovecot_epoch}:%{dovecot_version}-%{dovecot_release}

# Old packages merged into pigeonhole
Obsoletes:	dovecot-sieve < %{sieve_epoch}:%{sieve_version}-%{sieve_release}
Obsoletes:	dovecot-managesieve < %{manage_sieve_epoch}:%{manage_sieve_version}-%{manage_sieve_release}
Provides:	dovecot-sieve = %{sieve_epoch}:%{sieve_version}-%{sieve_release}
Provides:	dovecot-managesieve = %{manage_sieve_epoch}:%{manage_sieve_version}-%{manage_sieve_release}

%description pigeonhole
This package provides the sieve and managesieve plug-ins (version %{sieve_version})
for dovecot LDA.

%package pgsql
Summary:	Postgres SQL back end for dovecot
Requires:	dovecot = %{dovecot_epoch}:%{dovecot_version}-%{dovecot_release}

%description pgsql
This package provides the Postgres SQL back end for dovecot-auth etc.

%package mysql
Summary:	MySQL back end for dovecot
Requires:	dovecot = %{dovecot_epoch}:%{dovecot_version}-%{dovecot_release}

%description mysql
This package provides the MySQL back end for dovecot-auth etc.

%prep
%setup -q -n dovecot-%{dovecot_version}%{?prerel:.%{prerel}} -a 1

%patch -P 1 -p1 -b .default-settings
%patch -P 2 -p1 -b .mkcert-permissions
%patch -P 6 -p1 -b .waitonline
%patch -P 15 -p1 -b .bigkey

# Do not use own implementation of HMAC: use OpenSSL for certification purposes
# Not sent upstream as proper fix would use dovecot's lib-dcrypt but it introduces
# hard to break circular dependency between lib and lib-dcrypt
%if 0%{?downstream_hmac_patch}
%patch -P 16 -p1 -b .opensslhmac
%endif

%patch -P 17 -p1 -b .fixvalcond
%patch -P 20 -p1 -b .opensslv3
%patch -P 21 -p1 -b .7bad6a24

# Fedora/RHEL specific, drop OTP, which uses SHA1, so we don't use SHA1 for crypto purposes
%if 0%{?fedora} > 38 || 0%{?rhel} > 8
%patch -P 23 -p1 -b .nolibotp
rm -rf src/lib-otp
%endif

# Fix lucene include path
%if 0%{?lucene_support}
sed -i '/DEFAULT_INCLUDES *=/s|$| '"$(pkg-config --cflags libclucene-core)|" src/plugins/fts-lucene/Makefile.in
%endif

# SSL certificates are in /etc/pki
%patch -P 500
sed -i -e 's#@SSLDIR@#%{_sysconfdir}/pki/dovecot#g' doc/example-config/conf.d/10-ssl.conf doc/mkcert.sh

# Some systemd options break SELinux transition from init_t to dovecot_t and must be removed
# https://lists.fedoraproject.org/archives/list/selinux@lists.fedoraproject.org/thread/MYQQAM5OBUCTQOGVRBQRVA2A2X5N2LSZ/
%patch -P 501

# Use system crypto policy from Fedora 21 onwards
%if 0%{?system_crypto_policy}
%patch -P 505 -b .crypt
%endif

# ProtectSystem=full can only be used from f22 onwards
# Introduced in systemd 214
%if ! 0%{?systemd_protect_system}
%patch -P 507 -b .systemd_wo_protectsystem
%endif

# PAM Configuration
cp -p %{SOURCE2} .

# Copy in dovecot.conf manpage
cp -p %{SOURCE14} .

# Remove spurious exec permissions from source files
find src -name '*.c' -print0 | xargs -0 chmod -c 644

%build
# Work around build failure with link-time optimization in Fedora 33
%if 0%{?fedora} == 33
%define _lto_cflags %{nil}
%endif

# Harden the build
%global _hardened_build 1
export CFLAGS="%{__global_cflags} -fno-strict-aliasing -fstack-reuse=none"
export LDFLAGS="-Wl,-z,now -Wl,-z,relro %{__global_ldflags}"
%if 0%{?downstream_hmac_patch}
mkdir -p m4
autoreconf -fiv
%endif
%configure									\
			INSTALL_DATA="install -c -p -m644"			\
			--docdir=%{docdir}/dovecot				\
			--disable-rpath						\
			--disable-static					\
			--with-docs						\
			--with-gssapi=plugin					\
%{?have_libicu:		--with-icu}						\
			--with-ldap=plugin					\
			--with-libcap						\
%{?tcp_wrappers_support:--with-libwrap}						\
%{?lua_support:		--with-lua=plugin}					\
%{?lucene_support:	--with-lucene --with-exttextcat}			\
%{!?lucene_support:	--without-lucene --without-exttextcat}			\
			--with-mysql						\
			--with-nss						\
			--with-pam						\
			--with-pgsql						\
			--with-rundir=/run/dovecot				\
			--with-shadow						\
			--with-solr						\
			--with-sqlite						\
			--with-sql=plugin					\
			--with-ssl=openssl					\
			--with-ssldir=%{_sysconfdir}/pki/dovecot		\
			--with-zlib						\
%{?have_libzstd:	--with-zstd}
%{make_build}

# Pigeonhole
cd %{pigeonhole_dir}
%configure							\
			INSTALL_DATA="install -c -p -m644"	\
			--disable-static			\
			--with-dovecot=../			\
			--without-unfinished-features
%{make_build}
cd -

%install
# Install dovecot
%{make_install}

# We'll package the dovecot documentation ourselves
mv %{buildroot}%{docdir}/dovecot $(pwd)/dovecot-docs

# Fix multilib issues where convenient
%if 0%{?have_multilib_rpm_config}
%{multilib_fix_c_header} --file %{_includedir}/dovecot/config.h
%endif

# Install Pigeonhole
cd %{pigeonhole_dir}
%{make_install}
cd -

# We'll package the pigeonhole documentation ourselves too
mv %{buildroot}%{docdir}/dovecot $(pwd)/pigeonhole-docs
cd %{pigeonhole_dir}
ln AUTHORS ChangeLog INSTALL NEWS README ../pigeonhole-docs/
cd -

# Create state directories with appropriate permissions
mkdir -p %{buildroot}/run/dovecot/empty
chmod 755 %{buildroot}/run/dovecot
chmod 755 %{buildroot}/run/dovecot/empty
mkdir -p %{buildroot}/run/dovecot/login
chmod 750 %{buildroot}/run/dovecot/login
mkdir -p %{buildroot}/run/dovecot/token-login
chmod 750 %{buildroot}/run/dovecot/token-login
mkdir -p %{buildroot}%{_localstatedir}/lib/dovecot
chmod 750 %{buildroot}%{_localstatedir}/lib/dovecot

# Make sure state directories are created at boot time for systems
# with /run on tmpfs
install -p -D -m 644 %{SOURCE10} %{buildroot}%{_tmpfilesdir}/dovecot.conf

# Install the certificate generating script in %%{_libexecdir}/dovecot
install -p -m 755 doc/mkcert.sh %{buildroot}%{_libexecdir}/dovecot/mkcert.sh

# Generate ghost .pem files
mkdir -p %{buildroot}%{_sysconfdir}/pki/dovecot/{certs,private}
: > %{buildroot}%{_sysconfdir}/pki/dovecot/certs/dovecot.pem
: > %{buildroot}%{_sysconfdir}/pki/dovecot/private/dovecot.pem

# Install dovecot configuration and dovecot-openssl.cnf
mkdir -p %{buildroot}%{_sysconfdir}/dovecot/conf.d
mkdir -p %{buildroot}%{_sysconfdir}/pki/dovecot
install -p -m 644 dovecot-docs/example-config/dovecot.conf %{buildroot}%{_sysconfdir}/dovecot
install -p -m 644 dovecot-docs/example-config/conf.d/*.conf %{buildroot}%{_sysconfdir}/dovecot/conf.d
install -p -m 644 dovecot-docs/example-config/conf.d/*.conf.ext %{buildroot}%{_sysconfdir}/dovecot/conf.d
install -p -m 644 pigeonhole-docs/example-config/conf.d/*.conf %{buildroot}%{_sysconfdir}/dovecot/conf.d
install -p -m 644 pigeonhole-docs/example-config/conf.d/*.conf.ext %{buildroot}%{_sysconfdir}/dovecot/conf.d || :
install -p -m 644 doc/dovecot-openssl.cnf %{buildroot}%{_sysconfdir}/pki/dovecot/dovecot-openssl.cnf

# PAM Configuration
mkdir -p %{buildroot}%{_sysconfdir}/pam.d
install -p -m 644 dovecot.pam %{buildroot}%{_sysconfdir}/pam.d/dovecot

# Install additional manpages
install -p -D -m 644 dovecot.conf.5 %{buildroot}%{_mandir}/man5/dovecot.conf.5

# Blow away static libraries
find %{buildroot}%{_libdir}/dovecot -name '*.a' -delete

# Blow away libtool archives
find %{buildroot}%{_libdir}/dovecot -name '*.la' -delete

# Blow away unwanted documentation
rm %{buildroot}%{_sysconfdir}/dovecot/README
cd dovecot-docs
rm securecoding.txt thread-refs.txt
cd -

%check
# Setting DOVECOT_HOSTDOMAIN stops crash in gethostbyname() on Fedora 23 builds
export DOVECOT_HOSTDOMAIN=example.com
make check
make -C %{pigeonhole_dir} check

%pre
# Create account for dovecot to run as
getent group dovecot > /dev/null || \
	groupadd -g %{dovecot_gid} -r dovecot
getent passwd dovecot > /dev/null || \
	useradd -r -u %{dovecot_uid} -g dovecot \
		-d %{_libexecdir}/dovecot -M -s /sbin/nologin \
		-c "Dovecot IMAP Server" dovecot
getent group dovenull > /dev/null || \
	groupadd -r dovenull
getent passwd dovenull > /dev/null || \
	useradd -r -g dovenull \
		-d %{_libexecdir}/dovecot -s /sbin/nologin \
		-c "Dovecot's unauthorized user" dovenull

# Do not let dovecot run during upgrade (#134325)
if [ "$1" = "2" ]; then
	rm -f %{restart_flag}
	systemctl is-active dovecot.service &>/dev/null && touch %{restart_flag} || :
	systemctl stop dovecot.service &>/dev/null
fi

%post
if [ $1 -eq 1 ]; then
	systemctl daemon-reload &> /dev/null || :
fi

# Create SSL keys/certs
[ ! -f %{_sysconfdir}/pki/dovecot/certs/dovecot.pem ] && %{_libexecdir}/dovecot/mkcert.sh &> /dev/null || :

# Create SSL parameters
if [ ! -f %{_sysconfdir}/dovecot/dh.pem ]; then
	if [ -f %{_localstatedir}/lib/dovecot/ssl-parameters.dat ]; then
		# Migrate from old ssl-parameters.dat
		dd if=%{_localstatedir}/lib/dovecot/ssl-parameters.dat bs=1 skip=88 | \
			openssl dhparam -inform der > %{_sysconfdir}/dovecot/dh.pem || :
	else
		# Generate new parameters
		# This could take hours without -dsaparam, but doing it without -dsaparam is
		# advisable for users of OpenSSL 1.0.1 before 1.0.1r and OpenSSL 1.0.2 before
		# 1.0.2f, or they could be vulnerable to CVE-2016-0701
		# See https://www.openssl.org/news/secadv/20160128.txt for details
		openssl dhparam -dsaparam -out %{_sysconfdir}/dovecot/dh.pem 4096 || :
	fi
fi
exit 0

%preun
if [ $1 = 0 ]; then
	/bin/systemctl disable dovecot.service dovecot.socket &> /dev/null || :
	/bin/systemctl stop dovecot.service dovecot.socket &> /dev/null || :
	rm -rf /run/dovecot
fi

%postun
# service restarted in %%postun rather than %%post for the benefit of people doing composes in chroots
systemctl daemon-reload &> /dev/null || :
if [ "$1" -ge "1" -a -e %{restart_flag} ]; then
	systemctl start dovecot.service &> /dev/null || :
	rm -f %{restart_flag}
fi

%posttrans
# dovecot should be started again in %%postun, but it's not executed on reinstall;
# if it was already started, restart_flag won't be here, so it's ok to test it again
if [ -e %{restart_flag} ]; then
	systemctl start dovecot.service &> /dev/null || :
	rm -f %{restart_flag}
fi

%files
%{_tmpfilesdir}/dovecot.conf
%{_unitdir}/dovecot.service
%{_unitdir}/dovecot.socket
%license COPYING COPYING.LGPL COPYING.MIT
%doc dovecot-docs/* AUTHORS ChangeLog NEWS README
%dir %{_sysconfdir}/dovecot/
%dir %{_sysconfdir}/dovecot/conf.d/
%config(noreplace) %{_sysconfdir}/dovecot/dovecot.conf
%config(noreplace) %{_sysconfdir}/dovecot/conf.d/10-auth.conf
%config(noreplace) %{_sysconfdir}/dovecot/conf.d/10-director.conf
%config(noreplace) %{_sysconfdir}/dovecot/conf.d/10-logging.conf
%config(noreplace) %{_sysconfdir}/dovecot/conf.d/10-mail.conf
%config(noreplace) %{_sysconfdir}/dovecot/conf.d/10-master.conf
%config(noreplace) %{_sysconfdir}/dovecot/conf.d/10-metrics.conf
%config(noreplace) %{_sysconfdir}/dovecot/conf.d/10-ssl.conf
%config(noreplace) %{_sysconfdir}/dovecot/conf.d/15-lda.conf
%config(noreplace) %{_sysconfdir}/dovecot/conf.d/15-mailboxes.conf
%config(noreplace) %{_sysconfdir}/dovecot/conf.d/20-imap.conf
%config(noreplace) %{_sysconfdir}/dovecot/conf.d/20-lmtp.conf
%config(noreplace) %{_sysconfdir}/dovecot/conf.d/20-pop3.conf
%config(noreplace) %{_sysconfdir}/dovecot/conf.d/20-submission.conf
%config(noreplace) %{_sysconfdir}/dovecot/conf.d/90-acl.conf
%config(noreplace) %{_sysconfdir}/dovecot/conf.d/90-plugin.conf
%config(noreplace) %{_sysconfdir}/dovecot/conf.d/90-quota.conf
%config(noreplace) %{_sysconfdir}/dovecot/conf.d/auth-checkpassword.conf.ext
%config(noreplace) %{_sysconfdir}/dovecot/conf.d/auth-deny.conf.ext
%config(noreplace) %{_sysconfdir}/dovecot/conf.d/auth-dict.conf.ext
%config(noreplace) %{_sysconfdir}/dovecot/conf.d/auth-ldap.conf.ext
%config(noreplace) %{_sysconfdir}/dovecot/conf.d/auth-master.conf.ext
%config(noreplace) %{_sysconfdir}/dovecot/conf.d/auth-passwdfile.conf.ext
%config(noreplace) %{_sysconfdir}/dovecot/conf.d/auth-sql.conf.ext
%config(noreplace) %{_sysconfdir}/dovecot/conf.d/auth-static.conf.ext
%config(noreplace) %{_sysconfdir}/dovecot/conf.d/auth-system.conf.ext
%config(noreplace) %{_sysconfdir}/pam.d/dovecot
%config(noreplace) %{_sysconfdir}/pki/dovecot/dovecot-openssl.cnf
%dir %{_sysconfdir}/pki/dovecot/
%dir %{_sysconfdir}/pki/dovecot/certs/
%dir %{_sysconfdir}/pki/dovecot/private/
%attr(0600,root,root) %ghost %config(missingok,noreplace) %verify(not md5 size mtime) %{_sysconfdir}/pki/dovecot/certs/dovecot.pem
%attr(0600,root,root) %ghost %config(missingok,noreplace) %verify(not md5 size mtime) %{_sysconfdir}/pki/dovecot/private/dovecot.pem
%{_bindir}/doveadm
%{_bindir}/doveconf
%{_bindir}/dovecot-sysreport
%{_bindir}/dsync
%{_sbindir}/dovecot
%dir %{_libexecdir}/dovecot/
%{_libexecdir}/dovecot/aggregator
%{_libexecdir}/dovecot/anvil
%{_libexecdir}/dovecot/auth
%{_libexecdir}/dovecot/checkpassword-reply
%{_libexecdir}/dovecot/config
%{_libexecdir}/dovecot/decode2text.sh
%{_libexecdir}/dovecot/deliver
%{_libexecdir}/dovecot/dict
%{_libexecdir}/dovecot/director
%{_libexecdir}/dovecot/dns-client
%{_libexecdir}/dovecot/doveadm-server
%{_libexecdir}/dovecot/dovecot-lda
%{_libexecdir}/dovecot/gdbhelper
%{_libexecdir}/dovecot/health-check.sh
%{_libexecdir}/dovecot/imap
%{_libexecdir}/dovecot/imap-hibernate
%{_libexecdir}/dovecot/imap-login
%{_libexecdir}/dovecot/imap-urlauth
%{_libexecdir}/dovecot/imap-urlauth-login
%{_libexecdir}/dovecot/imap-urlauth-worker
%{_libexecdir}/dovecot/indexer
%{_libexecdir}/dovecot/indexer-worker
%{_libexecdir}/dovecot/ipc
%{_libexecdir}/dovecot/lmtp
%{_libexecdir}/dovecot/log
%{_libexecdir}/dovecot/maildirlock
%{_libexecdir}/dovecot/mkcert.sh
%{_libexecdir}/dovecot/old-stats
%{_libexecdir}/dovecot/pop3
%{_libexecdir}/dovecot/pop3-login
%{_libexecdir}/dovecot/quota-status
%{_libexecdir}/dovecot/rawlog
%{_libexecdir}/dovecot/replicator
%{_libexecdir}/dovecot/script
%{_libexecdir}/dovecot/script-login
%{_libexecdir}/dovecot/stats
%{_libexecdir}/dovecot/submission
%{_libexecdir}/dovecot/submission-login
%if 0%{?tcp_wrappers_support}
%{_libexecdir}/dovecot/tcpwrap
%endif
%{_libexecdir}/dovecot/xml2text
# Note: %%{_libdir}/dovecot/*.so are plug-ins, not devel files
%dir %{_libdir}/dovecot/
%dir %{_libdir}/dovecot/auth/
%dir %{_libdir}/dovecot/dict/
%dir %{_libdir}/dovecot/doveadm/
%dir %{_libdir}/dovecot/old-stats/
%dir %{_libdir}/dovecot/settings/
%{_libdir}/dovecot/auth/lib20_auth_var_expand_crypt.so
%{_libdir}/dovecot/auth/libauthdb_imap.so
%{_libdir}/dovecot/auth/libauthdb_ldap.so
%if 0%{?lua_support}
%{_libdir}/dovecot/auth/libauthdb_lua.so
%endif
%{_libdir}/dovecot/auth/libmech_gssapi.so
%{_libdir}/dovecot/auth/libdriver_sqlite.so
%{_libdir}/dovecot/dict/libdict_ldap.so
%{_libdir}/dovecot/dict/libdriver_sqlite.so
%{_libdir}/dovecot/doveadm/lib10_doveadm_acl_plugin.so
%{_libdir}/dovecot/doveadm/lib10_doveadm_quota_plugin.so
%{_libdir}/dovecot/doveadm/lib20_doveadm_fts_plugin.so
%if 0%{?lucene_support}
%{_libdir}/dovecot/doveadm/lib20_doveadm_fts_lucene_plugin.so
%endif
%{_libdir}/dovecot/doveadm/libdoveadm_mail_crypt_plugin.so
%{_libdir}/dovecot/libdriver_sqlite.so
%{_libdir}/dovecot/libdovecot.so.0
%{_libdir}/dovecot/libdovecot.so.0.0.0
%{_libdir}/dovecot/libdovecot-compression.so.0
%{_libdir}/dovecot/libdovecot-compression.so.0.0.0
%{_libdir}/dovecot/libdovecot-dsync.so.0
%{_libdir}/dovecot/libdovecot-dsync.so.0.0.0
%{_libdir}/dovecot/libdovecot-fts.so.0
%{_libdir}/dovecot/libdovecot-fts.so.0.0.0
%{_libdir}/dovecot/libdovecot-lda.so.0
%{_libdir}/dovecot/libdovecot-lda.so.0.0.0
%{_libdir}/dovecot/libdovecot-ldap.so.0
%{_libdir}/dovecot/libdovecot-ldap.so.0.0.0
%{_libdir}/dovecot/libdovecot-login.so.0
%{_libdir}/dovecot/libdovecot-login.so.0.0.0
%if 0%{?lua_support}
%{_libdir}/dovecot/libdovecot-lua.so
%{_libdir}/dovecot/libdovecot-lua.so.0
%{_libdir}/dovecot/libdovecot-lua.so.0.0.0
%endif
%{_libdir}/dovecot/libdovecot-sieve.so.0
%{_libdir}/dovecot/libdovecot-sieve.so.0.0.0
%{_libdir}/dovecot/libdovecot-sql.so.0
%{_libdir}/dovecot/libdovecot-sql.so.0.0.0
%{_libdir}/dovecot/libdovecot-storage.so.0
%{_libdir}/dovecot/libdovecot-storage.so.0.0.0
%if 0%{?lua_support}
%{_libdir}/dovecot/libdovecot-storage-lua.so
%{_libdir}/dovecot/libdovecot-storage-lua.so.0
%{_libdir}/dovecot/libdovecot-storage-lua.so.0.0.0
%endif
%{_libdir}/dovecot/lib01_acl_plugin.so
%if 0%{?lua_support}
%{_libdir}/dovecot/lib01_mail_lua_plugin.so
%endif
%{_libdir}/dovecot/lib02_imap_acl_plugin.so
%{_libdir}/dovecot/lib02_lazy_expunge_plugin.so
%{_libdir}/dovecot/lib05_mail_crypt_acl_plugin.so
%{_libdir}/dovecot/lib05_pop3_migration_plugin.so
%{_libdir}/dovecot/lib10_last_login_plugin.so
%{_libdir}/dovecot/lib10_mail_crypt_plugin.so
%{_libdir}/dovecot/lib10_quota_plugin.so
%{_libdir}/dovecot/lib11_imap_quota_plugin.so
%{_libdir}/dovecot/lib11_trash_plugin.so
%{_libdir}/dovecot/lib15_notify_plugin.so
%{_libdir}/dovecot/lib20_charset_alias_plugin.so
%{_libdir}/dovecot/lib20_fts_plugin.so
%{_libdir}/dovecot/lib20_listescape_plugin.so
%{_libdir}/dovecot/lib20_mail_log_plugin.so
%{_libdir}/dovecot/lib20_mailbox_alias_plugin.so
%{_libdir}/dovecot/lib20_notify_status_plugin.so
%{_libdir}/dovecot/lib20_push_notification_plugin.so
%{_libdir}/dovecot/lib20_quota_clone_plugin.so
%{_libdir}/dovecot/lib20_replication_plugin.so
%{_libdir}/dovecot/lib20_var_expand_crypt.so
%{_libdir}/dovecot/lib20_virtual_plugin.so
%{_libdir}/dovecot/lib20_zlib_plugin.so
%if 0%{?lucene_support}
%{_libdir}/dovecot/lib21_fts_lucene_plugin.so
%endif
%{_libdir}/dovecot/lib21_fts_solr_plugin.so
%{_libdir}/dovecot/lib21_fts_squat_plugin.so
%if 0%{?lua_support}
%{_libdir}/dovecot/lib22_push_notification_lua_plugin.so
%endif
%{_libdir}/dovecot/lib30_imap_zlib_plugin.so
%{_libdir}/dovecot/lib90_old_stats_plugin.so
%{_libdir}/dovecot/lib95_imap_old_stats_plugin.so
%{_libdir}/dovecot/lib95_imap_sieve_plugin.so
%{_libdir}/dovecot/lib99_welcome_plugin.so
%{_libdir}/dovecot/libdcrypt_openssl.so
%{_libdir}/dovecot/libfs_compress.so
%{_libdir}/dovecot/libfs_crypt.so
%{_libdir}/dovecot/libfs_mail_crypt.so
%{_libdir}/dovecot/libssl_iostream_openssl.so
%{_libdir}/dovecot/old-stats/libold_stats_mail.so
%{_libdir}/dovecot/old-stats/libstats_auth.so
%attr(0755,root,dovecot) %dir /run/dovecot/
%dir /run/dovecot/empty/
%attr(0750,root,dovenull) %dir /run/dovecot/login/
%attr(0750,root,dovenull) %dir /run/dovecot/token-login/
%attr(0750,dovecot,dovecot) %dir %{_localstatedir}/lib/dovecot/
%dir %{_datadir}/dovecot/
%dir %{_datadir}/dovecot/stopwords/
%{_datadir}/dovecot/stopwords/stopwords_da.txt
%{_datadir}/dovecot/stopwords/stopwords_de.txt
%{_datadir}/dovecot/stopwords/stopwords_en.txt
%{_datadir}/dovecot/stopwords/stopwords_es.txt
%{_datadir}/dovecot/stopwords/stopwords_fi.txt
%{_datadir}/dovecot/stopwords/stopwords_fr.txt
%{_datadir}/dovecot/stopwords/stopwords_it.txt
%{_datadir}/dovecot/stopwords/stopwords_nl.txt
%{_datadir}/dovecot/stopwords/stopwords_no.txt
%{_datadir}/dovecot/stopwords/stopwords_pt.txt
%{_datadir}/dovecot/stopwords/stopwords_ro.txt
%{_datadir}/dovecot/stopwords/stopwords_ru.txt
%{_datadir}/dovecot/stopwords/stopwords_sv.txt
%{_datadir}/dovecot/stopwords/stopwords_tr.txt
%{_mandir}/man1/deliver.1*
%{_mandir}/man1/doveadm.1*
%{_mandir}/man1/doveadm-acl.1*
%{_mandir}/man1/doveadm-altmove.1*
%{_mandir}/man1/doveadm-auth.1*
%{_mandir}/man1/doveadm-backup.1*
%{_mandir}/man1/doveadm-batch.1*
%{_mandir}/man1/doveadm-config.1*
%{_mandir}/man1/doveadm-copy.1*
%{_mandir}/man1/doveadm-deduplicate.1*
%{_mandir}/man1/doveadm-director.1*
%{_mandir}/man1/doveadm-dump.1*
%{_mandir}/man1/doveadm-exec.1*
%{_mandir}/man1/doveadm-expunge.1*
%{_mandir}/man1/doveadm-fetch.1*
%{_mandir}/man1/doveadm-flags.1*
%{_mandir}/man1/doveadm-force-resync.1*
%{_mandir}/man1/doveadm-fs.1*
%{_mandir}/man1/doveadm-fts.1*
%{_mandir}/man1/doveadm-help.1*
%{_mandir}/man1/doveadm-import.1*
%{_mandir}/man1/doveadm-index.1*
%{_mandir}/man1/doveadm-instance.1*
%{_mandir}/man1/doveadm-kick.1*
%{_mandir}/man1/doveadm-log.1*
%{_mandir}/man1/doveadm-mailbox.1*
%{_mandir}/man1/doveadm-mailbox-cryptokey.1*
%{_mandir}/man1/doveadm-move.1*
%{_mandir}/man1/doveadm-penalty.1*
%{_mandir}/man1/doveadm-proxy.1*
%{_mandir}/man1/doveadm-purge.1*
%{_mandir}/man1/doveadm-pw.1*
%{_mandir}/man1/doveadm-quota.1*
%{_mandir}/man1/doveadm-rebuild.1*
%{_mandir}/man1/doveadm-reload.1*
%{_mandir}/man1/doveadm-replicator.1*
%{_mandir}/man1/doveadm-save.1*
%{_mandir}/man1/doveadm-search.1*
%{_mandir}/man1/doveadm-stats.1*
%{_mandir}/man1/doveadm-stop.1*
%{_mandir}/man1/doveadm-sync.1*
%{_mandir}/man1/doveadm-user.1*
%{_mandir}/man1/doveadm-who.1*
%{_mandir}/man1/doveconf.1*
%{_mandir}/man1/dovecot.1*
%{_mandir}/man1/dovecot-lda.1*
%{_mandir}/man1/dovecot-sysreport.1*
%{_mandir}/man1/dsync.1*
%{_mandir}/man5/dovecot.conf.5*
%{_mandir}/man7/doveadm-search-query.7*

%files devel
%{_includedir}/dovecot/
%{_datadir}/aclocal/dovecot.m4
%{_datadir}/aclocal/dovecot-pigeonhole.m4
%{_libdir}/dovecot/dovecot-config
%{_libdir}/dovecot/libdovecot.so
%{_libdir}/dovecot/libdovecot-compression.so
%{_libdir}/dovecot/libdovecot-dsync.so
%{_libdir}/dovecot/libdovecot-fts.so
%{_libdir}/dovecot/libdovecot-lda.so
%{_libdir}/dovecot/libdovecot-ldap.so
%{_libdir}/dovecot/libdovecot-login.so
%{_libdir}/dovecot/libdovecot-sieve.so
%{_libdir}/dovecot/libdovecot-sql.so
%{_libdir}/dovecot/libdovecot-storage.so

%files pigeonhole
%license %{pigeonhole_dir}/COPYING %{pigeonhole_dir}/COPYING.LGPL
%doc pigeonhole-docs/*
%config(noreplace) %{_sysconfdir}/dovecot/conf.d/20-managesieve.conf
%config(noreplace) %{_sysconfdir}/dovecot/conf.d/90-sieve.conf
%config(noreplace) %{_sysconfdir}/dovecot/conf.d/90-sieve-extprograms.conf
%{_bindir}/sievec
%{_bindir}/sieve-dump
%{_bindir}/sieve-filter
%{_bindir}/sieve-test
%{_libdir}/dovecot/lib90_sieve_plugin.so
%{_libdir}/dovecot/lib95_imap_filter_sieve_plugin.so
%{_libdir}/dovecot/doveadm/lib10_doveadm_sieve_plugin.so
%{_libdir}/dovecot/settings/libmanagesieve_settings.so
%{_libdir}/dovecot/settings/libmanagesieve_login_settings.so
%{_libdir}/dovecot/settings/libpigeonhole_settings.so
%{_libdir}/dovecot/sieve/
%{_libexecdir}/dovecot/managesieve
%{_libexecdir}/dovecot/managesieve-login
%{_mandir}/man1/doveadm-sieve.1*
%{_mandir}/man1/sievec.1*
%{_mandir}/man1/sieved.1*
%{_mandir}/man1/sieve-dump.1*
%{_mandir}/man1/sieve-filter.1*
%{_mandir}/man1/sieve-test.1*
%{_mandir}/man7/pigeonhole.7*

%files mysql
%{_libdir}/dovecot/libdriver_mysql.so
%{_libdir}/dovecot/auth/libdriver_mysql.so
%{_libdir}/dovecot/dict/libdriver_mysql.so

%files pgsql
%{_libdir}/dovecot/libdriver_pgsql.so
%{_libdir}/dovecot/auth/libdriver_pgsql.so
%{_libdir}/dovecot/dict/libdriver_pgsql.so

%changelog
* Wed Oct 25 2023 Paul Howarth <paul@city-fan.org> - 1:2.3.21-3.0.cf
- Drop lucene to reduce dependencies from Fedora 40, EL-10 onwards; use solr
  for fts instead
- Drop now-redundant build dependency glibc-gconv-extra

* Fri Oct  6 2023 Paul Howarth <paul@city-fan.org> - 1:2.3.21-2.0.cf
- Rebuild for new libsodium in Rawhide

* Mon Sep 18 2023 Paul Howarth <paul@city-fan.org> - 1:2.3.21-1.0.cf
- Update dovecot to 2.3.21
  - lib-oauth2: Allow JWT tokens to be validated with missing typ field
    - The typ field is left out by some key issuers to conserve space, notably
      kubernetes
    - Now, missing typ is tolerated but if present it still must be "jwt"
  - auth: Auth passdb and userdb reply can contain "event_<name>=value", which
    will be added to login event and mail user event respectively
  - lib-master: Set process title during various initialization stages to
    clearly describe what the process is waiting on
  - lib-storage: The mail_temp_scan_interval is now fuzzed, incrementing it by
    0..30%% based on username's hash to reduce the chance of load spikes
  - lib-storage: The temp file scan has been moved from the open of the mailbox
    to the close, to reduce the latency perceived by users
  - stats: If metric has fields specified, all these fields are exported as
    counters to prometheus exposition
    See https://doc.dovecot.org/configuration_manual/stats/openmetrics/
  - *-login: Processes might have crashed when a SSL connection disconnects
    uncleanly
  - acl: When plugin was loaded \HasChildren and \HasNoChildren flags were
    calculated incorrectly for mailboxes containing '*' and '%%' in their
    names
  - auth: Crash occured if a connection to PostgreSQL database server failed
    during startup
  - auth: Logins with invalid passwords (e.g. unknown scheme) in passdb were
    failing with "password mismatch" instead of "internal error"
  - auth: XOAUTH2 and OAUTHBEARER mechanisms were not giving out protocol
    specific error message on all errors, which especially broke OIDC discovery
  - dbox: When last_temp_file_scan header wasn't set (especially after dsync
    migration), the next mailbox open always triggers the temp file scan; this
    could have caused a load spike after migrations (fixed by using the mailbox
    directory's atime when the header isn't set, which usually moves the scan
    time into the future)
  - dict-redis: A crash would occur on transaction rollback
  - dsync: Infinite loop causing out of memory would occur when handling
    mailbox deletion from remote end and hierarchy separators would differ
  - dsync: Incremental dsync failed for folder names ending with '%%', unless
    BROKENCHAR was set; also folder names with '%%' elsewhere in them caused
    each incremental dsync to unnecessarily rename the folder to a temporary
    name and back (v2.3.19 regression)
  - imap-hibernate: If an IMAP client unhibernation timed out with
    "(version received)", the unhibernation could still have successfully
    finished later on and continued working normally, which was rather
    confusing, because imap-hibernate already logged that the client got
    disconnected; avoid this by forcing the connection to shutdown on
    unhibernation timeout
  - imapc: Crashed when a folder mapped through the virtual plugin disappears
    from the storage
  - imapc: EXPUNGE, EXISTS or FETCH replies from a server for a previously
    selected mailbox could have been processed as if they belonged to the new
    mailbox currently being selected; this could have caused warnings
  - lib-http: Dovecot HTTP server (doveadm, stats/openmetrics) may have
    disconnected HTTP clients before the response is fully sent; this happened
    only on busy servers where kernel's socket buffers were rather full
  - lib-http: Fixed a potential crash on http-server if a client disconnected
    early (v2.3.18 regression)
  - lib-index: Index file corruption could have caused a crash
    Fixes:
    Panic: file mail-transaction-log-view.c: line 165 (mail_transaction_log_view_set):
    assertion failed: (min_file_seq <= max_file_seq).
  - lib-index: Purging an existing >1GB cache file can crash; now, cache files
    still above 1GB after purging are removed
    Fixes:
    Panic: file mail-index-util.c: line 10 (mail_index_uint32_to_offset):
    assertion failed: (offset < 0x40000000)
  - lib-lua: A HTTP client could not resolve DNS names in mail processes,
    because it expected "the dns-client" socket to exist in the current
    directory
  - lib-oauth2: Dovecot would send client_id and client_secret as POST
    parameters to the introspection server; these need to be optionally in
    Basic auth instead
  - lib-oauth2: JWT aud validation was not performed if aud was missing from a
    token, but was configured on Dovecot
  - lib-oauth2: JWT key type check was too strict
  - lib-oauth2: JWT token audience was not validated against client_id as
    required by the specification
  - lib-ssl-iostream: Using the ssl_require_crl=yes setting may have caused
    CRL check failures for outgoing SSL/TLS connections, although it was
    supposed to affect checking CRLs only for client-side SSL certificates
    (v2.3.17 regression)
  - lib-sql: MySQL driver leaked memory when connection failed
  - lib-storage: Various fixes when running into out of disk space
  - master: Service idle_kill setting didn't work properly on busy servers
    - It was very unlikely that any process was idling long enough to become
      killed
    - Also, the idle_kill handling code was using quite a lot of CPU on the
      master process when there were a lot of processes (e.g. imap)
    - The new behaviour is to track the lowest number of idling processes every
      idle_kill time interval and then kill that many idling processes
  - mdbox: Temp file scan was done for always empty directories
  - mdbox: The fdatasync() call was done in wrong parent directory when
    writing mails (also on a failure it crashed instead of logging an error)
  - notify_status: The plugin crashes if any user initialization fails
  - pop3: Sending command with the ':' character caused an assert-crash
    (v2.3.18 regression)
    Fixes: Panic: event_reason_code_prefix(): name has ':'
  - stats: Fix panic when a nonexistent event exporter was referenced while
    adding a new metric dynamically via doveadm stats add; this produces a
    proper error now
  - stats: If process exported a lot of events and then exited, some of the
    last events may have become lost
  - stats: Invalid Prometheus label names were created with specific
    histogram group_by configurations; Prometheus rejected these labels
  - welcome: The plugin didn't execute in some situations that created INBOX
    but didn't open it, e.g. if GETMETADATA was used before the INBOX was opened
- Update pigeonhole to 0.5.21
  - sieve: Using the deleteheader action on a message with a broken/invalid
    header can cause the Sieve interpreter to crash with an assert panic; this
    can happen e.g. when the message is missing the empty EOH line between the
    headers and the body of the message
    Fixes:
    Panic: file edit-mail.c: line 820 (edit_mail_headers_parse):
    assertion failed: (body_offset > 0).
  - sieve: Pigeonhole added an extra Message-ID header during mail forwarding
    when the existing one was invalid; now it adds the Message-ID only if it is
    entirely missing - existing Message-ID(s) are left unchanged

* Thu Jul 20 2023 Paul Howarth <paul@city-fan.org> - 1:2.3.20-6.0.cf
- Rebuilt for https://fedoraproject.org/wiki/Fedora_39_Mass_Rebuild

* Sun Jul 16 2023 Paul Howarth <paul@city-fan.org> - 1:2.3.20-5.0.cf
- Rebuilt for ICU 73.2

* Thu Apr 27 2023 Paul Howarth <paul@city-fan.org> - 1:2.3.20-4.0.cf
- Use SPDX-format license tag
- Avoid use of deprecated patch syntax

* Tue Feb 14 2023 Paul Howarth <paul@city-fan.org> - 1:2.3.20-3.0.cf
- Drop SHA1 OTP from F-39/EL-9 onwards

* Thu Jan 19 2023 Paul Howarth <paul@city-fan.org> - 1:2.3.20-2.0.cf
- Rebuilt for https://fedoraproject.org/wiki/Fedora_38_Mass_Rebuild

* Mon Dec 26 2022 Paul Howarth <paul@city-fan.org> - 1:2.3.20-1.0.cf
- Update dovecot to 2.3.20
  - Add dsync_features=no-header-hashes
    - When this setting is enabled and one dsync side doesn't support mail
      GUIDs (i.e. imapc), there is no fallback to using header hashes; instead,
      dsync assumes that all mails with identical IMAP UIDs contains the same
      mail contents, which can significantly improve dsync performance with
      some IMAP servers that don't support caching Date/Message-ID headers
  - lua: HTTP client has more settings now
    - See https://doc.dovecot.org/admin_manual/lua/#dovecot.http.client
  - replicator: "doveadm replicator status" command now outputs when the next
    sync is expected for the user
  - LAYOUT=index: Duplicate GUIDs were not cleaned out; also, the list recovery
    was not optimal
  - auth: Assert crash would occur when iterating multiple userdb backends
  - director: Logging into director using master user with
    auth_master_user_separator character redirected user to a wrong backend,
    unless master_user_separator setting was also set to the same value;
    merged these into auth_master_user_separator
  - dsync: Couldn't always fix folder GUID conflicts automatically with Maildir
    format; this resulted in replication repeatedly failing with "Remote lost
    mailbox GUID"
  - dsync: Failed to migrate INBOX when using namespace prefix=INBOX/,
    resulting in "Remote lost mailbox GUID" errors
  - dsync: INBOX was created too early with namespace prefix=INBOX/, resulting
    in a GUID conflict; this may have been resolved automatically, but not
    always
  - dsync: v2.3.18 regression: Wrong imapc password with dsync caused
    Panic: file lib-event.c: line 506 (event_pop_global):
    assertion failed: (event == current_global_event)
  - imapc: Requesting STATUS for a mailbox with imapc and INDEXPVT configured
    did not return correct (private) unseen counts
  - lib-dict: Process would crash when committing data to redis without dict
    proxy
  - lib-mail: Corrupted cached BODYSTRUCTURE caused panic during FETCH (v2.3.13
    regression)
    Fixes: Panic: file message-part-data.c: line 579 (message_part_is_attachment):
    assertion failed: (data != NULL)
  - lib-storage: mail_attribute_dict with dict-sql failed when it tried to
    lookup empty dict keys
  - lib: ioloop-kqueue was missing include, breaking some BSD builds
  - lua-http: Dovecot Lua HTTP client could not resolve DNS names in mail
    processes, because it expected "dns-client" socket to exist in the current
    directory
  - oauth2: Using %%{oauth2:name} variables could cause useless introspections
  - pop3: Sending POP3 command with ':' character caused an assert-crash
    (v2.3.18 regression)
  - replicator: Replication queue had various issues, potentially causing
    replication requests to become stuck
  - stats: Invalid Prometheus label names were created with specific histogram
    group_by configurations; Prometheus rejected these labels
- Update pigeonhole to 0.5.20
  - No changes - release done to keep version numbers synced

* Wed Nov  9 2022 Paul Howarth <paul@city-fan.org> - 1:2.3.19.1-6.0.cf
- Use Wants=network-online.target instead of preexec nm-online (#2095949)

* Wed Oct 12 2022 Paul Howarth <paul@city-fan.org> - 1:2.3.19.1-5.0.cf
- Build with lua support from Fedora 38 onwards (#2132420)

* Wed Aug  3 2022 Paul Howarth <paul@city-fan.org> - 1:2.3.19.1-4.0.cf
- Rebuilt for ICU 71.1

* Sat Jul 23 2022 Paul Howarth <paul@city-fan.org> - 1:2.3.19.1-3.0.cf
- Rebuilt for https://fedoraproject.org/wiki/Fedora_37_Mass_Rebuild

* Fri Jul 15 2022 Paul Howarth <paul@city-fan.org> - 1:2.3.19.1-2.0.cf
- Fix possible privilege escalation when similar master and non-master passdbs
  are used

* Tue Jun 14 2022 Paul Howarth <paul@city-fan.org> - 1:2.3.19.1-1.0.cf
- Update dovecot to 2.3.19.1
  - doveadm deduplicate: Non-duplicate mails were deleted (v2.3.19 regression)
  - auth: Crash would occur when iterating multiple backends; fixes:
    Panic: file userdb-blocking.c: line 125 (userdb_blocking_iter_next):
    assertion failed: (ctx->conn != NULL)

* Fri Jun  3 2022 Paul Howarth <paul@city-fan.org> - 1:2.3.19-1.0.cf
- Update dovecot to 2.3.19
  - Added mail_user_session_finished event, which is emitted when the mail user
    session is finished (e.g. imap, pop3, lmtp); it also includes fields with
    some process statistics information (see
    https://doc.dovecot.org/admin_manual/list_of_events/ for more information)
  - Added process_shutdown_filter setting: when an event matches the filter,
    the process will be shut down after the current connection(s) have finished,
    which is intended to reduce memory usage of long-running imap processes that
    keep a lot of memory allocated instead of freeing it to the OS
  - auth: Add cache hit indicator to auth passdb/userdb finished events; see
    https://doc.dovecot.org/admin_manual/list_of_events/ for more information
  - doveadm deduplicate: Performance is improved significantly
  - imapc: COPY commands were sent one mail at a time to the remote IMAP server;
    now the copying is buffered, so multiple mails can be copied with a single
    COPY command
  - lib-lua: Add a Lua interface to Dovecot's HTTP client library; see
    https://doc.dovecot.org/admin_manual/lua/ for more information
  - auth: Cache lookup would use incorrect cache key after username change
  - auth: Improve handling unexpected LDAP connection errors/hangs; try to fix
    up these cases by reconnecting to the LDAP server and aborting LDAP requests
    earlier
  - auth: Process crashed if userdb iteration was attempted while auth-workers
    were already full handling auth requests
  - auth: db-oauth2: Using %%{oauth2:name} variables caused unnecessary
    introspection requests
  - dict: Timeouts may have been leaked at deinit
  - director: Ring may have become unstable if a backend's tag was changed; it
    could also have caused director process to crash
  - doveadm kick: Numeric parameter was treated as IP address
  - doveadm: Proxying can panic when flushing print output; fixes:
    Panic: file ioloop.c: line 865 (io_loop_destroy): assertion failed:
    (ioloop == current_ioloop)
  - doveadm sync: BROKENCHAR was wrongly changed to '_' character when migrating
    mailboxes; this was set by default to %%, so any mailbox names containing %%
    characters were modified to "_25"
  - imapc: Copying or moving mails with doveadm to an imapc mailbox could have
    produced "Error: Syncing mailbox '[...]' failed" errors; the operation
    itself succeeded but attempting to sync the destination mailbox failed
  - imapc: Prevent index log synchronization errors when two or more imapc
    sessions are adding messages to the same mailbox index files, i.e.
    INDEX=MEMORY is not used
  - indexer: Process was slowly leaking memory for each indexing request
  - lib-fts: fts header filters caused binary content to be sent to the indexer
    with non-default configuration
  - doveadm-server: Process could hang in some situations when printing output
    to TCP client, e.g. when printing doveadm sync state
  - lib-index: dovecot.index.log files were often read and parsed entirely,
    rather than only the parts that were actually necessary; this mainly
    increased CPU usage
  - lmtp-proxy: Session ID forwarding would cause same session IDs being used
    when delivering the same mail to multiple backends
  - log: Log prefix update may have been lost if log process was busy; this
    could have caused log prefixes to be empty or in some cases reused between
    sessions, i.e. log lines could have been logged for the wrong user/session
  - mail_crypt: Plugin crashes if it's loaded only for some users: fixes
    Panic: Module context mail_crypt_user_module missing
  - mail_crypt: When LMTP was delivering mails to both recipients with mail
    encryption enabled and not enabled, the non-encrypted recipients may have
    gotten mails encrypted anyway; this happened when the first recipient was
    encrypted (mail_crypt_save_version=2) and the 2nd recipient was not
    encrypted (mail_crypt_save_version=0)
  - pop3: Session would crash if empty line was sent
  - stats: HTTP server leaked memory
  - submission-login: Long credentials, such as OAUTH2 tokens, were refused
    during SASL interactive due to submission server applying line length limits
  - submission-login: When proxying to remote host, authentication was not
    using interactive SASL when logging in using long credentials such as OAUTH2
    tokens; this caused authentication to fail due to line length constraints in
    SMTP protocol
  - submission: Terminating the client connection with QUIT command after mail
    transaction is started with MAIL command and before it is finished with
    DATA/BDAT can cause a segfault crash
  - virtual: doveadm search queries with mailbox-guid as the only parameter
    crashes: Panic: file virtual-search.c: line 77 (virtual_search_get_records):
    assertion failed: (result != 0)
- Update pigeonhole to 0.5.19
  - No changes - release done to keep version numbers synced

* Fri Feb  4 2022 Paul Howarth <paul@city-fan.org> - 1:2.3.18-1.0.cf
- Update dovecot to 2.3.18
  - Removed mail_cache_lookup_finished event: this event wasn't especially
    useful, but it increased CPU usage significantly
  - fts: Don't index inline base64 encoded content in FTS indexes using the
    generic tokenizer; this reduces the FTS index sizes by removing input that
    is very unlikely to be searched for
    - See https://doc.dovecot.org/configuration_manual/fts/tokenization for
      details on how base64 is detected
    - Only applies when using libfts
  - lmtp: Session IDs are now preserved through proxied connections, so LMTP
    sessions can be tracked; this slightly changes the LMTP session ID format
    by appending ":Tn" (transaction), ":Pn" (proxy connection) and ":Rn"
    (recipient) counters after the session ID prefix
  - Events now have "reason_code" field, which can provide a list of reasons
    why the event is happening (see
    https://doc.dovecot.org/admin_manual/event_reasons/)
  - New events are added (see
    https://doc.dovecot.org/admin_manual/list_of_events/)
  - fts: Added fts_header_excludes and fts_header_includes settings to specify
    which headers to index (see
    https://doc.dovecot.org/settings/plugin/fts-plugin#plugin-fts-setting-fts-header-excludes
    for configuration details)
  - fts: Initialize the textcat language detection library only once per
    process; this can reduce CPU usage if fts_languages setting has multiple
    languages listed and service indexer-worker { service_count } isn't 1
    - Only applies when using libfts
  - lib-storage: Reduced CPU usage significantly for some operations that
    accessed lots of emails (e.g. fetching all flags in a folder, SORT, ...)
  - lib: DOVECOT_PREREQ() - Add micro version that enables compiling external
    plugins against different versions of Dovecot
  - lmtp: Added new lmtp_verbose_replies setting that makes errors sent to the
    LMTP client much more verbose with details about why exactly backend proxy
    connections or commands are failing
  - submission: Support implicit SASL EXTERNAL with
    submission_client_workarounds=implicit-auth-external; this allows
    automatically logging in when SSL client certificate is present
  - *-login: Statistics were disabled if stats process connection was lost
  - auth: Authentication master user login fails with SCRAM-* SASL mechanisms
  - auth: With auth_cache_verify_password_with_worker=yes, passdb extra fields
    in the auth cache got lost
  - doveadm: Fixed crash if zlib_save_level setting was specified, but
    zlib_save was unset (v2.3.15 regression)
  - doveadm: Proxying can panic when flushing print output (v2.3.17 regression)
    Fixes: Panic: file ioloop.c: line 865 (io_loop_destroy): assertion failed:
    (ioloop == current_ioloop)
  - doveadm: stats add --group-by parameter didn't work
  - fts: Using email-address fts tokenizer could result in excessive memory
    usage with garbage email input, which could cause the indexer-worker
    processes to fail due to reaching the VSZ memory size limit
    - Only applies when using libfts
  - imap: A SEARCH command timing out while fts returns indexes may timeout
    returning "NO [SERVERBUG]", while it should return "NO [INUSE]" instead
  - imap: LIST-EXTENDED doesn't return STATUS for all folders; sending
    LIST .. RETURN (SUBSCRIBED STATUS (...)) did not return STATUS for folders
    that are not subscribed when they have a child folder that is subscribed as
    mandated by IMAP RFCs
  - imapc: Mailbox vsize calculation crashed with
    Panic: file index-mailbox-size.c: line 344 (index_mailbox_vsize_hdr_add_missing):
    assertion failed: (mails_left > 0)
  - indexer: If indexer-worker crashes, the request it was processing gets
    stuck in the indexer process; this stops indexing for the folder until
    indexer process is restarted (v2.3.14 regression)
  - indexer: Process was slowly leaking memory for each indexing request
  - lib-event: Unnamed events were wrongly filtered out for event/metric
    filters like "event=abc OR something_independent_of_event_name"
  - lib-index: 64-bit big endian CPUs handle last_used field in
    dovecot.index.cache wrong
  - lib-ssl-iostream: Fix buggy OpenSSL error handling without assert-crashing;
    if there is no error available, log it as an error instead of crashing
    - The previous fix for this in v2.3.11 was incomplete
    - Fixes
      Panic: file istream-openssl.c: line 51 (i_stream_ssl_read_real):
      assertion failed: (errno != 0)
  - lmtp: Out-of-memory issues can happen when proxying large messages to
    LMTP backend servers that accept the message data too slowly
  - master: HAProxy header parsing has read buffer overflow if provided header
    size is invalid; this happens only if inet_listener { haproxy=yes } is
    configured and only if the remote IP address is in haproxy_trusted_networks
  - old_stats: Plugin kept increasing memory usage, which became noticeable
    with long-running imap sessions
  - stats: Dynamically adding same metric multiple times causes multiple stats
  - submission-login: Authentication does not accept OAUTH2 token (or other
    very long credentials) because it considers the line to be too long
  - submission-login: Process can crash if HELO is pipelined with an invalid
    domain
  - submission-proxy: Don't use SASL-IR if it would make the AUTH command line
    longer than 512 bytes
  - submission: Service would crash if relay server authentication failed
  - virtual: FTS search in a virtual folder could crash if there are duplicate
    mailbox GUIDs; this mainly happened when user had both INBOX and
    INBOX/INBOX folders and the namespace prefix was INBOX/
    - Fixes
      Panic: file hash.c: line 252 (hash_table_insert_node):
      assertion failed: (opcode == HASH_TABLE_OP_UPDATE)
  - virtual: If mailbox opening fails, the backend mailbox is leaked and
    process crashes when client disconnects; fixes
    Panic: file mail-user.c: line 232 (mail_user_deinit):
    assertion failed: ((*user)->refcount == 1)
  - virtual: Searching headers in virtual folders didn't always use full-text
    search indexes, if fts_enforced=no or body
- Update pigeonhole to 0.5.18
  - duplicate: Users without a home directory can crash with Sieve when using
    duplicate database (v2.3.17 regression)
  - imapsieve: When mail was expunged when processing imapsieve events, a crash
    could occur; fixes
    Panic: file mail-index-map.c: line 558 (mail_index_map_lookup_seq_range):
    assertion failed: (first_uid > 0)
  - managesieve-login: Proxy didn't support forwarding the forward_* passdb
    fields
  - redirect: Sieve would crash if redirect after keep-equivalent action failed
  - sieve: Interpreter crashes when the Sieve index extension is used with
    index zero
  - vnd.dovecot.filter: Envelope sender string may become corrupted when Sieve
    scripts are using vnd.dovecot.filter; this could end up corrupting mbox's
    From line and return wrong envelope sender string in Sieve tests

* Fri Jan 21 2022 Paul Howarth <paul@city-fan.org> - 1:2.3.17.1-2.0.cf
- Rebuilt for https://fedoraproject.org/wiki/Fedora_36_Mass_Rebuild

* Sun Dec 12 2021 Paul Howarth <paul@city-fan.org> - 1:2.3.17.1-1.1.cf
- No libsodium in EL-9

* Tue Dec  7 2021 Paul Howarth <paul@city-fan.org> - 1:2.3.17.1-1.0.cf
- Update dovecot to 2.3.17.1
  - dsync: Add back accidentally removed parameters
  - lib-ssl-iostream: Fix assert-crash when OpenSSL returned syscall error
    without errno
  - master: Dovecot failed to start if ssl_ca was too large
- Update pigeonhole to 0.5.17.1
  - managesieve: Dovecot failed to start if ssl_ca was too large
  - lib-sieve-tool: Binaries failed to run if ssl_ca was too large

* Fri Oct 29 2021 Paul Howarth <paul@city-fan.org> - 1:2.3.17-1.0.cf
- Update dovecot to 2.3.17
  - Dovecot now logs a warning if time seems to jump forward at least 100
    milliseconds
  - dict: Lines logged by the dict process now contain the dict name as the
    prefix
  - lib-index: mail_cache_fields, mail_always_cache_fields and
    mail_never_cache_fields now verify that the listed header names are valid;
    in particular, the UTF8 "–" character has sometimes been wrongly used
    instead of the ASCII "-"
  - *-login: Added login_proxy_rawlog_dir setting to capture rawlogs between
    proxy and backend
  - dict: The server process now keeps the last 10 idle dict backends cached
    for a maximum of 30 seconds; practically this acts as a connection pool
    for dict-redis and dict-ldap (note that this doesn't affect dict-sql,
    because it already had its own internal cache)
  - doveadm: New stats add/remove commands added to support changing the
    metrics configuration at runtime
  - lazy_expunge: Added lazy_expunge_exclude settings to disable lazy_expunge
    for specific folders; \Special-use flags can be used as folder names
  - lib-lua: Added a new helper function dovecot.restrict_global_variables()
    to disable or enable defining new global variables
  - LAYOUT=index List index rebuild was missing
  - LAYOUT=index: Duplicate GUIDs were not detected
  - acl: When using acl_ignore_namespace Dovecot attempted to access or create
    dovecot-acl-list even when the namespace should have been ignored; for
    virtual namespaces this could have yielded errors about "Read-only file
    system" or "Permission denied"
  - auth: Setting the "master" passdb field to empty value would cause
    proxying to fail with an authentication error; now, an empty "master" field
    is ignored
  - doveadm-server: Duplicate error lines were sent for failed commands; this
    didn't normally cause visible problems, except when using wildcards in
    usernames or -A parameter to go through multiple users
  - doveadm-server: Logs written by doveadm-server were often missing log
    prefixes, especially mail_log_prefix for mail commands; logs sent to
    doveadm TCP client were also missing log prefixes
  - doveadm: v2.3 regression: batch command always crashes
  - doveadm: v2.3.11 regression: Commands failed if ssl_cert or ssl_key files
    weren't readable by the user running doveadm, even though doveadm didn't
    actually use these settings
  - imap-hibernate: Process may crash at deinit:
    Panic: file ioloop.c: line 928 (io_loop_destroy): assertion failed:
    (ioloop->cur_ctx == NULL)
  - imap: Using imap_fetch_failure=no-after can cause assert-crash with some
    IMAP commands if reading the mail fails (e.g. wrong cached mail size);
    fixes:
    Panic: file index-mail-headers.c: line 198 (index_mail_parse_header_init):
    assertion failed: (!mail->data.header_parser_initialized)
  - imap: v2.3.10 regression: When using INDEXPVT to enable private \Seen flags
    (for shared or public namespaces) the STORE command did not send untagged
    replies for the \Seen flag changes
  - imap: v2.3.15 regression: If PREVIEW/SNIPPET is not the final FETCH option
    in the command, the IMAP FETCH response is broken
  - imap: v2.3.15 regression: MOVE command leaks mailbox if it can't be opened
    and crashes at deinit:
    Panic: file mail-user.c: line 229 (mail_user_deinit): assertion failed:
    ((*user)->refcount == 1)
  - imapc: Copying nonexistent mail via imapc could have crashed. Fixes:
    Panic: file mail-storage.c: line 2385 (mailbox_transaction_commit_get_changes):
    assertion failed: (ret < 0 || seq_range_count(&changes_r->saved_uids) == save_count ||
    array_count(&changes_r->saved_uids) == 0).
  - indexer: v2.3.15 regression: Process crashes if indexer-client disconnects
    while it's waiting for command reply; this happened for example if IMAP
    SEARCH triggered long fts indexing and the IMAP client disconnected
    whilst waiting for the reply
  - indexer: v2.3.15 regression: Process may have crashed in some situations
  - indexer: v2.3.15 regression: indexer-worker processes may not have reached
    the process_limit in some situations, possibly even using just one
    indexer-worker process even though there were many indexing requests queued
  - lib-compression: Reading lz4 compressed mdbox mails may crash; fixes:
    Panic: file istream.c: line 345 (i_stream_read_memarea):
    assertion failed: (!stream->blocking)
  - lib-compression: bench-compress crashes due to xz being read-only
  - lib-lua: Fix linking libdict_lua for non-GNU linkers when Lua support is
    disabled
  - lib-mail: There was no limit on how large an email header name could be;
    processable header names are now limited to 1000 bytes
  - lib-oauth2: Dovecot disallowed JWT tokens if their validity time was older
    than token creation time (nbf < iat)
  - lib-storage: Reduce memory footprint of certain storage operations
  - lib-storage: When listing mailboxes with storage name escape characters
    (^ or .) as part of the mailbox name, the listing could show corrupted
    mailbox names; the corruption can occur when using LAYOUT=INDEX and maildir
    or obox, or when using the listescape plugin
  - mail-crypt: Fix "-O" argument for "doveadm mailbox cryptokey password"
    command to be a boolean, and not expect a string
  - submission-login: Add support for not authenticating to next hop in
    submission proxying
  - submission-login: EHLO was not sent again after XCLIENT when doing
    submission proxying
  - virtual: Mailboxes do not correctly detect underlying mailboxes getting
    re-created even though they have a different UIDVALIDITY or GUID
- Update pigeonhole to 0.5.17
  - duplicate: The Sieve duplicate test is prone to false negatives when the
    user receives many e-mails concurrently, meaning that duplicate deliveries
    can still occur
  - fileinto: v2.3.16 regression: Sieve delivery crashes if mail is delivered
    to non-existing and existing folder
  - imap-filter-sieve: v2.3.15 regression: The CPU limits on Sieve execution
    are too easily exceeded in IMAP context (the IMAPSieve and FILTER=SIEVE
    capabilities); changed the default to unlimited CPU time for IMAP context,
    since similar excessive resource usage can be caused by other means as well
    (the CPU limits on Sieve scripts executed at LDA/LMTP delivery are still
    enforced by default)
  - redirect: The Sieve redirect action has protections against users
    triggering mail loops; unfortunately, the detection of a redirect mail loop
    sometimes causes the message to get lost if no other Sieve action is
    applied that delivers the message somewhere else
  - redirect: v2.3.16 regression: With certain Sieve scripts if redirect fails
    due to temporary failure, the lmtp process may crash after the delivery;
    Fixes: Panic: file mail-user.c: line 229 (mail_user_deinit):
    assertion failed: ((*user)->refcount == 1)

* Wed Sep 29 2021 Paul Howarth <paul@city-fan.org> - 1:2.3.16-4.0.cf
- Fix OpenSSLv3 issues (#2005884)

* Mon Aug  9 2021 Paul Howarth <paul@city-fan.org> - 1:2.3.16-1.0.cf
- Update dovecot to 2.3.16
  - Any unexpected exit() will now result in a core dump; this can especially
    help notice problems when a Lua script causes exit(0)
  - auth-worker process is now restarted when the number of auth requests
    reaches service auth-worker { service_count }; the default is still
    unlimited
  - Event improvements: Added data_stack_grow event and http-client category;
    see https://doc.dovecot.org/admin_manual/list_of_events/
  - oauth2: Support RFC 7628 openid-configuration element, which allows clients
    to support OAUTH2 for any server, not just a few hardcoded servers like
    they do now (see openid_configuration_url setting in
    dovecot-oauth2.conf.ext)
  - mysql: Single statements are no longer enclosed with BEGIN/COMMIT
  - dovecot-sysreport --core supports multiple core files now and does not
    require specifying the binary path
  - imapc: When imap_acl plugin is loaded and imapc_features=acl is used,
    IMAP ACL commands are proxied to the remote server; see
    https://doc.dovecot.org/configuration_manual/mail_location/imapc/
  - dict-sql now supports the "UPSERT" syntax for SQLite and PostgreSQL
  - imap: If IMAP client disconnects during a COPY command, the copying is
    aborted, and changes are reverted; this may help to avoid many email
    duplicates if client disconnects during COPY and retries it after
    reconnecting
  - master process was using 100%% CPU if service attempted to create more
    processes due to process_min_avail, but process_limit was already reached
    (v2.3.15 regression)
  - Using attachment detection flags wrongly logged unnecessary "Failed to add
    attachment keywords" errors (v2.3.13 regression)
  - IMAP QRESYNC: Expunging UID 1 mail resulted in broken VANISHED response,
    which could have confused IMAP clients (v2.3.13 regression)
  - imap: STORE didn't send untagged replies for \Seen changes for (shared)
    mailboxes using INDEXPVT (v2.3.10 regression)
  - rawlog_dir setting would not log input that was pipelined after
    authentication command
  - Fixed potential infinite looping with autoexpunging
  - Log event exporter: Truncate long fields to 1000 bytes
  - LAYOUT=index: ACL inheritance didn't work when creating mailboxes
  - Event filters: Unquoted '?' wildcard caused a crash at startup
  - fs-metawrap: Fix to handling zero sized files
  - imap-hibernate: Fixed potential crash at de-init
  - acl: dovecot-acl-list files were written for acl_ignore_namespaces
  - program-client (used by Sieve extprograms, director_flush_socket) may have
    missed status response from UNIX and network sockets, resulting in
    unexpected failures
- Update pigeonhole to 0.5.16
  - .dovecot.sieve.log file now includes year in the header
  - Change Sieve script result execution to delay definitive action execution
    to the end of a successful Sieve script execution session, which is part of
    an effort to solve problems with the Sieve duplicate test; as a
    side-effect, some rare temporary-error cases yield different results, in
    which partial failure is more likely

* Thu Jul 22 2021 Paul Howarth <paul@city-fan.org> - 1:2.3.15-2.0.cf
- Rebuilt for https://fedoraproject.org/wiki/Fedora_35_Mass_Rebuild

* Tue Jun 22 2021 Paul Howarth <paul@city-fan.org> - 1:2.3.15-1.0.cf
- Update dovecot to 2.3.15
  - CVE-2021-29157: Dovecot does not correctly escape kid and azp fields in JWT
    tokens, which may be used to supply attacker controlled keys to validate
    tokens, if attacker has local access
  - CVE-2021-33515: On-path attacker could have injected plaintext commands
    before STARTTLS negotiation that would be executed after STARTTLS finished
    with the client
  - Disconnection log messages are now more standardized across services; they
    also always now start with "Disconnected" prefix
  - Dovecot now depends on libsystemd for systemd integration
  - Removed support for Lua 5.2; use version 5.1 or 5.3 instead
  - config: Some settings are now marked as "hidden" and it's discouraged to
    change these settings; they will no longer be visible in doveconf output,
    except if they have been changed or if the doveconf -s parameter is used
    (see https://doc.dovecot.org/settings/advanced/ for details)
  - imap-compress: Compression level is now algorithm specific
    (see https://doc.dovecot.org/settings/plugin/compress-plugin/)
  - indexer-worker: Convert "Indexed" info logs to an event named
    "indexer_worker_indexing_finished" (see
    https://doc.dovecot.org/admin_manual/list_of_events/#indexer-worker-indexing-finished)
  - Add TSLv1.3 support to min_protocols
  - Allow configuring ssl_cipher_suites (for TLSv1.3+)
  - acl: Add acl_ignore_namespace setting, which allows to entirely ignore ACLs
    for the listed namespaces
  - imap: Support official RFC8970 preview/snippet syntax; old methods of
    retrieving preview information via IMAP commands ("SNIPPET and PREVIEW with
    explicit algorithm selection") have been deprecated
  - imapc: Support INDEXPVT for imapc storage to enable private message flags
    for cluster wide shared mailboxes
  - lib-storage: Add new events: mail_opened, mail_expunge_requested,
    mail_expunged, mail_cache_lookup_finished
    (see https://doc.dovecot.org/admin_manual/list_of_events/#mail)
  - zlib, imap-compression, fs-compress: Support compression levels that the
    algorithm supports
    - Before, we would allow hardcoded value between 1 and 9 and would default
      to 6
    - Now, we allow using per-algorithm value range and default to whatever
      default the algorithm specifies
  - *-login: Commands pipelined together with and just after the authenticate
    command cause these commands to be executed twice; this applies to all
    protocols that involve user login, which currently comprises of imap, pop3,
    submission and managesieve
  - *-login: Processes are supposed to disconnect the oldest non-logged in
    connection when process_limit was reached; this didn't actually happen with
    the default "high-security mode" (with service_count=1) where each
    connection is handled by a separate process
  - *-login: When login process reaches client/process limits, oldest client
    connections are disconnected; if one of these was still doing anvil lookup,
    this caused a crash, though it could happen only if the login process
    limits were very low or if the server was overloaded
  - Fixed building with link time optimizations (-flto)
  - auth: Userdb iteration with passwd driver does not always return all
    users with some nss drivers
  - dsync: Shared INBOX not synced when "mail_shared_explicit_inbox" was
    disabled; if a user has a shared mailbox which is another user's INBOX,
    dsync didn't include the mailbox in syncing unless explicit naming was
    enabled with "mail_shared_explicit_inbox" set to "yes"
  - dsync: Shared namespaces were not synced with "-n" flag
  - dsync: Syncing shared INBOX failed if mail_attribute_dict was not set; if a
    user has a shared mailbox that is another user's INBOX, dsync failed to
    export the mailbox if mail attributes are disabled
  - fts-solr, fts-tika: Using both Solr FTS and Tika may have caused HTTP
    requests to assert-crash: Panic: file http-client-request.c: line 1232
    (http_client_request_send_more): assertion failed: (req->payload_input != NULL)
  - fts-tika: 5xx errors returned by Tika server as indexing failures; however,
    Tika can return 5xx for some attachments every time, so the 5xx error
    should be retried once, but treated as success if it happens on the retry
    as well (v2.3 regression)
  - fts-tika: v2.3.11 regression: Indexing messages with fts-tika may have
    resulted in Panic: file message-parser.c: line 802 (message_parser_deinit_from_parts):
    assertion failed: (ctx->nested_parts_count == 0 || i_stream_have_bytes_left(ctx->input))
  - imap: SETMETADATA could not be used to unset metadata values; instead, NIL
    was handled as a "NIL" string (v2.3.14 regression)
  - imap: IMAP BINARY FETCH crashes at least on empty base64 body:
    Panic: file index-mail-binary.c: line 358 (blocks_count_lines):
    assertion failed: (block_count == 0 || block_idx+1 == block_count)
  - imap: If IMAP client using the NOTIFY command was disconnected while
    sending FETCH notifications to the client, imap could crash with
    Panic: Trying to close mailbox INBOX with open transactions
  - imap: Using IMAP COMPRESS extension can cause IMAP connection to hang when
    IMAP commands are >8 kB long
  - imapc: If remote server sent BYE but didn't immediately disconnect, it
    could cause infinite busy-loop
  - lib-index: Corrupted cache record size in dovecot.index.cache file could
    have caused a crash (segfault) when accessing it
  - lib-oauth2: JWT token time validation now works correctly with 32-bit
    systems
  - lib-ssl-iostream: Checking hostnames against an SSL certificate was
    case-sensitive
  - lib-storage: Corrupted mime.parts in dovecot.index.cache may have resulted
    in Panic: file imap-bodystructure.c: line 206 (part_write_body):
    assertion failed: (text == ((part->flags & MESSAGE_PART_FLAG_TEXT) != 0))
  - lib-storage: Index rebuilding (e.g. via doveadm force-resync) didn't
    preserve the "hdr-pop3-uidl" header; because of this, the next pop3 session
    could have accessed all of the emails' metadata to read their POP3 UIDL
    (opening dbox files)
  - listescape: When using the listescape plugin and a shared namespace, the
    plugin didn't work properly anymore, resulting in errors like:
    "Invalid mailbox name: Name must not have '/' character"
  - lmtp: Connection crashes if connection gets disconnected due to multiple
    bad commands and the last bad command is BDAT
  - lmtp: The Dovecot-specific LMTP parameter XRCPTFORWARD was blindly
    forwarded by LMTP proxy without checking that the backend has support; this
    caused a command parameter error from the backend if it was running an
    older Dovecot release (this could only occur in more complex setups where
    the message was proxied twice; when the proxy generated the XRCPTFORWARD
    parameter itself the problem did not occur, so this only happened when it
    was forwarded)
  - lmtp: The LMTP proxy crashes with a panic when the remote server replies
    with an error while the mail is still being forwarded through a DATA/BDAT
    command
  - lmtp: Username may have been missing from lmtp log line prefixes when it
    was performing autoexpunging
  - master: Dovecot would incorrectly fail with haproxy 2.0.14 service checks
  - master: Systemd service: Dovecot announces readiness for accepting
    connections earlier than it should; the following environment variables are
    now imported automatically and can be omitted from import_environment
    setting: NOTIFY_SOCKET LISTEN_FDS LISTEN_PID
  - master: service { process_min_avail } was launching processes too slowly
    when master was forking a lot of processes
  - util: Make the health-check.sh example script POSIX shell compatible
- Update pigeonhole to 0.5.15
  - CVE-2020-28200: Sieve interpreter is not protected against abusive scripts
    that claim excessive resource usage: fixed by limiting the user CPU time
    per single script execution and cumulatively over several script runs
    within a configurable timeout period; sufficiently large CPU time usage
    is summed in the Sieve script binary and execution is blocked when the sum
    exceeds the limit within that time, and the block is lifted when the script
    is updated after the resource usage times out
  - Disconnection log messages are now more standardized across services; they
    also always now start with "Disconnected" prefix
  - managesieve: Commands pipelined together with and just after the
    authenticate command cause these commands to be executed twice
- Note that the systemd unit start-up is changed to Type=Notify except on old
  distributions such as EL-7

* Thu May 20 2021 Paul Howarth <paul@city-fan.org> - 1:2.3.14-4.0.cf
- Rebuild for ICU 69

* Wed May 12 2021 Paul Howarth <paul@city-fan.org> - 1:2.3.14-2.0.cf
- Re-enable LTO for Fedora 34 onwards
- Use OpenSSL's implementation of HMAC for Fedora 32 onwards
- Add ICU and zstd support
- Use libpq-devel instead of postgresql-devel from Fedora 29 onwards

* Thu Mar  4 2021 Paul Howarth <paul@city-fan.org> - 1:2.3.14-1.0.cf
- Update dovecot to 2.3.14
  - Added new aliases for some variables; usage of the old ones is possible,
    but discouraged (these were partially added already to v2.3.13)
    See https://doc.dovecot.org/configuration_manual/config_file/config_variables/
    for more information
  - Optimize imap/pop3/submission/managesieve proxies to use less CPU at the
    cost of extra memory usage
  - Remove autocreate, expire, snarf and mail-filter plugins
  - Remove cydir storage driver
  - Remove XZ/LZMA write support; read support will be removed in a future
    release
  - doveadm -D: add timestamps to debug output even when LOG_STDERR_TIMESTAMP
    environment variable is not set (timestamp format is taken from
    log_timestamp setting)
  - If BROKENCHAR or listescape plugin is used, the escaped folder names may
    be slightly different from before in some situations; this is unlikely to
    cause issues, although caching clients may redownload the folders
  - imapc: it now enables BROKENCHAR=~ by default to escape remote folder names
    if necessary; this also means that if there are any '~' characters in the
    remote folder names, they will be visible as "~7e"
  - imapc: when using local index files, folder names were escaped on the
    filesystem a bit differently (this has effect only if there are folder
    names that actually require escaping, which isn't so common); the old
    style folders will automatically be deleted from the filesystem
  - stats: update exported metrics to be compliant with OpenMetrics standard
  - doveadm: add an optional '-p' parameter to metadata list command; if
    enabled, "/private", and "/shared" metadata prefixes will be prepended to
    the keys in the list output
  - doveconf: support environment variables in config files; see
    https://doc.dovecot.org/configuration_manual/config_file/config_file_syntax/#environment-variables
    for more details
  - indexer-worker: change indexer to disconnect from indexer-worker after
    each request, which allows service indexer-worker's service_count and
    idle_kill settings to work; these can be used to restart indexer-worker
    processes once in a while to reduce their memory usage
  - auth: "nodelay" with various authentication mechanisms such as apop and
    digest-md5 crashed AUTH process if authentication failed
  - auth: auth lua script generating an error triggered an assertion failure:
    Panic: file db-lua.c: line 630 (auth_lua_call_password_verify):
    assertion failed: (lua_gettop(script->L) == 0).
  - configure: fix libunwind detection to work on other than x86_64 systems
  - doveadm-server: process could crash if logging was done outside command
    handling; for example http-client could have done debug logging afterwards,
    resulting in either segfault or Panic: file http-client.c: line 642
    (http_client_context_close): assertion failed: (cctx->clients_list == NULL)
  - dsync: folder name escaping with BROKENCHAR didn't work completely
    correctly, which particularly caused problems with dsync-migrations using
    imapc where some of the remote folder names may not have been accessible
  - dsync: doveadm sync + imapc doesn't always sync all mails when doing an
    incremental sync (-1), which could lead to mail loss when used for
    migration; this happens only when GUIDs aren't used (i.e. imapc without
    imapc_features=guid-forced)
  - fts-tika: when tika server returns error, some mails cause Panic: file
    message-parser.c: line 802 (message_parser_deinit_from_parts): assertion
    failed: (ctx->nested_parts_count == 0 || i_stream_have_bytes_left(ctx->input))
  - lib-imap: imapc parsing illegal BODYSTRUCTUREs with NILs could have
    resulted in crashes, which exposed that Dovecot was wrongly accepting atoms
    in "nstring" handling; changed the IMAP parsing to be more strict about
    this now
  - lib-index: if dovecot.index.cache has corrupted message size, fetching
    BODY/BODYSTRUCTURE may cause assert-crash: Panic: file index-mail.c: line
    1140 (index_mail_parse_body_finish): assertion failed:
    (mail->data.parts != NULL)
  - lib-index: minor error handling and race condition fixes related to
    rotating dovecot.index.log; these didn't usually cause problems, unless
    the log files were rotated rapidly
  - lib-lua: Lua scripts using coroutines or lua libraries using coroutines
    (e.g., cqueues) panicked
  - Message PREVIEW handled whitespace wrong so first space would get eaten
    from between words
  - FTS and message PREVIEW (snippet) parsed HTML &entities case-sensitively
  - lib-mail: when max nested MIME parts were reached, IMAP BODYSTRUCTURE was
    written in a way that may have caused confusion for IMAP clients and also
    Dovecot itself when parsing it; the truncated part is now written out using
    application/octet-stream MIME type
  - lib-oauth2: HS512 and HS384 JWT token algorithms crash when you try to use
    them: Panic: file hmac.c: line 26 (hmac_init): assertion failed:
    (meth->context_size <= MAC_MAX_CONTEXT_SIZE)
  - event filters: NOT keyword did not have the correct associativity:
    NOT a AND b were getting parsed as NOT (a AND b) instead of (NOT a) AND b
  - Ignore ECONNRESET when closing socket; this avoids logging useless errors
    on systems like FreeBSD
  - event filters: event filter syntax error may lead to Panic: file
    event-filter.c: line 137 (event_filter_parse): assertion failed:
    (state.output == NULL)
  - lib: timeval_cmp_margin() was broken on 32-bit systems, which could
    potentially have caused HTTP timeouts to be handled incorrectly
  - log: instance_name wasn't used as syslog ident by the log process
  - master: after a service reached process_limit and client_limit, it could
    have taken up to 1 second to realize that more client connections became
    available, during which time client connections could have been rejected
    unnecessarily and a warning logged: Warning: service(...): process_limit
    (...) reached, client connections are being dropped
  - stats: crash would occur when generating openmetrics data for metrics using
    aggregating functions
  - stats: event filters comparing against empty strings crash the stats
    process
- Update pigeonhole to 0.5.14
  - IMAP FILTER command: cmd-filter-sieve - do not allow NIL as script name
    argument
- Set DOVECOT_HOSTDOMAIN in %%check as workaround for segfault in
  gethostbyname() on Fedora 23 builds

* Wed Feb 10 2021 Paul Howarth <paul@city-fan.org> - 1:2.3.13-7.0.cf
- Rebuild for libpq ABI fix (#1908268)

* Mon Feb  1 2021 Paul Howarth <paul@city-fan.org> - 1:2.3.13-6.0.cf
- Use %%{make_build} and %%{make_install}

* Thu Jan 28 2021 Paul Howarth <paul@city-fan.org> - 1:2.3.13-5.0.cf
- Rebuilt for https://fedoraproject.org/wiki/Fedora_34_Mass_Rebuild

* Wed Jan 20 2021 Paul Howarth <paul@city-fan.org> - 1:2.3.13-4.0.cf
- Fix multilib issues (Fedora 22 onwards)

* Sun Jan 10 2021 Paul Howarth <paul@city-fan.org> - 1:2.3.13-2.0.cf
- Drop ssl_dh patch

* Mon Jan  4 2021 Paul Howarth <paul@city-fan.org> - 1:2.3.13-1.0.cf
- Update dovecot to 2.3.13
  - CVE-2020-24386: Specially crafted command can cause IMAP hibernate to
    allow logged in user to access other people's emails and filesystem
    information
  - Metric filter and global event filter variable syntax changed to a
    SQL-like format
    (see https://doc.dovecot.org/configuration_manual/event_filter/)
  - auth: Added new aliases for %%{variables}; usage of the old ones is
    possible, but discouraged
  - auth: Removed RPA auth mechanism, SKEY auth mechanism, NTLM auth mechanism
    and related password schemes
  - auth: Removed passdb-sia, passdb-vpopmail and userdb-vpopmail
  - auth: Removed postfix postmap socket
  - auth: Added new fields for auth server events; these fields are also now
    available for all auth events - see
    https://doc.dovecot.org/admin_manual/list_of_events/#authentication-server
    for details
  - imap-hibernate: Added imap_client_hibernated, imap_client_unhibernated
    and imap_client_unhibernate_retried events - see
    https://doc.dovecot.org/admin_manual/list_of_events/ for details
  - lib-index: Added new mail_index_recreated event - see
    https://doc.dovecot.org/admin_manual/list_of_events/#mail-index-recreated
  - lib-sql: Support TLS options for cassandra driver; this requires cpp-driver
    v2.15 (or later) to work reliably
  - lib-storage: Missing $HasAttachment / $HasNoAttachment flags are now added
    to existing mails if mail_attachment_detection_option=add-flags and it can
    be done inexpensively
  - login proxy: Added login_proxy_max_reconnects setting (default 3) to
    control how many reconnections are attempted
  - login proxy: imap/pop3/submission/managesieve proxying now supports
    reconnection retrying on more than just connect() failure; any error except
    a non-temporary authentication failure will result in reconnect attempts
  - auth: Lua passdb/userdb leaks stack elements per call, eventually causing
    the stack to become too deep and crashing the auth or auth-worker process
  - auth: SASL authentication PLAIN mechanism could be used to trigger read
    buffer overflow; however, this doesn't seem to be exploitable in any way
  - auth: v2.3.11 regression: GSSAPI authentication fails because dovecot
    disallows NUL bytes for it
  - dict: Process used too much CPU when iterating keys, because each key used
    a separate write() syscall
  - doveadm-server: Crash could occur if logging was done outside command
    handling, e.g. http-client could have done debug logging afterwards,
    resulting in either segfault or Panic: file http-client.c: line 642
    (http_client_context_close): assertion failed: (cctx->clients_list == NULL)
  - doveadm-server: v2.3.11 regression: Trying to connect to doveadm server
    process via starttls assert-crashed if there were no ssl=yes listeners:
    Panic: file master-service-ssl.c: line 22 (master_service_ssl_init):
    assertion failed: (service->ssl_ctx_initialized)
  - fts-solr: HTTP requests may have assert-crashed:
    Panic: file http-client-request.c: line 1232 (http_client_request_send_more):
    assertion failed: (req->payload_input != NULL)
  - imap: IMAP NOTIFY could crash with a segmentation fault due to a bad
    configuration that causes errors; sending the error responses to the client
    can cause the segmentation fault, which can for example happen when several
    namespaces use the same mail storage location
  - imap: IMAP NOTIFY used on a shared namespace that doesn't actually exist
    (e.g. public namespace for a nonexistent user) can crash with a panic:
    Panic: Leaked view for index /tmp/home/asdf/mdbox/dovecot.list.index:
    Opened in (null):0
  - imap: IMAP session can crash with QRESYNC extension if many changes are
    done before asking for expunged mails since last sync
  - imap: Process might hang indefinitely if client disconnects after sending
    some long-running commands pipelined, for example FETCH+LOGOUT
  - lib-compress: Mitigate crashes when configuring a not compiled in
    compression; errors with compression configuration now distinguish between
    not supported and unknown
  - lib-compression: Using xz/lzma compression in v2.3.11 could have written
    truncated output in some situations; this would result in "Broken pipe"
    read errors when trying to read it back
  - lib-compression: zstd compression could have crashed in some situations:
    Panic: file ostream.c: line 287 (o_stream_sendv_int): assertion failed:
    (!stream->blocking)
  - lib-dict: dict client could have crashed in some rare situations when
    iterating keys
  - lib-http: Fix several assert-crashes in HTTP client
  - lib-index: v2.3.11 regression: When mails were expunged at the same time as
    lots of new content was being saved to the cache (e.g. cache file was lost
    and is being re-filled) a deadlock could occur with dovecot.index.cache /
    dovecot.index.log
  - lib-index: v2.3.11 regression: dovecot.index.cache file was being purged
    (rewritten) too often when it had a field that hadn't been accessed for
    over 1 month, but less than 2 months; every cache file change caused a
    purging in this situation
  - lib-mail: MIME parts were not returned correctly by Dovecot MIME parser;
    regression caused by fixing CVE-2020-12100
  - lib-mail: When max nested MIME parts were reached, IMAP BODYSTRUCTURE was
    written in a way that may have caused confusion for both IMAP clients and
    Dovecot itself when parsing it; the truncated part is now written out using
    application/octet-stream MIME type
  - lib-mail: v2.3.11 regression: Mail delivery / parsing crashed when the
    10000th MIME part was message/rfc822 (or if parent was multipart/digest):
    Panic: file message-parser.c: line 167 (message_part_append):
    assertion failed: (ctx->total_parts_count <= ctx->max_total_mime_parts)
  - lib-oauth2: Dovecot incorrectly required oauth2 server introspection reply
    to contain username with invalid token
  - lib-ssl-iostream, lib-dcrypt: Fix building with OpenSSL that has deprecated
    APIs disabled
  - lib-storage: When mail's size is different from the cached one (in
    dovecot.index.cache or Maildir S=size in the filename), this is handled by
    logging "Cached message size smaller/larger than expected" error; however,
    in some situations this also ended up crashing with:
    Panic: file istream.c: line 315 (i_stream_read_memarea):
    assertion failed: (old_size <= _stream->pos - _stream->skip)
  - lib-storage: v2.3 regression: Copying/moving mails was taking much more
    memory than before; this was mainly visible when copying/moving thousands
    of mails in a single transaction
  - lib-storage: v2.3.11 regression: Searching messages assert-crashed
    (without FTS): Panic: file message-parser.c: line 174 (message_part_finish):
    assertion failed: (ctx->nested_parts_count > 0)
  - lib: Dovecot v2.3 moved signal handlers around in ioloops, causing more CPU
    usage than in v2.2
  - lib: Fixed JSON parsing: '\' escape sequence may have wrongly resulted in
    error if it happened to be at read boundary; any NUL characters and
    '\u0000' will now result in parsing error instead of silently truncating
    the data
  - lmtp, submission: Server may hang if SSL client connection disconnects
    during the delivery; if this happened repeatedly, it could have ended up
    reaching process_limit and preventing any further lmtp/submission deliveries
  - lmtp: Proxy does not always properly log TLS connection problems as errors;
    in some cases, only a debug message is logged if enabled
  - lmtp: The LMTP service can hang when commands are pipelined, which can in
    particular occur when one command in the middle of the pipeline fails; one
    example of this occurs for proxied LMTP transactions in which the final
    DATA or BDAT command is pipelined after a failing RCPT command
  - login-proxy: The login_source_ips setting has no effect, and therefore the
    proxy source IPs are not cycled through as they should be
  - master: Process was using 100%% CPU in some situations when a broken
    service was being throttled
  - pop3-login: POP3 login would fail with "Input buffer full" if the initial
    response for SASL was too long
  - stats: Crash would occur when generating openmetrics data for metrics
    using aggregating functions
- Update pigeonhole to 0.5.13
  - duplicate: The test was handled badly in a multiscript (sieve_before,
    sieve_after) scenario in which an earlier script in the sequence with a
    duplicate test succeeded, while a later script caused a runtime failure; in
    that case, the message is recorded for duplicate tracking while the message
    may not actually have been delivered in the end
  - editheader: Sieve interpreter entered infinite loop at startup when the
    "editheader" configuration listed an invalid header name; this problem can
    only be triggered by the administrator
  - relational: The Sieve relational extension can cause a segfault at compile
    time, triggered by invalid script syntax; the segfault happens when this
    match type is the last argument of the test command amd is not possible in
    a valid script; positional arguments are normally present after that, which
    would prevent the segfault
  - sieve: For some Sieve commands the provided mailbox name is not properly
    checked for UTF-8 validity, which can cause assert crashes at runtime when
    an invalid mailbox name is encountered; this can be caused by the user
    writing a bad Sieve script involving the affected commands
    ("mailboxexists", "specialuse_exists"), or by the remote sender only when
    the user has written a Sieve script that passes message content to one of
    the affected commands
  - sieve: Large sequences of 8-bit octets passed to certain Sieve commands
    that create or modify message headers that allow UTF-8 text (vacation,
    notify and addheader) can cause the delivery or IMAP process (when
    IMAPSieve is used) to enter a memory-consuming semi-infinite loop that
    ends when the process exceeds its memory limits; logged in users can cause
    these hangs only for their own processes
- Use bigger default key size (#1882939)
- Use /run for local state directory (#1777922)
- Use %%license unconditionally
- Fix time margin calculations on 32-bit systems
  (https://github.com/dovecot/core/pull/149)

* Fri Sep  4 2020 Paul Howarth <paul@city-fan.org> - 1:2.3.11.3-5.0.cf
- Fix GSSAPI issue

* Thu Aug 27 2020 Paul Howarth <paul@city-fan.org> - 1:2.3.11.3-4.0.cf
- Sync with Rawhide build

* Thu Aug 13 2020 Paul Howarth <paul@city-fan.org> - 1:2.3.11.3-1.0.cf
- Update dovecot to 2.3.11.3
  - CVE-2020-12100: Parsing mails with a large number of MIME parts could have
    resulted in excessive CPU usage or a crash due to running out of stack
    memory
  - CVE-2020-12673: Dovecot's NTLM implementation did not correctly check
    message buffer size, which lead to reading past allocation, which could
    lead to crash
  - CVE-2020-10967: lmtp/submission: Issuing the RCPT command with an address
    that has the empty quoted string as local-part caused the lmtp service to
    crash
  - CVE-2020-12674: Dovecot's RPA mechanism implementation accepted zero-length
    messages, which lead to assert-crashes later on
  - Events: Fix inconsistency in events (see event documentation at
    https://doc.dovecot.org/)
  - imap_command_finished event's cmd_name field now contains "unknown" for
    unknown commands; a new "cmd_input_name" field contains the command name
    exactly as it was sent
  - lib-index: Renamed mail_cache_compress_* settings to mail_cache_purge_*;
    note that these settings are mainly intended for testing and usually
    shouldn't be changed
  - events: Renamed "index" event category to "mail-index"
  - events: service:<name> category is now using the name from configuration
    file
  - dns-client: service dns_client was renamed to dns-client
  - log: Prefixes generally use the service name from configuration file; for
    example, dict-async service will now use "dict-async(pid): " log prefix
   instead of "dict(pid): "
  - *-login: Changed logging done by proxying to use a consistent prefix
    containing the IP address and port
  - *-login: Changed disconnection log messages to be slightly clearer
  - dict: Add events for dictionaries
  - lib-index: Finish logging with events
  - oauth2: Support local validation of JWT tokens
  - stats: Add support for dynamic histograms and grouping (see
    https://doc.dovecot.org/configuration_manual/stats/)
  - imap: Implement RFC 8514: IMAP SAVEDATE
  - lib-index: If a long-running transaction (e.g. SORT/FETCH on a huge folder)
    adds a lot of data to dovecot.index.cache file, commit those changes
    periodically to make them visible to other concurrent sessions as well
  - stats: Add OpenMetrics exporter for statistics (see
    https://doc.dovecot.org/configuration_manual/stats/openmetrics/)
  - stats: Support disabling stats-writer socket by setting
    stats_writer_socket_path=""
  - auth-worker: Process keeps slowly increasing its memory usage and
    eventually dies with "out of memory" due to reaching vsz_limit
  - auth: Prevent potential timing attacks in authentication secret
    comparisons: OAUTH2 JWT-token HMAC, imap-urlauth token, crypt() result
  - auth: Several auth-mechanisms allowed input to be truncated by NUL, which
    can potentially lead to unintentional issues or even successful logins
    that should have failed
  - auth: When auth policy returned a delay, auth_request_finished event had
    policy_result=ok field instead of policy_result=delayed
  - auth: auth process crash when auth_policy_server_url is set to an invalid
    URL
  - dict-ldap: Crash occurs if var_expand template expansion fails
  - dict: If dict client disconnected while iteration was still running, dict
    process could have started using 100% CPU, although it was still handling
    clients
  - doveadm: Running doveadm commands via proxying may hang, especially when
    doveadm is printing a lot of output
  - imap: "MOVE * destfolder" goes to a loop copying the last mail to the
    destination until the imap process dies due to running out of memory
  - imap: Running "UID MOVE 1:* Trash" on an empty folder goes to infinite loop
  - imap: SEARCH doesn't support $
  - lib-compress: Buffer over-read in zlib stream read
  - lib-dns: If DNS lookup times out, lib-dns can cause crash in calling
    process
  - lib-index: Fixed several bugs in dovecot.index.cache handling that could
    have caused cached data to be lost
  - lib-index: Writing to ≥1 GB dovecot.index.cache files may cause
    assert-crashes
  - lib-ssl-iostream: Fix buggy OpenSSL error handling without assert-crashing;
    if there is no error available, log it as an error instead of crashing
  - lib-ssl-iostream: ssl_key_password setting did not work
  - submission: A segfault crash may occur when the client or server
    disconnects while a non-transaction command like NOOP or VRFY is still
    being processed
  - virtual: Copying/moving mails with IMAP into a virtual folder assert-crashes
  - auth: Lua passdb/userdb leaks stack elements per call, eventually causing
    the stack to become too deep and crashing the auth or auth-worker process
  - lib-mail: v2.3.11 regression: MIME parts not returned correctly by Dovecot
    MIME parser
  - pop3-login: Login would fail with "Input buffer full" if the initial
    response for SASL was too long
  - pop3-login: Login didn't handle commands in multiple IP packets properly;
    this mainly affected large XCLIENT commands or a large SASL initial
    response parameter in the AUTH command
  - pop3: pop3_deleted_flag setting was broken, causing assert-crash
- Update pigeonhole to 0.5.11
  - managesieve: managesieve_max_line_length setting is now a "size" type
    instead of just number of bytes; this allows using e.g. "64k" as the value
  - lib-sieve: When folding white space is used in the Message-ID header, it is
    not stripped away correctly before the message ID value is used, causing
    e.g. garbled log lines at delivery
- Add patch to fix test failures on 32-bit systems

* Wed Jul 29 2020 Paul Howarth <paul@city-fan.org> - 1:2.3.10.1-2.0.cf
- Work around build failure with link-time optimization in Fedora 33 onwards

* Tue May 19 2020 Paul Howarth <paul@city-fan.org> - 1:2.3.10.1-1.0.cf
- Update dovecot to 2.3.10.1
  - CVE-2020-10957: lmtp/submission: A client can crash the server by sending a
    NOOP command with an invalid string parameter
    - This occurs particularly for a parameter that doesn't start with a double
      quote
    - This applies to all SMTP services, including submission-login, which
      makes it possible to crash the submission service without authentication
  - CVE-2020-10958: lmtp/submission: Sending many invalid or unknown commands
    can cause the server to access freed memory, which can lead to a server
    crash
    - This happens when the server closes the connection with a "421 Too many
      invalid commands" error; the bad command limit depends on the service
      (lmtp or submission) and varies between 10 to 20 bad commands
  - CVE-2020-10967: lmtp/submission: Issuing the RCPT command with an address
    that has the empty quoted string as local-part causes the lmtp service to
    crash

* Mon Mar  9 2020 Paul Howarth <paul@city-fan.org> - 1:2.3.10-1.0.cf
- Update dovecot to 2.3.10
  - Disable retpoline mitigations by default, as they can cause severe
    performance regressions and so they should be only enabled when applicable
  - IMAP MOVE now commits transactions in batches of 1000 mails, which helps
    especially with lazy_expunge when moving a lot of mails, mainly avoiding
    situations where multiple IMAP sessions are running the same MOVE command
    and duplicating the mails in the lazy_expunge folder; with this change
    there can still be some duplication but the MOVE always progresses forward;
    also if the MOVE fails at some point, the changes up to the last 1000 mails
    are still committed instead of rolled back (note that the COPY command
    behaviour hasn't changed, because it is required by IMAP standard to be an
    atomic operation)
  - IMAP EXPUNGE and CLOSE now expunges mails in batches of 1000 mails, which
    helps especially with lazy_expunge when expunging a lot of mails (e.g.
    millions) to make sure that the progress always moves forward even if the
    process is killed
  - Autoexpunging now expunges mails in batches of 1000 mails, which helps
    especially with lazy_expunge when expunging a lot of mails (e.g. millions)
    to make sure that the progress always moves forward even if the process is
    killed
  - Add tool for generating sysreport, called dovecot-sysreport; this generates
    a bundle of information usually needed for support requests
  - Add support for the new IMAP \Important SPECIAL-USE flag (RFC 8457)
  - Add metric { group_by } setting, which allows automatically creating new
    metrics based on the fields you want to group statistics by (NOTE: this
    feature is considered experimental and syntax is subject to change in
    future releases)
  - auth: Support SCRAM-SHA-256 authentication mechanism
  - imap: Support the new IMAP STATUS=SIZE extension
  - Use TCP_QUICKACK to reduce latency for some TCP connections
  - quota-status: Made the service more robust against erroneous use with
    Postfix ACL policies other than smtpd_recipient_restrictions
  - Add "revision" field support to imap_id_send setting; using "revision *"
    will send in IMAP ID command response the short commit hash of the Dovecot
    git source tree HEAD (same as in dovecot --version)
  - IMAP ENVELOPE now includes all addresses when there are multiple headers
    (From, To, Cc, etc.); the standard way of having multiple addresses is just
    to list them all in a single header - it's non-standard to have multiple
    headers - however, since MTAs allow these mails to pass through and
    different software may handle them in different ways, it's better from a
    security point of view to show all the addresses
  - Event filters now support using "field_name=" to match a field that doesn't
    exist or has an empty value, for example use "error=" to match only events
    that didn't fail
  - acl: INBOX ACLs shouldn't apply for IMAP GETMETADATA/SETMETADATA commands
  - cassandra: CASS_ERROR_SERVER_WRITE_FAILURE error should also be treated as
    "uncertain write failure"
  - dict-redis: Using quota_clone configured with dict-redis could have crashed
    when Redis responded slowly
  - imap-hibernate: Communication trouble with imap-master lead to segfault
  - imap-hibernate: Unhibernation retrying wasn't working
  - imap: Fixed auth lookup privilege problem when imap process was reused and
    user was being un-hibernated
  - Fix potential crash when copying/moving mails within the same folder; this
    happened only when there were a lot of fields in dovecot.index.cache
  - lib-index: Recreating dovecot.index.cache file could have crashed when
    merging bitmask fields
  - lib-index: Using public/shared folders with INDEXPVT configured to use
    private \Seen flags, trying to search seen/unseen in an empty folder
    crashed with segfault
  - lib-mail: Large base64-encoded mails weren't decoded properly; this could
    have affected searching/indexing mails and message snippet generation
  - lib-mail: Message with only quoted text could have caused message snippet
    to ignore its 200 character limit and return the entire message; this was
    also added to dovecot.index.cache file, which increased disk space and
    memory usage unnecessarily (v2.3.9.2 regression; previous versions cached
    the quoted snippet as empty); in a large mail, quoted text could have
    incorrectly become added to the snippet, possibly mixed together with
    non-quoted text
  - lib-smtp: client could have assert-crashed if STARTTLS handshake finished
    earlier than usual
  - lib-ssl-iostream: remove -static flag for lib-ssl-iostream linking to
    prevent a compile issue
  - lib-storage: Mailbox synchronization may have assert-crashed in some rare
    situations
  - lib-storage: mdbox didn't preserve date.saved with dsync
  - lib: Don't require EAI_{ADDRFAMILY,NODATA}, breaks FreeBSD
  - master: Some services could respawn unthrottled if they crash during
    start-up
  - push-notification: Do not send push_notification_finished event if
    nothing was done; this happens when mail transaction is started and ended
    with no changes
  - quota-status: Addresses with special characters in the local part caused
    problems in the interaction between Postfix and Dovecot; Postfix sent its
    own internal representation in the recipient field, while Dovecot expected
    a valid RFC5321 mailbox address
  - submission-login: SESSION was not correctly encoded field for the XCLIENT
    command; in particular, a '+' character introduced by the session ID's
    Base64 encoding caused problems
  - submission: Fix submission_max_mail_size to work correctly on 32-bit
    systems
  - submission: Trusted connections crashed in second connection's EHLO if
    submission-login { service_count } is something other than 1 (which is the
    default)
  - submission: XCLIENT command was never used in the protocol exchange with
    the relay MTA when submission_backend_capabilities is configured, even when
    the relay MTA was properly configured to accept the XCLIENT command
- Update pigeonhole to 0.5.10
  - imap_sieve_filter: Change result action logging to include IMAP UID
  - vacation: Addresses were compared case-sensitively

* Thu Feb 13 2020 Paul Howarth <paul@city-fan.org> - 1:2.3.9.3-1.0.cf
- Update dovecot to 2.3.9.3
  - Truncated UTF-8 could be used to DoS submission-login and lmtp processes
    (CVE-2020-7046)
  - Specially crafted mail could crash snippet generation (CVE-2020-7957)

* Thu Jan 30 2020 Paul Howarth <paul@city-fan.org> - 1:2.3.9.2-2.0.cf
- Rebuilt for https://fedoraproject.org/wiki/Fedora_32_Mass_Rebuild

* Sun Dec 15 2019 Paul Howarth <paul@city-fan.org> - 1:2.3.9.2-1.0.cf
- Update dovecot to 2.3.9.2
  - Mails with empty From/To headers can also cause crash in push notification
    drivers

* Fri Dec 13 2019 Paul Howarth <paul@city-fan.org> - 1:2.3.9.1-1.0.cf
- Update dovecot to 2.3.9.1
  - Mails with group addresses in From or To fields caused crash in push
    notification drivers (CVE-2019-19722)
- Build with lz4, libexttextcat and libstemmer from Fedora 32 onwards

* Fri Dec  6 2019 Paul Howarth <paul@city-fan.org> - 1:2.3.9-1.0.cf
- Update dovecot to 2.3.9
  - Changed several event field names for consistency and to avoid conflicts in
    parent-child event relationships:
    - SMTP server command events: Renamed "name" to "cmd_name"
    - Events inheriting from a mailbox: Renamed "name" to "mailbox"
    - Server connection events have only "remote_ip", "remote_port", "local_ip"
      and "local_port"
    - Removed duplicate "client_ip", "ip" and "port"
    - Mail storage events: Removed "service" field; use "service:<name>"
      category instead
    - HTTP client connection events: Renamed "host" to "dest_host" and "port"
      to "dest_port"
  - auth: Drop Postfix socketmap support: it hasn't been working with recent
    Postfix versions for a while now
  - push-notification-lua: The "subject" field is now decoded to UTF8 instead
    of kept as MIME-encoded
  - push-notification-lua: Added new "from_address", "from_display_name",
    "to_address" and "to_display_name" fields; the display names are decoded to
    UTF8
  - Added various new fields to existing events; see
    http://doc.dovecot.net/admin_manual/list_of_events.html
  - Add lmtp_add_received_header setting; it can be used to prevent LMTP from
    adding "Received:" headers
  - doveadm: Support SSL/STARTTLS for proxied doveadm connections based on
    doveadm_ssl setting and proxy ssl/tls settings
  - Log filters support now "service:<name>", which matches all events for the
    given service; it can also be used as a category
  - lib: Use libunwind to get abort backtraces with function names where
    available
  - lmtp: When the LMTP proxy changes the username (from passdb lookup) add an
    appropriate ORCPT parameter
  - lmtp: Add lmtp_client_workarounds setting to implement workarounds for
    clients that send MAIL and RCPT commands with additional spaces before the
    path and for clients that omit <> brackets around the path; see
    example-config/conf.d/20-lmtp.conf
  - lda/lmtp: Invalid MAIL FROM addresses were rejected too aggressively; now
    mails from addresses with unicode characters are delivered, but their
    Return-Path header will be <> instead of the given MAIL FROM address
  - lmtp: The lmtp_hdr_delivery_address setting is ignored
  - imap: imap_command_finished event's "args" and "human_args" parameters were
    always empty
  - mbox: Seeking in zlib and bzip2 compressed input streams didn't work
    correctly
  - imap-hibernate: Process crashed when client got destroyed while it was
    attempted to be unhibernated, and the unhibernation fails
  - *-login: Proxying may have crashed if SSL handshake to the backend failed
    immediately; this was unlikely to happen in normal operation
  - *-login: If TLS handshake to upstream server failed during proxying, login
    process could crash due to invalid memory access
  - *-login: v2.3 regression: Using SASL authentication without initial
    response may have caused SSL connections to hang; this happened often at
    least with PHP's IMAP library
  - *-login: When login processes are flooded with authentication attempts it
    starts logging errors about "Authentication server sent unknown id"; this
    is still expected, however, it also caused the login process to disconnect
    from auth server and potentially log some user's password in the error
    message
  - dict-sql: SQL prepared statements were not shared between sessions; this
    resulted in creating a lot of prepared statements, which was especially
    inefficient when using Cassandra backend with a lot of Cassandra nodes
  - auth: auth_request_finished event didn't have success=yes parameter set
    for successful authentications
  - auth: userdb dict - Trying to list users crashed
  - submission: Service could be configured to allow anonymous authentication
    mechanism and anonymous user access
  - LAYOUT=index: Corrupted dovecot.list.index caused folder creation to panic
  - doveadm: HTTP server crashes if request target starts with double "/"
  - dsync: Remote dsync started hanging if the initial doveadm "dsync-server"
    command was sent in the same TCP packet as the following dsync handshake
    (v2.3.8 regression)
  - lib: Several "input streams" had a bug that in some rare situations might
    cause it to access freed memory, which could lead to crashes or corruption;
    the only currently known effect of this is that using zlib plugin with
    external mail attachments (mail_attachment_dir) could cause fetching the
    mail to return a few bytes of garbage data at the beginning of the header
    (note that the mail wasn't saved corrupted, but fetching it caused
    corrupted mail to be sent to the client)
  - lib-storage: If a mail only has quoted content, use the quoted text for
    generating message snippet (IMAP PREVIEW) instead of returning empty
    snippet
  - lib-storage: When vsize header was rebuilt, newly calculated message sizes
    were added to dovecot.index.cache instead of being directly saved into
    vsize records in dovecot.index
  - lib: JSON generator was escaping UTF-8 characters unnecessarily
- Update pigeonhole to 0.5.9
  - Added events for Sieve and ManageSieve, see
    https://doc.dovecot.org/admin_manual/list_of_events/#pigeonhole
  - Pigeonhole: Implement the Sieve "special-use" extension described in
    RFC 8579
  - duplicate: Test only compared the handles, which would cause different
    values to be cached as the same duplicate test; fix to also compare the
    actual hashes
  - imap_sieve_filter: IMAP FILTER Command had various bugs in error handling;
    errors may have been duplicated for each email, errors may have been
    missing entirely, command tag and ERRORS/WARNINGS parameters were swapped

* Fri Oct 11 2019 Paul Howarth <paul@city-fan.org> - 1:2.3.8-1.0.cf
- Update dovecot to 2.3.8
  - Added mail_delivery_started and mail_delivery_finished events; see
    https://doc.dovecot.org/admin_manual/list_of_events/ for details
  - dsync-replication: Don't replicate users who have "noreplicate" extra
    field in userdb
  - doveadm service status: Show total number of processes created
  - When logging to syslog, use instance_name setting's value for the ident;
    this is commonly added as a log prefix
  - Base64 encoding/decoding code was rewritten with additional features; it
    shouldn't cause any user visible changes
  - v2.3.7 regression: If a folder only receives new mails without any other
    mail access, dovecot.index.log keeps growing forever and dovecot.index
    keeps being rewritten for every mail delivery
  - dsync-replication may lose keywords after syncing mails restored from
    another replica; this only happened if the mail only had keywords and no
    system flags
  - event filters: Non-textual event fields could not be filtered using
    wildcards
  - auth: Scope parameter was missing from OAuth password grant request
  - doveadm client-server communication may hang in some situations; it was
    also using unnecessarily small TCP/IP packet sizes
  - doveadm who and kick did not flush protocol output correctly
  - imap: SETMETADATA with literal value would delete the metadata value
    instead of updating it
  - imap: When client issues FETCH PREVIEW (LAZY=FUZZY) command, the caching
    decisions should be updated so that newly saved mails will have the
    preview cached
  - With mail_nfs_index=yes and/or mail_nfs_storage=yes setuid/setgid
    permission bits in some files may have become dropped with some NFS
    servers; changed NFS flushing to now use chmod() instead of chown()
  - quota: warnings did not work if quota root was noenforcing
  - acl: Global ACL file ignored the last line if it didn't end with LF
  - doveadm stats dump: With JSON formatter output numbers using the number
    type instead of as strings
  - lmtp_proxy: Ensure that real_* variables are correctly set when using
    lmtp_proxy
  - event exporter: http-post driver had hardcoded timeout and did not support
    DNS lookups or TLS connections
  - auth: Fix user iteration to work with userdb passwd with glibc v2.28
  - auth: auth service can crash if auth-policy JSON response is invalid or
    returned too fast
  - In some rare situations "ps" output could have shown a lot of "?"
    characters after Dovecot process titles
  - When dovecot.index.pvt is empty, an unnecessary error is logged:
    Error: .../dovecot.index.pvt reset, view is now inconsistent
  - SMTP address encoder duplicated initial double quote character when the
    localpart of an address ended in '..'. For example "user+..@example.com"
    became ""user+.."@example.com in a sieve redirect
- Update pigeonhole to 0.5.8
  - Sieve may leak resources in rare cases when a redirect, vacation or report
    action fails to send the message; this mainly applies when Sieve is
    executed in IMAP context, i.e. for the IMAPSIEVE or FILTER=SIEVE
    capabilities
- Drop support from building pigeonhole from VCS snapshot

* Thu Aug 29 2019 Paul Howarth <paul@city-fan.org> - 1:2.3.7.2-1.0.cf
- Update dovecot to 2.3.7.2
  - CVE-2019-11500: IMAP protocol parser does not properly handle NUL byte when
    scanning data in quoted strings, leading to out of bounds heap memory
    writes
- Update pigeonhole to 0.5.7.2
  - CVE-2019-11500: ManageSieve protocol parser does not properly handle NUL
    byte when scanning data in quoted strings, leading to out of bounds heap
    memory writes

* Mon Jul 29 2019 Paul Howarth <paul@city-fan.org> - 1:2.3.7.1-1.2.cf
- Drop patch for flaky HTTP test, seems OK now

* Mon Jul 29 2019 Paul Howarth <paul@city-fan.org> - 1:2.3.7.1-1.1.cf
- Update pigeonhole to 0.5.7.1
  - dsync: Sieve script syncing failed if mailbox attributes weren't enabled

* Wed Jul 24 2019 Paul Howarth <paul@city-fan.org> - 1:2.3.7.1-1.0.cf
- Update dovecot to 2.3.7.1
  - Fix TCP_NODELAY errors being logged on non-Linux OSes
  - lmtp proxy: Fix assert-crash when client uses BODY=8BITMIME
  - Remove wrongly-added checks in namespace prefix checking

* Mon Jul 15 2019 Paul Howarth <paul@city-fan.org> - 1:2.3.7-1.0.cf
- Update dovecot to 2.3.7
  - fts-solr: Removed break-imap-search parameter
  - Added more events for the new statistics, see
    https://doc.dovecot.org/admin_manual/list_of_events/
  - mail-lua: Add IMAP metadata accessors, see
    https://doc.dovecot.org/admin_manual/lua/
  - Add event exporters that allow exporting raw events to log files and
    external systems, see
    https://doc.dovecot.org/configuration_manual/event_export/
  - SNIPPET is now PREVIEW and size has been increased to 200 characters
  - Add body option to fts_enforced; this triggers building FTS index only on
    body search, and an error using FTS index fails the search rather than
    reads through all the mails
  - Submission/LMTP: Fixed crash when domain argument is invalid in a second
    EHLO/LHLO command
  - Copying/moving mails using Maildir format loses IMAP keywords in the
    destination if the mail also has no system flags
  - mail_attachment_detection_options=add-flags-on-save caused email body to be
    unnecessarily opened when FETCHing mail headers that were already cached
  - mail attachment detection keywords not saved with maildir
  - dovecot.index.cache may have grown excessively large in some situations;
    this happened especially when using autoexpunging with lazy_expunge folders
    (also with mdbox format in general the cache file wasn't recreated as often
    as it should have)
  - Autoexpunged mails weren't immediately deleted from the disk; instead, the
    deletion from disk happened the next time the folder was opened, which
    could have caused unnecessary delays if the opening was done by an
    interactive IMAP session
  - Dovecot's TCP connections sometimes add extra 40 ms latency due to not
    enabling TCP_NODELAY; HTTP and SMTP/LMTP connections weren't affected, but
    everything else was (this delay wasn't always visible - only in some
    situations with some message/packet sizes)
  - imapc: Fix various crash conditions
  - Dovecot builds were not always reproducible
  - login-proxy: With shutdown_clients=no after config reload the existing
    connections could no longer be listed or kicked with doveadm
  - "doveadm proxy kick" with -f parameter caused a crash in some situations
  - Auth policy can cause segmentation fault crash during auth process shutdown
    if all auth requests have not been finished
  - Fix various minor bugs leading to incorrect behaviour in mailbox list index
    handling; these rarely caused noticeable problems
  - LDAP auth: Iteration accesses freed memory, possibly crashing auth-worker
  - local_name { .. } filter in dovecot.conf does not correctly support
    multiple names and wildcards were matched incorrectly
  - replicator: dsync assert-crashes if it can't connect to remote TCP server
  - config: Memory leak in config process when ssl_dh setting wasn't set and
    there was no ssl-parameters.dat file; this caused config process to die
    once in a while with "out of memory"
- Update pigeonhole to 0.5.7
  - vacation: Made the subject for the automatic response message produced by
    the Sieve vacation action configurable; both the default subject (if the
    script defines none) and the subject template (e.g. used to add a subject
    prefix) can be configured
  - dsync: dsync-replication does not synchronize Sieve scripts
  - imap_sieve_filter: Reduce FILTER=SIEVE verbosity over IMAP connection
  - testsuite: Pigeonhole testsuite segfaulted if it was compiled with GCC 9

* Sun Jun  2 2019 Paul Howarth <paul@city-fan.org> - 1:2.3.6-3.0.cf
- Disable gcc 9 stack reuse temporarily
- Use /run instead of /var/run (#1706372)

* Wed May  1 2019 Paul Howarth <paul@city-fan.org> - 1:2.3.6-1.0.cf
- Update dovecot to 2.3.6
  - CVE-2019-11494: Submission-login crashed with signal 11 due to null pointer
    access when authentication was aborted by disconnecting
  - CVE-2019-11499: Submission-login crashed when authentication was started
    over TLS secured channel and invalid authentication message was sent
  - auth: Support password grant with passdb oauth2
  - Use system default CAs for outbound TLS connections
  - Simplify array handling with new helper macros
  - fts_solr: Enable configuring batch_size and soft_commit features
  - lmtp/submission: Fixed various bugs in XCLIENT handling, including a hang
    when XCLIENT commands were sent infinitely to the remote server
  - lmtp/submission: Forwarded multi-line replies were erroneously sent as two
    replies to the client
  - lib-smtp: client: Message was not guaranteed to contain CRLF consistently
    when CHUNKING was used
  - fts_solr: Plugin was no longer compatible with Solr 7
  - Make it possible to disable certificate checking without setting
    ssl_client_ca_* settings
  - pop3c: SSL support was broken
  - mysql: Closing connection twice lead to crash on some systems
  - auth: Multiple oauth2 passdbs crashed auth process on deinit
  - HTTP client connection errors infrequently triggered a segmentation fault
    when the connection was idle and not used for a particular client instance
- Update pigeonhole to 0.5.6
  - sieve: Redirect loop prevention is sometimes ineffective; improve existing
    loop detection by also recognizing the X-Sieve-Redirected-From header in
    incoming messages and dropping redirect actions when it points to the
    sending account (this header is already added by the redirect action, so
    this improvement only adds an additional use of this header)
  - sieve: Prevent execution of implicit keep upon temporary failure occurring
    at runtime

* Thu Apr 18 2019 Paul Howarth <paul@city-fan.org> - 1:2.3.5.2-1.0.cf
- Update dovecot to 2.3.5.2
  - CVE-2019-10691: Trying to login with 8bit username containing invalid UTF8
    input causes auth process to crash if auth policy is enabled; this could be
    used rather easily to cause a DoS (similar crash also happens during mail
    delivery when using invalid UTF8 in From or Subject header when OX push
    notification driver is used)

* Fri Mar 29 2019 Paul Howarth <paul@city-fan.org> - 1:2.3.5.1-1.0.cf
- Update dovecot to 2.3.5.1
  - CVE-2019-7524: Missing input buffer size validation leads into arbitrary
    buffer overflow when reading fts or pop3 uidl header from Dovecot index;
    exploiting this requires direct write access to the index files
- Add patch to make flaky HTTP test less flaky
  https://www.dovecot.org/pipermail/dovecot/2019-March/114974.html

* Wed Mar  6 2019 Paul Howarth <paul@city-fan.org> - 1:2.3.5-1.0.cf
- Update dovecot to 2.3.5
  - Lua push notification driver: mail keywords and flags are provided in
    MessageNew and MessageAppend events
  - Submission: Implement support for plugins
  - auth: When auth_policy_log_only=yes, only log what the policy server
    response would do without actually doing it
  - auth: Always log policy server decisions with auth_verbose=yes
  - v2.3.[34]: doveadm log errors: Output was missing user/session
  - lda: Debug log lines could have shown slightly corrupted
  - login proxy: Login processes may have crashed in various ways when
    login_proxy_max_disconnect_delay was set
  - imap: Fix crash with Maildir+zlib if client disconnects during APPEND
  - lmtp proxy: Fix potential assert-crash
  - lmtp/submission: Fix crash when SMTP client transaction times out
  - Submission: Split large XCLIENT commands to 512 bytes per command, so
    Postfix accepts them
  - Submission: Fix crash when client sends invalid BURL command
  - Submission: relay backend: VRFY command: Avoid forwarding 500 and 502
    replies back to client
  - lib-http: Fix potential assert-crash when DNS lookup fails
  - lib-fts: Fix search query generation when one language ignores a token
    (e.g. via stopwords)
- Update pigeonhole to 0.5.5
  - IMAPSieve: Add new plugin/imapsieve_expunge_discarded setting that causes
    messages discarded by an IMAPSieve script to be expunged immediately,
    rather than only being marked as "\Deleted" (which is still the default
    behaviour)
  - IMAPSieve: Fix panic crash occurring when a COPY command copies messages
    from a virtual mailbox where the source messages originate from more than a
    single real mailbox
  - imap4flags extension: Fix deleting all keywords; when the action resulted
    in all keywords being removed, no changes were actually applied
  - variables extension: Fix truncation of UTF-8 variable content; the maximum
    size of Sieve variables was enforced by truncating the variable string
    content bluntly at the limit, but this does not consider UTF-8 code point
    boundaries, which resulted in broken UTF-8 strings
  - IMAPSieve, IMAP FILTER=SIEVE: Fix replacing a modified message; Sieve
    scripts running in IMAPSIEVE or IMAP FILTER=SIEVE context that modify the
    message, stored the message a second time, rather than replacing the
    originally stored unmodified message
  - Fix segmentation fault occurring when both the sieve_extprograms plugin
    (for the Sieve interpreter) and the imap_filter_sieve plugin (for IMAP) are
    loaded at the same time; a symbol was defined by both plugins, causing a
    clash when both were loaded

* Tue Feb  5 2019 Paul Howarth <paul@city-fan.org> - 1:2.3.4.1-1.0.cf
- Update dovecot to 2.3.4.1
  - CVE-2019-3814: If imap/pop3/managesieve/submission client has trusted
    certificate with missing username field (ssl_cert_username_field), under
    some configurations Dovecot mistakenly trusts the username provided via
    authentication instead of failing
  - ssl_cert_username_field setting was ignored with external SMTP AUTH,
    because none of the MTAs (Postfix, Exim) currently send the cert_username
    field; this may have allowed users with trusted certificate to specify any
    username in the authentication (this bug didn't affect Dovecot's Submission
    service)

* Tue Jan 15 2019 Paul Howarth <paul@city-fan.org> - 1:2.3.4-2.0.cf
- Build with libsodium support from Fedora 25 and EL-7 onwards

* Mon Nov 26 2018 Paul Howarth <paul@city-fan.org> - 1:2.3.4-1.0.cf
- Update dovecot to 2.3.4
  - The default postmaster_address is now
    "postmaster@<user domain or server hostname>"; if username contains the
    @domain part, that's used, otherwise the server's hostname is used
  - "doveadm stats dump" now returns two decimals for the "avg" field
  - Added push notification driver that uses a Lua script
  - Added new SQL, DNS and connection events; see
    https://wiki2.dovecot.org/Events
  - Added "doveadm mailbox cache purge" command
  - Added events API support for Lua scripts
  - doveadm force-resync -f parameter performs "index fsck" while opening the
    index, which may be useful to fix some types of broken index files (this
    may become the default behavior in a later version)
  - director: Kicking a user crashes if login process is very slow
  - pop3_no_flag_updates=no: Don't expunge DELEted and RETRed messages unless
    QUIT is sent
  - auth: Fix crypt() segfault with glibc-2.28+
  - imap: Running UID FILTER script with errors assert-crashes
  - dsync, pop3-migration: POP3 UIDLs weren't added to dovecot.index.cache
    while mails were saved
  - dict clients may have been using 100%% CPU while waiting for dict server to
    finish commands
  - doveadm user: Fixed user listing via HTTP API
  - All levels of Cassandra log messages were logged as Dovecot errors
  - http/smtp client may have crashed after SSL handshake
  - Lua auth converted strings that looked like numbers into numbers
- Update pigeonhole to 0.5.4
  - Adjustments to several changes in Dovecot v2.3.4 make this Pigeonhole
    release dependent on that Dovecot release; it will not compile against
    older Dovecot versions; conversely, you need to upgrade Pigeonhole when
    upgrading Dovecot to v2.3.4
  - The changes regarding the default postmaster_address in Dovecot v2.3.4
    mainly apply to Pigeonhole; the new default should work for all existing
    installations, thereby fixing several reported v2.3/v0.5 migration problems
  - IMAP FILTER=SIEVE capability: Fix assert crash occurring when running
    UID FILTER on a Sieve script with errors
- Add upstream fix for 32-bit issues
  (https://www.dovecot.org/pipermail/dovecot/2018-November/113576.html)

* Tue Oct  2 2018 Paul Howarth <paul@city-fan.org> - 1:2.3.3-1.0.cf
- Update dovecot to 2.3.3
  - doveconf hides more secrets now in the default output
  - ssl_dh setting is no longer enforced at startup; if it's not set and
    non-ECC DH key exchange happens, an error is logged and the client is
    disconnected
  - Added log_debug=<filter> setting
  - Added log_core_filter=<log filter> setting
  - quota-clone: Write to dict asynchronously
  - --enable-hardening attempts to use retpoline Spectre 2 mitigations
  - lmtp proxy: Support source_ip passdb extra field
  - doveadm stats dump: Support more fields and output stddev by default
  - push-notification: Add SSL support for OX backend
  - NUL bytes in mail headers can cause truncated replies when fetched
  - director: Conflicting host up/down state changes may in some rare
    situations ended up in a loop of two directors constantly overwriting each
    others' changes
  - director: Fix hang/crash when multiple doveadm commands are being handled
    concurrently
  - director: Fix assert-crash if doveadm disconnects too early
  - virtual plugin: Some searches used 100%% CPU for many seconds
  - dsync assert-crashed with acl plugin in some situations
  - mail_attachment_detection_options=add-flags-on-save assert-crashed with
    some specific Sieve scripts
  - Mail snippet generation crashed with mails containing invalid
    Content-Type:multipart header
  - Log prefix ordering was different for some log lines
  - quota: With noenforcing option current quota usage wasn't updated
  - auth: Kerberos authentication against Samba assert-crashed
  - stats clients were unnecessarily chatty with the stats server
  - imapc: Fixed various assert-crashes when reconnecting to server
  - lmtp, submission: Fix potential crash if client disconnects while handling
    a command
  - quota: Fixed compiling with glibc-2.26 / support libtirpc
  - fts-solr: Empty search values resulted in 400 Bad Request errors
  - fts-solr: default_ns parameter couldn't be used
  - submission server crashed if relay server returned over 7 lines in a reply
    (e.g. to EHLO)
- Update pigeonhole to 0.5.3
  - Fix assertion panic occurring when managesieve service fails to open INBOX
    while saving a Sieve script; this was caused by a lack of cleanup after
    failure
  - Fix specific messages causing an assert panic with actions that compose a
    reply (e.g. vacation); with some rather weird input from the original
    message, the header folding algorithm (as used for composing the References
    header for the reply) got confused, causing the panic
  - IMAP FILTER=SIEVE capability: Fix FILTER SIEVE SCRIPT command parsing;
    after finishing reading the Sieve script, the command parsing sometimes
    didn't continue with the search arguments - this is a time-critical bug
    that likely only occurs when the Sieve script is sent in the next TCP frame
- Enable hardening

* Mon Aug 20 2018 Paul Howarth <paul@city-fan.org> - 1:2.3.2.1-3.0.cf
- Rebuild

* Mon Jul 16 2018 Paul Howarth <paul@city-fan.org> - 1:2.3.2.1-2.0.cf
- Rebuilt for https://fedoraproject.org/wiki/Fedora_29_Mass_Rebuild

* Wed Jul 11 2018 Paul Howarth <paul@city-fan.org> - 1:2.3.2.1-1.0.cf
- Update dovecot to 2.3.2.1
  - SSL/TLS servers may have crashed during client disconnection
  - lmtp: With lmtp_rcpt_check_quota=yes mail deliveries may sometimes have
    assert-crashed
  - v2.3.2: "make check" may have crashed with 32bit systems

* Mon Jul  2 2018 Paul Howarth <paul@city-fan.org> - 1:2.3.2-1.0.cf
- Update dovecot to 2.3.2
  - old-stats plugin: Don't temporarily enable PR_SET_DUMPABLE while opening
    /proc/self/io (this may still cause security problems if the process is
    ptrace()d at the same time); instead, open it while still running as root
  - doveadm: Added mailbox cache decision and remove commands; see
    doveadm-mailbox(1) man page for details
  - doveadm: Added rebuild attachments command for rebuilding
    $HasAttachment or $HasNoAttachment flags for matching mails; see
    doveadm-rebuild(1) man page for details
  - cassandra: Use fallback_consistency on more types of errors
  - lmtp proxy: Support outgoing SSL/TLS connections
  - lmtp: Add lmtp_rawlog_dir and lmtp_proxy_rawlog_dir settings
  - submission: Add support for rawlog_dir
  - submission: Add submission_client_workarounds setting
  - lua auth: Add password_verify() function and additional fields in auth
    request
  - doveadm-server: TCP connections are hanging when there is a lot of network
    output; this especially caused hangs in dsync-replication
  - Using multiple type=shared mdbox namespaces crashed
  - mail_fsync setting was ignored; it was always set to "optimized"
  - lua auth: Fix potential crash at deinit
  - SSL/TLS servers may have crashed if client disconnected during handshake
  - SSL/TLS servers: Don't send extraneous certificates to client when alt
    certs are used
  - lda, lmtp: Return-Path header without '<' may have assert-crashed
  - lda, lmtp: Unencoded UTF-8 in email address headers may assert-crash
  - lda: -f parameter didn't allow empty/null/domainless address
  - lmtp, submission: Message size limit was hardcoded to 40 MB; exceeding it
    caused the connection to get dropped during transfer
  - lmtp: Fix potential crash when delivery fails at DATA stage
  - lmtp: login_greeting setting was ignored
  - Fix to work with OpenSSL v1.0.2f
  - systemd unit restrictions were too strict by default
  - Fix potential crashes when a lot of log output was produced
  - SMTP client may have assert-crashed when sending mail
  - IMAP COMPRESS: Send "end of compression" marker when disconnecting
  - cassandra: Fix consistency=quorum to work
  - dsync: Lock file generation failed if home directory didn't exist
  - Snippet generation for HTML mails didn't ignore &entities inside
    blockquotes, producing strange looking snippets
  - imapc: Fix assert-crash if getting disconnected and after reconnection all
    mails in the selected mailbox are gone
  - pop3c: Handle unexpected server disconnections without assert-crash
  - fts: Fixes to indexing mails via virtual mailboxes
  - fts: If mails contained NUL characters, the text around it wasn't indexed
  - Obsolete dovecot.index.cache offsets were sometimes used; trying to fetch a
    field that was just added to cache file may not have always found it
- Update pigeonhole to 0.5.2
  - Implement plugin for the a vendor-defined IMAP capability called
    "FILTER=SIEVE"; it adds the ability to manually invoke Sieve filtering
    in IMAP (more information can be found in
    doc/plugins/imap_filter_sieve.txt)
  - The Sieve address test caused an assertion panic for invalid addresses with
    UTF-8 codepoints in the localpart; fixed by properly detecting invalid
    addresses with UTF-8 codepoints in the localpart and skipping these like
    other invalid addresses while iterating addresses for the address test
  - Make the length of the subject header for the vacation response
    configurable and enforce the limit in UTF-8 codepoints rather than bytes;
    The subject header for a vacation response was statically truncated to 256
    bytes, which is too limited for multi-byte UTF-8 characters
  - Sieve editheader extension: Fix assertion panic occurring when it is used
    to manipulate a message header with a very large header field
  - Properly abort execution of the sieve_discard script upon error; before,
    the LDA Sieve plugin attempted to execute the sieve_discard script when an
    error occurs, which can lead to the message being lost
  - Fix the interaction between quota and the sieve_discard script; when quota
    was used together with a sieve_discard script, the message delivery did not
    bounce when the quota was exceeded
- Add patch to fix crash in test suite on i686
  (https://github.com/dovecot/core/pull/88)

* Fri Apr  6 2018 Paul Howarth <paul@city-fan.org> - 1:2.3.1-2.1.cf
- Retain CAP_AUDIT_WRITE (#1564348)

* Sat Mar 31 2018 Paul Howarth <paul@city-fan.org> - 1:2.3.1-2.0.cf
- Use libxcrypt for Fedora ≥ 28 (#1548520)
- Fix FTBFS - murmurhash3 check fail

* Wed Mar 28 2018 Paul Howarth <paul@city-fan.org> - 1:2.3.1-1.0.cf
- Update dovecot to 2.3.1
  - Submission server support improvements and bug fixes
  - Lots of bug fixes to submission server
  - API CHANGE: array_idx_modifiable will no longer allocate space
  - Particularly affects how you should check MODULE_CONTEXT result, or use
    REQUIRE_MODULE_CONTEXT
  - mail_attachment_detection_options setting controls when $HasAttachment and
    $HasNoAttachment keywords are set for mails
  - imap: Support fetching body snippets using FETCH (SNIPPET) or
    (SNIPPET (LAZY=FUZZY))
  - fs-compress: Automatically detect whether input is compressed or not;
    prefix the compression algorithm with "maybe-" to enable the detection, for
    example: "compress:maybe-gz:6:..."
  - Added settings to change dovecot.index* files' optimization behaviour (see
    https://wiki2.dovecot.org/IndexFiles#Settings)
  - Auth cache can now utilize auth workers to do password hash verification by
    setting auth_cache_verify_password_with_worker=yes
  - Added charset_alias plugin (see
    https://wiki2.dovecot.org/Plugins/CharsetAlias)
  - imap_logout_format and pop3_logout_format settings now support all of the
    generic variables (e.g. %%{rip}, %%{session}, etc.)
  - Added auth_policy_check_before_auth, auth_policy_check_after_auth and
    auth_policy_report_after_auth settings
  - master: Support HAProxy PP2_TYPE_SSL command and set "secured" variable
    appropriately
  - Invalid UCS4 escape in HTML can cause crashes
  - imap: IMAP COMPRESS -enabled client crashes on disconnect
  - lmtp: Fix crash when user is over quota
  - lib-lda: Parsing Return-Path header address fails when it contains CFWS
  - auth: SASL with Exim fails for AUTH commands without an initial response
  - imap: SPECIAL-USE capability isn't automatically added
  - auth: LDAP subqueries do not support standard auth variables in var-expand
  - auth: SHA256-CRYPT and SHA512-CRYPT schemes do not work
  - lib-index: mail_always/never_cache_fields are not used for existing cache
    files
  - imap: Fetching headers leaks memory if search doesn't find any mails
  - lmtp: ORCPT support in RCPT TO
  - imap-login: Process sometimes ends up in infinite loop
  - sdbox: Rolled back save/copy transaction doesn't delete temp files
  - mail: lock_method=dotlock causes crashes
- Update pigeonhole to 0.5.1
  - Explicitly disallow UTF-8 in localpart in addresses parsed from Sieve
    script
  - editheader extension: Corrected the stream position calculations performed
    while making the modified message available as a stream; Pigeonhole Sieve
    crashed in LMTP with an assertion panic when the Sieve editheader extension
    was used before the message was redirected
  - fileinto extension: Fix assert panic occurring when fileinto is used
    without being listed in the require line, while the copy extension is
    listed there; this is a very old bug
  - imapsieve plugin: Do not assert crash or log an error for messages that
    disappear concurrently while applying Sieve scripts; this event is now
    logged as a debug message
  - Sieve extprograms plugin: Large output from "execute" command crashed
    delivery; fixed buffering issue in code that handles output from the
    external program

* Fri Mar  2 2018 Paul Howarth <paul@city-fan.org> - 1:2.3.0.1-1.0.cf
- Update dovecot to 2.3.0.1
  - CVE-2017-15130: TLS SNI config lookups may lead to excessive memory usage,
    causing imap-login/pop3-login VSZ limit to be reached and the process
    restarted; this happens only if Dovecot config has local_name { } or
    local { } configuration blocks and attacker uses randomly generated SNI
    servernames
  - CVE-2017-14461: Parsing invalid email addresses may cause a crash or leak
    memory contents to attacker, e.g. these memory contents might contain parts
    of an email from another user if the same imap process is reused for
    multiple users
  - CVE-2017-15132: Aborted SASL authentication leaks memory in login process
  - Linux: Core dumping is no longer enabled by default via PR_SET_DUMPABLE,
    because this may allow attackers to bypass chroot/group restrictions;
    nowadays core dumps can be safely enabled by using
    "sysctl -w fs.suid_dumpable=2", and if the old behaviour is wanted, it can
    still be enabled by setting:
    import_environment=$import_environment PR_SET_DUMPABLE=1
  - imap-login with SSL/TLS connections may end up in infinite loop
- Update pigeonhole to 0.5.0.1
  - imap4flags extension: Fix binary corruption occurring when
    setflag/addflag/removeflag flag-list is a variable
  - sieve-extprograms plugin: Fix segfault occurring when used in IMAPSieve
    context
- Make sure crypt() is declared

* Thu Jan 11 2018 Paul Howarth <paul@city-fan.org> - 1:2.3.0-1.1.cf
- Remove tcp_wrappers from Fedora 28 onwards (#1518761)
- Use mariadb-connector-c-devel instead of mysql-devel from Fedora 28 onwards
  (#1493624)

* Wed Jan  3 2018 Paul Howarth <paul@city-fan.org> - 1:2.3.0-1.0.cf
- Update dovecot to 2.3.0
  - Various setting changes, see https://wiki2.dovecot.org/Upgrading/2.3
  - Logging rewrite started: Logging is now based on hierarchical events
  - Statistics rewrite started: Stats are now based on (log) events
  - ssl_dh setting replaces the old generated ssl-parameters.dat
  - IMAP: When BINARY FETCH finds a broken mail, send [PARSE] error instead of
    [UNKNOWNCTE]
  - Linux: core dumping via PR_SET_DUMPABLE is no longer enabled by default due
    to potential security reasons (found by cPanel Security Team)
  - Added support for SMTP submission proxy server, which includes support for
    BURL and CHUNKING extension
  - LMTP rewrite: Now supports CHUNKING extension and mixing of local/proxy
    recipients
  - auth: Support libsodium to add support for ARGON2I and ARGON2ID password
    schemes
  - auth: Support BLF-CRYPT password scheme in all platforms
  - auth: Added LUA scripting support for passdb/userdb (see
    https://wiki2.dovecot.org/AuthDatabase/Lua)
  - Input streams are more reliable now when there are errors or when the
    maximum buffer size is reached; previously in some situations this could
    have caused Dovecot to try to read already freed memory
  - Output streams weren't previously handling failures when writing a trailer
    at the end of the stream; this mainly affected encrypt and zlib compress
    ostreams, which could have silently written truncated files if the last
    write happened to fail (which shouldn't normally have ever happened)
  - virtual plugin: Fixed panic when fetching mails from virtual mailboxes with
    IMAP BINARY extension
  - doveadm-server: Fix potential hangs with SSL connections
  - doveadm proxy: Reading commands' output from v2.2.33+ servers could have
    caused the output to be corrupted or caused a crash
  - Many other smaller fixes
- Update pigeonhole to 0.5.0
  - editheader extension: The implementation of header modifications is heavily
    updated; although the functionality has not changed, the underlying code
    was updated to address several static analysis warnings, runtime integer
    arithmetic warnings (Clang), and to match updates in the Dovecot stream API
  - variables extension: Made the maximum scope and variable size configurable
  - subaddress: Support multiple recipient_delimiters
  - enotify extension: mailto method: Fixed parsing of mailto URI with only a
    header part
  - enotify plugin: mailto method: Make sure the "From:" header is set to a
    usable address and not "(null)"
  - Fixed writing address headers to outgoing messages; sometimes headers were
    MIME-encoded twice, yielding invalid results
- Attempt to generate /etc/dovecot/dh.pem, either by migrating from an existing
  /var/lib/dovecot/ssl-parameters.dat file if present, or by generating new
  parameters using openssl
- Drop use of -fno-strict-aliasing compiler flag
- Drop support for distributions older than Fedora 18 since Dovecot now
  requires openssl ≥ 1.0.1
  - Can now guarantee that OpenSSL has ECC support
  - Suitably recent version of clucene always available now
  - Init system is always systemd now
  - Drop support for migrating from ancient dovecot packages with different
    layouts

* Mon Oct 30 2017 Paul Howarth <paul@city-fan.org> - 1:2.2.33.2-1.0.cf
- Update dovecot to 2.2.33.2
  - doveadm: Fix crash in proxying (or dsync replication) if remote is running
    older than v2.2.33
  - auth: Fix memory leak in %%{ldap_dn}
  - dict-sql: Fix data types to work correctly with Cassandra
- Update pigeonhole to 0.4.21
  - redirect action: Always set the X-Sieve-Redirected-From header to
    sieve_user_email if configured; previously, it would use the envelope
    recipient instead if available, which makes no sense if the primary e-mail
    address is available
  - vacation extension: Allow ignoring the envelope sender while composing the
    "To:" header for the reply; this change adds a new setting
    "sieve_vacation_to_header_ignore_envelope", which, when enabled, means the
    "To:" header is always composed from headers in the source message and thus
    allows ignoring the envelope, which is useful e.g.  when SRS is used
  - vacation extension: Compose the "To:" header from the full sender address
    found in the first "Sender:", "From:" or "Resent-From:" header
  - LDA Sieve plugin: Fixed sequential execution of LDAP-based scripts; a
    missing LDAP-based script could cause the script sequence to exit earlier
  - sieve-filter: Removed the (now) duplicate utf8 to mutf7 mailbox name
    conversion, which caused problems with mailbox names containing UTF-8
    characters; the Dovecot API was changed years ago, but apparently
    sieve-filter was never updated

* Thu Oct 12 2017 Paul Howarth <paul@city-fan.org> - 1:2.2.33.1-1.0.cf
- Update dovecot to 2.2.33.1
  - dovecot-lda was logging to stderr instead of to the log file

* Wed Oct 11 2017 Paul Howarth <paul@city-fan.org> - 1:2.2.33-1.0.cf
- Update dovecot to 2.2.33
  - doveadm director commands wait for the changes to be visible in the whole
    ring before they return; this is especially useful in testing
  - Environments listed in import_environment setting are now set or preserved
    when executing standalone commands (e.g. doveadm)
  - doveadm proxy: Support proxying logs; previously the logs were visible only
    in the backend's logs
  - Added %%{if}; see https://wiki2.dovecot.org/Variables#Conditionals
  - Added a new notify_status plugin, which can be used to update dict with
    current status of a mailbox when it changes. See
    https://wiki2.dovecot.org/Plugins/NotifyStatus
  - Mailbox list index can be disabled for a namespace by appending
    ":LISTINDEX=" to location setting
  - dsync/imapc: Added dsync_hashed_headers setting to specify which headers
    are used to match emails
  - pop3-migration: Add pop3_migration_ignore_extra_uidls=yes to ignore mails
    that are visible in POP3 but not IMAP; this could happen if new mails were
    delivered during the migration run
  - pop3-migration: Further improvements to help with Zimbra
  - pop3-migration: Cache POP3 UIDLs in imapc's dovecot.index.cache if indexes
    are enabled; these are used to optimize incremental syncs
  - cassandra, dict-sql: Use prepared statements if protocol version>3
  - auth: Added %%{ldap_dn} variable for passdb/userdb ldap
  - acl: The "create" (k) permission in global acl-file was sometimes ignored,
    allowing users to create mailboxes when they shouldn't have
  - sdbox: Mails were always opened when expunging, unless mail_attachment_fs
    was explicitly set to empty
  - lmtp/doveadm proxy: hostip passdb field was ignored, which caused
    unnecessary DNS lookups if host field wasn't an IP
  - lmtp proxy: Fix crash when receiving unexpected reply in RCPT TO
  - quota_clone: Update also when quota is unlimited (broken in v2.2.31)
  - mbox, zlib: Fix assert-crash when accessing compressed mbox
  - doveadm director kick -f parameter didn't work
  - doveadm director flush <host> resulted flushing all hosts, if <host> wasn't
    an IP address
  - director: Various fixes to handling backend/director changes at abnormal
    times, especially while ring was unsynced; these could have resulted in
    crashes, non-optimal behaviour or ignoring some of the changes
  - director: Use less CPU in imap-login processes when moving/kicking many
    users
  - lmtp: Session IDs were duplicated/confusing with multiple RCPT TOs when
    lmtp_rcpt_check_quota=yes
  - doveadm sync -1 fails when local mailboxes exist that do not exist
    remotely; this commonly happened when lazy_expunge mailbox was autocreated
    when incremental sync expunged mails
  - pop3: rawlog_dir setting didn't work

* Tue Aug 29 2017 Paul Howarth <paul@city-fan.org> - 1:2.2.32-2.0.cf
- Update pigeonhole to 0.4.20
  - Made the retention period for redirect duplicate identifiers configurable,
    and changed the default retention period from 24 to 12 hours; for accounts
    that perform many redirects, the lda-dupes database could grow to
    impractical sizes
  - sieve-filter: Fixed memory leak: forgot to clean up script binary at end of
    execution
  - managesieve-login: Fixed handling of AUTHENTICATE command: a second
    authenticate command would be parsed incorrectly, a problem was caused by
    changes in the previous release
  - LDA Sieve plugin: Fixed minor memory leak caused by not cleaning up the
    sieve_discard script

* Fri Aug 25 2017 Paul Howarth <paul@city-fan.org> - 1:2.2.32-1.0.cf
- Update dovecot to 2.2.32
  - imapc: Info-level line is logged every time when successfully connected to
    the remote server: this includes local/remote IP/port, which can be useful
    for matching against external logs
  - config: Log a warning if plugin { key=no } is used explicitly; v2.3 will
    support "no" properly in plugin settings, but for now any value at all for
    a boolean plugin setting is treated as "yes", even if it's written as
    explicit "no" - this change will now warn that it most likely won't work as
    intended
  - Various optimizations to avoid accessing files/directories when it's not
    necessary; especially avoid accessing mail root directories when INDEX
    directories point to a different filesystem
  - mail_location can now include ITERINDEX parameter, which tells Dovecot to
    perform mailbox listing from the INDEX path instead of from the mail root
    path; it's mainly useful when the INDEX storage is on a faster storage
  - mail_location can now include VOLATILEDIR=<path> parameter; this is used
    for creating lock files and in future potentially other files that don't
    need to exist permanently - the path could point to tmpfs for example
    (this is especially useful to avoid creating lock files to NFS or other
    remote filesystems)
  - mail_location's LISTINDEX=<path> can now contain a full path; this allows
    storing mailbox list index to a different storage than the rest of the
    indexes, for example to tmpfs
  - mail_location can now include NO-NOSELECT parameter; this automatically
    deletes any \NoSelect mailboxes that have no children (these mailboxes are
    sometimes confusing to users)
  - mail_location can now include BROKENCHAR=<char> parameter; this can be
    useful with imapc to access mailbox names that aren't valid mUTF-7 charset
    from remote servers
  - If mailbox_list_index_very_dirty_syncs=yes, the list index is no longer
    refreshed against filesystem when listing mailboxes; this allows the
    mailbox listing to be done entirely by only reading the mailbox list index
  - Added mailbox_list_index_include_inbox setting to control whether INBOX's
    STATUS information should be cached in the mailbox list index: the default
    is "no", but it may be useful to change it to "yes", especially if
    LISTINDEX points to tmpfs
  - userdb can return chdir=<path>, which overrides mail_home for the chdir
    location; this can be useful to avoid accessing home directory on login
  - userdb can return postlogin=<socket> to specify per-user imap/pop3
    postlogin socket path
  - cassandra: Add support for result paging by adding page_size=<n> parameter
    to the connect setting
  - dsync/imapc, pop3-migration plugin: Strip also trailing tabs from headers
    when matching mails; this helps with migrations from Zimbra
  - imap_logout_format supports now %%{appended} and %%{autoexpunged}
  - virtual plugin: Optimize IDLE to use mailbox list index for finding out
    when something has changed
  - Added apparmor plugin (see https://wiki2.dovecot.org/Plugins/Apparmor)
  - virtual plugin: A lot of fixes; in many cases it was also working very
    inefficiently or even incorrectly
  - imap: NOTIFY parameter parsing was incorrectly "fixed" in v2.2.31; it was
    actually (mostly) working in previous versions, but broken in v2.2.31
  - Modseq tracking didn't always work correctly; this could have caused imap
    unhibernation to fail or IMAP QRESYNC/CONDSTORE extensions to not work
    perfectly
  - mdbox: "Inconsistency in map index" wasn't fixed automatically
  - dict-ldap: %%variable values used in the LDAP filter weren't escaped
  - quota=count: quota_warning = -storage=.. was never executed (try #2);
    v2.2.31 fixed it for -messages, but not for -storage
  - imapc: ≥ 32 kB mail bodies were supposed to be cached for subsequent
    FETCHes, but weren't
  - quota-status service didn't support recipient_delimiter
  - acl: Don't access dovecot-acl-list files with acl_globals_only=yes
  - mail_location: If INDEX dir is set, mailbox deletion deletes its childrens'
    indexes; for example if "box" is deleted, "box/child" index directory was
    deleted as well (but mails were preserved)
  - director: v2.2.31 caused rapid reconnection loops to directors that were
    down

* Thu Aug  3 2017 Paul Howarth <paul@city-fan.org> - 1:2.2.31-5.0.cf
- Rebuilt for https://fedoraproject.org/wiki/Fedora_27_Binutils_Mass_Rebuild

* Wed Jul 26 2017 Paul Howarth <paul@city-fan.org> - 1:2.2.31-4.0.cf
- Rebuilt for https://fedoraproject.org/wiki/Fedora_27_Mass_Rebuild

* Fri Jul 21 2017 Paul Howarth <paul@city-fan.org> - 1:2.2.31-3.0.cf
- Enable tcpwrap support (#1450587)
- Revert commit breaking NOTIFY support

* Tue Jun 27 2017 Paul Howarth <paul@city-fan.org> - 1:2.2.31-1.0.cf
- Update dovecot to 2.2.31
  - LMTP: Removed "(Dovecot)" from added Received headers; some installations
    want to hide it, and there's not really any good reason for anyone to have
    it
  - Add ssl_alt_cert and ssl_alt_key settings to add support for having both
    RSA and ECDSA certificates
  - dsync/imapc, pop3-migration plugin: Strip trailing whitespace from headers
    when matching mails; this helps with migrations from Zimbra
  - acl: Add acl_globals_only setting to disable looking up per-mailbox
    dovecot-acl files
  - Parse invalid message addresses better; this mainly affects the generated
    IMAP ENVELOPE replies
  - v2.2.30 wasn't fixing corrupted dovecot.index.cache files properly; it
    could have deleted wrong mail's cache or assert-crashed
  - v2.2.30 mail-crypt-acl plugin was assert-crashing
  - v2.2.30 welcome plugin wasn't working
  - Various fixes to handling mailbox listing, especially related to handling
    non-existent autocreated/autosubscribed mailboxes and ACLs
  - Global ACL file was parsed as if it was local ACL file, which caused some
    of the ACL rule interactions not to work exactly as intended
  - auth: forward_* fields didn't work properly: only the first forward field
    was working, and only if the first passdb lookup succeeded
  - Using mail_sort_max_read_count sometimes caused "Broken sort-* indexes,
    resetting" errors
  - Using mail_sort_max_read_count may have caused very high CPU usage
  - Message address parsing could have crashed on invalid input
  - imapc_features=fetch-headers wasn't always working correctly and caused
    the full header to be fetched
  - imapc: Various bugfixes related to connection failure handling
  - quota=imapc sent unnecessary FETCH RFC822.SIZE to server when expunging
    mails
  - quota=count: quota_warning = -storage=.. was never executed
  - quota=count: Add support for "ns" parameter
  - dsync: Fix incremental syncing for mails that don't have Date or Message-ID
    headers
  - imap: Fix hang when client sends pipelined SEARCH + EXPUNGE/CLOSE/LOGOUT
  - oauth2: Token validation didn't accept empty server responses
  - imap: NOTIFY command has been almost completely broken since the beginning;
    it seems nobody has been trying to use it
- Update pigeonhole to 0.4.19
  - This release adjusts Pigeonhole to several changes in the Dovecot API,
    making it depend on Dovecot v2.2.31
  - Fixed bug in handling of implicit keep in some cases: implicit
    side-effects, such as assigned flags, were not always applied correctly
  - include extension: Fixed segfault that (sometimes) occurred when the global
    script location was left unconfigured

* Mon Jun 12 2017 Paul Howarth <paul@city-fan.org> - 1:2.2.30.2-1.0.cf
- Update dovecot to 2.2.30.2
  - auth: Multiple failed authentications within short time caused crashes
  - push-notification: OX driver crashed at deinit

* Thu Jun  1 2017 Paul Howarth <paul@city-fan.org> - 1:2.2.30.1-1.0.cf
- Update dovecot to 2.2.30.1
  - quota_warning scripts weren't working in v2.2.30
  - vpopmail still wasn't compiling

* Wed May 31 2017 Paul Howarth <paul@city-fan.org> - 1:2.2.30-1.0.cf
- Update dovecot to 2.2.30
  - auth: Use timing safe comparisons for everything related to passwords; it's
    unlikely that these could have been used for practical attacks, especially
    because Dovecot delays and flushes all failed authentications in 2 second
    intervals, and it could have worked only when passwords were stored in
    plaintext in the passdb
  - master process sends SIGQUIT to all running children at shutdown, which
    instructs them to close all the socket listeners immediately; this way,
    restarting Dovecot should no longer fail due to some processes keeping the
    listeners open for a long time
  - auth: Add passdb { mechanisms=none } to match separate passdb lookup
  - auth: Add passdb { username_filter } to use passdb only if user matches the
    filter (see https://wiki2.dovecot.org/PasswordDatabase)
  - dsync: Add dsync_commit_msgs_interval setting, which attempts to commit the
    transaction after saving this many new messages; because of the way dsync
    works, it may not always be possible if mails are copied or UIDs need to
    change
  - imapc: Support imapc_features=search without ESEARCH extension
  - imapc: Add imapc_features=fetch-bodystructure to pass through remote
    server's FETCH BODY and BODYSTRUCTURE
  - imapc: Add quota=imapc backend to use GETQUOTA/GETQUOTAROOT on the remote
    server
  - passdb imap: Add allow_invalid_cert and ssl_ca_file parameters
  - If dovecot.index.cache corruption is detected, reset only the one corrupted
    mail instead of the whole file
  - doveadm mailbox status: Add "firstsaved" field
  - director_flush_socket: Add old host's up/down and vhost count as parameters
  - More fixes to automatically fix corruption in dovecot.list.index
  - dsync-server: Fix support for dsync_features=empty-header-workaround
  - imapc: Various bugfixes, including infinite loops on some errors
  - IMAP NOTIFY wasn't working for non-INBOX if IMAP client hadn't enabled
    modseq tracking via CONDSTORE/QRESYNC
  - fts-lucene: Fix it to work again with mbox format
  - Some internal error messages may have contained garbage in v2.2.29
  - mail-crypt: Re-encrypt when copying/moving mails and per-mailbox keys are
    used, otherwise the copied mails can't be opened
  - vpopmail: Fix compiling

* Thu Apr 13 2017 Paul Howarth <paul@city-fan.org> - 1:2.2.29.1-1.0.cf
- Update dovecot to 2.2.29.1
  - imapc reconnection fix was forgotten from 2.2.29 release, which also made
    "make check" fail in a unit test
  - dict-sql: Merging multiple UPDATEs to a single statement wasn't actually
    working
  - Fixed building with vpopmail
- Update pigeonhole to 0.4.18
  - imapsieve plugin: Implemented the copy_source_after rule action
  - imapsieve plugin: Added non-standard Sieve environment items for the source
    and destination mailbox
  - multiscript: The execution of the discard script had an implicit "keep",
    rather than an implicit "discard"

* Tue Apr 11 2017 Paul Howarth <paul@city-fan.org> - 1:2.2.29-1.0.cf
- Update dovecot to 2.2.29 (see NEWS for details)
  - Bug fixes include not expanding %%variables in passdb/userdb dict keys; if
    dict was used as the authentication passdb, using specially crafted
    %%variables in the username could be used to cause DoS (CVE-2017-2669)
- Drop support for EOL distributions prior to F-13
  - Drop BuildRoot: and Group: tags
  - Drop explicit buildroot cleaning in %%install section
  - Drop explicit %%clean section
  - BR: quota-devel unconditionally
  - Drop ICE and fallocate64 patches
  - /etc/pam.d/password-auth is always available now

* Wed Mar  1 2017 Paul Howarth <paul@city-fan.org> - 1:2.2.28-1.1.cf
- Update pigeonhole to 0.4.17
  - LDA Sieve plugin: Fixed handling of an early explicit keep during
    multiscript execution: action side-effects and the message snapshot would
    be lost at the final stage where the implicit keep is evaluated, which
    could result in the IMAP flags assigned to the message to be forgotten or
    that headers modified by the "editheader" extension would revert to their
    original state
  - file script storage: Amended the up-to-date time stamp comparison for
    on-disk binaries to include nanoseconds, which will fix problems occurring
    when both binary and script are saved within the same second; this fix is
    ineffective on older systems that have no support for nanoseconds in stat()
    timestamps, which should be pretty rare nowadays
  - file script storage: Improve saving and listing permission error to include
    more details
  - imapsieve plugin: Make sure "INBOX" is upper case in static mailbox rules;
    otherwise, the mailbox name would never match, since matching is performed
    case-sensitively and Dovecot only returns the upper-cased "INBOX"
  - imapsieve plugin: Fixed assert failure occurring when used with virtual
    mailboxes
  - doveadm sieve plugin: Fixed crash when setting Sieve script via attribute's
    string value

* Sat Feb 25 2017 Paul Howarth <paul@city-fan.org> - 1:2.2.28-1.0.cf
- Update dovecot to 2.2.28 (see NEWS for details)
- Update patches as needed

* Sun Feb 12 2017 Paul Howarth <paul@city-fan.org> - 1:2.2.27-3.0.cf
- Rebuilt for https://fedoraproject.org/wiki/Fedora_26_Mass_Rebuild

* Thu Dec 15 2016 Paul Howarth <paul@city-fan.org> - 1:2.2.27-2.0.cf
- Fix big endian issue (#1403760)

* Mon Dec  5 2016 Paul Howarth <paul@city-fan.org> - 1:2.2.27-1.0.cf
- Update dovecot to 2.2.27
  - dovecot.list.index.log rotation sizes/times were changed so that the .log
    file stays smaller and .log.2 is deleted sooner
  - Added mail_crypt plugin that allows encryption of stored emails
    (see http://wiki2.dovecot.org/Plugins/MailCrypt)
  - stats: Global stats can be sent to Carbon server by setting
    stats_carbon_server=ip:port
  - imap/pop3 proxy: If passdb returns proxy_not_trusted, don't send ID/XCLIENT
  - Added generic hash modifier for %%variables:
    %%{<hash algorithm>;rounds=<n>,truncate=<bits>,salt=s>:field}; hash
    algorithm is any of the supported ones, e.g. md5, sha1, sha256, and also
    "pkcs5" is supported using SHA256, e.g. %%{sha256:user} or
    %%{md5;truncate=32:user}
  - Added support for SHA3-256 and SHA3-512 hashes
  - config: Support DNS wildcards in local_name, e.g.
    local_name *.example.com { .. } matches anything.example.com, but not
    multiple.anything.example.com
  - config: Support multiple names in local_name, e.g.
    local_name "1.example.com 2.example.com" { .. }
  - Fixed crash in auth process when auth-policy was configured and
    authentication was aborted/failed without a username set
  - director: If two users had different tags but the same hash, the users may
    have been redirected to the wrong tag's hosts
  - Index files may have been thought incorrectly lost, causing
    "Missing middle file seq=.." to be logged and index rebuild; this happened
    more easily with IMAP hibernation enabled
  - Various fixes to restoring state correctly in un-hibernation
  - dovecot.index files were commonly 4 bytes per email too large; this is
    because 3 bytes per email were being wasted that could have been used for
    IMAP keywords
  - Various fixes to handle dovecot.list.index corruption better
  - lib-fts: Fixed assert-crash in address tokenizer with specific input
  - Fixed assert-crash in HTML to text parsing with specific input (e.g. for
    FTS indexing or snippet generation)
  - doveadm sync -1: Fixed handling mailbox GUID conflicts
  - sdbox, mdbox: Perform full index rebuild if corruption is detected inside
    lib-index, which runs index fsck
  - quota: Don't skip quota checks when moving mails between different quota
    roots
  - search: Multiple sequence sets or UID sets in search parameters weren't
    handled correctly; they were incorrectly merged together
- Update patches as needed
- Add patch to fix broken configure check for mysql_ssl_set
- Add patch to skip some additional tests if there's no ECC support in OpenSSL
- Add patch to fix more configure tests broken with
  -Werror=implicit-function-declaration

* Mon Oct 31 2016 Paul Howarth <paul@city-fan.org> - 1:2.2.26.0-1.0.cf
- Update dovecot to 2.2.26.0
  - Fixed some compiling issues
  - auth: Fixed assert-crash when using NTLM or SKEY mechanisms and multiple
    passdbs
  - auth: Fixed crash when exporting to auth-worker passdb extra fields that
    had empty values
  - dsync: Fixed assert-crash in dsync_brain_sync_mailbox_deinit
- Update pigeonhole to 0.4.16
  - Part of the Sieve extprograms implementation was moved to Dovecot, which
    means that this release depends on Dovecot v2.2.26+
  - ManageSieve: The PUTSCRIPT command now allows uploading empty Sieve
    scripts; there was really no good reason to disallow doing that
  - Sieve vnd.dovecot.report extension:
    - Added a Dovecot-Reporting-User field to the report body, which contains
      the e-mail address of the user sending the report
    - Added support for configuring the "From:" address used in the report
  - LDA sieve plugin: Implemented support for a "discard script" that is run
    when the message is going to be discarded; this allows doing something
    other than throwing the message away for good
  - Sieve vnd.dovecot.environment extension: Added vnd.dovecot.config.*
    environment items; these environment items map to sieve_env_* settings from
    the plugin {} section in the configuration (such values can of course also
    be returned from userdb)
  - Sieve vacation extension: Use the Microsoft X-Auto-Response-Suppress header
    to prevent unwanted responses from and to (older) Microsoft products
  - ManageSieve: Added rawlog_dir setting to store ManageSieve traffic logs;
    this replaces at least partially the rawlog plugin (mimics similar
    IMAP/POP3 change)
  - doveadm sieve plugin: synchronization: Prevent setting file timestamps to
    unix epoch time, which occurred when Dovecot passed the timestamp as
    'unknown' during synchronization
  - Sieve exprograms plugin: Fixed spurious '+' sometimes returned at the end
    of socket-based program output
  - imapsieve plugin: Fixed crash occurring in specific situations
  - Performed various fixes based on static analysis and Clang warnings
- Update old OpenSSL compatibility patch

* Fri Oct 28 2016 Paul Howarth <paul@city-fan.org> - 1:2.2.26-1.0.cf
- Update dovecot to 2.2.26
  - Cumulative bugfix and enhancement release: see NEWS for details
- Add patch to support building on old distributions with OpenSSL < 0.9.8m and
  hence no SSL_clear_options, and also check for EC_KEY_new when deciding
  whether or not to build dcrypt as the existing test for EVP_PKEY_CTX_new_id
  passes on Fedora 12 to 17 and then the build fails due to missing EC support

* Mon Aug  1 2016 Paul Howarth <paul@city-fan.org> - 1:2.2.25-1.1.cf
- Update pigeonhole to 0.4.15
  - vacation extension: The sieve_user_email setting is now used in the check
    for implicit delivery
  - imapsieve plugin: For any mail transaction, the mailbox was opened a second
    time, even if no mailbox rule matched; this was unintentional, useless and
    caused problems when the imapsieve plugin was used with other plugins like
    acl
  - extprograms plugin: Significantly improved error handling; no stream errors
    were logged
  - extprograms plugin: Fixed bug in handling of result code from remote
    program (script service)
  - extprograms plugin: Connection to remote program service was not retried
  - Several small fixes based on static analysis
  - Fixed handling of quoted string localparts in email addresses

* Mon Jul  4 2016 Paul Howarth <paul@city-fan.org> - 1:2.2.25-1.0.cf
- Update dovecot to 2.2.25
  - lmtp: Start tracking lmtp_user_concurrency_limit and reject already at
    RCPT TO stage, which avoids MTA unnecessarily completing DATA only to get
    an error
  - doveadm: Previously, only mail settings were read from protocol doveadm
    { .. } section: now, all settings are
  - quota: Added quota_over_flag_lazy_check setting, which avoids checking
    quota_over_flag always at startup; instead, it's checked only when quota
    is being read for some other purpose
  - auth: Added a new auth policy service:
    http://wiki2.dovecot.org/Authentication/Policy
  - auth: Added PBKDF2 password scheme
  - auth: Added %%{auth_user}, %%{auth_username} and %%{auth_domain}
  - auth: Added ":remove" suffix to extra field names to remove them
  - auth: Added "delay_until=<timestamp>[+<max random secs>]" passdb extra
    field; the auth will wait until <timestamp> and optionally some randomness
    and then return success
  - dict proxy: Added idle_msecs=<n> parameter; support async operations
  - Performance improvements for handling large mailboxes
  - Added lib-dcrypt API for providing cryptographic functions
  - Added "doveadm mailbox update" command
  - imap commands' output now includes timing spent on the "syncing" stage if
    it's larger than 0
  - cassandra: Added metrics=<path> to connect setting to output internal
    statistics in JSON format every second to <path>
  - doveadm mailbox delete: Added -e parameter to delete only empty mailboxes;
    Added --unsafe option to quickly delete a mailbox, bypassing lazy_expunge
    and quota plugins
  - doveadm user and auth cache flush are now available via doveadm-server
  - doveadm service stop <services> will stop specified services while leaving
    the rest of Dovecot running
  - quota optimization: Avoid reading mail sizes for backends that don't need
    them (count, fs, dirsize)
  - Added mailbox { autoexpunge_max_mails=<n> } setting
  - Added welcome plugin: http://wiki2.dovecot.org/Plugins/Welcome
  - fts: Added fts_autoindex_exclude setting
  - v2.2.24's MIME parser was assert-crashing on mails having truncated MIME
    headers
  - auth: With multiple userdbs the final success/failure result wasn't always
    correct: the last userdb's result was always used
  - doveadm backup was sometimes deleting entire mailboxes unnecessarily
  - doveadm: Command -parameters weren't being sent to doveadm-server
  - If dovecot.index read failed e.g. because mmap() reached VSZ limit, an
     empty index could have been opened instead, corrupting the mailbox state
  - imapc: Fixed EXPUNGE handling when imapc_features didn't have modseq
  - lazy-expunge: Fixed a crash when copying failed, plus various other fixes
  - fts-lucene: Fixed crash on index rescan
  - auth_stats=yes produced broken output
  - dict-ldap: Various fixes
  - dict-sql: NULL values crashed; now they're treated as "not found"
- Add patch with upstream fixes for compatibility with old distributions
- Simplify find commands using -delete
- Specify all build requirements

* Thu Apr 28 2016 Paul Howarth <paul@city-fan.org> - 1:2.2.24-1.0.cf
- Update dovecot to 2.2.24
  - doveconf now warns if it sees a global setting being changed when the same
    setting was already set inside some filters (a common mistake has been
    adding more plugins to a global mail_plugins setting after it was already
    set inside protocol { .. }, which caused the global setting to be ignored
    for that protocol)
  - LMTP proxy: Increased default timeout 30s -> 125s, which makes it less
    likely to reach the timeout and cause duplicate deliveries
  - LMTP and indexer now append ":suffix" to session IDs to make it unique for
    the specific user's delivery (fixes duplicate session ID warnings in stats
    process)
  - Added dict-ldap for performing read-only LDAP dict lookups
  - lazy-expunge: All mails can be saved to a single specified mailbox
  - mailbox { autoexpunge } supports now wildcards in mailbox names
  - doveadm HTTP API: Added support for proxy commands
  - imapc: Reconnect when getting disconnected in non-selected state
  - imapc: Added imapc_features=modseq to access MODSEQs/HIGHESTMODSEQ; this is
    especially useful for incremental dsync
  - doveadm auth/user: Auth lookup performs debug logging if -o auth_debug=yes
    is given to doveadm
  - Added passdb/userdb { auth_verbose=yes|no } setting
  - Cassandra: Added user, password, num_threads, connect_timeout and
    request_timeout settings
  - doveadm user -e <value>: Print <value> with %%variables expanded
  - Huge header lines could have caused Dovecot to use too much memory
    (depending on config and used IMAP commands); typically this would result
    in only the single user's process dying with out of memory due to reaching
    service { vsz_limit } - not a global DoS
  - dsync: Detect and handle invalid/stale -s state string better
  - dsync: Fixed crash caused by specific mailbox renames
  - auth: Auth cache is now disabled passwd-file; it was unnecessary and it
    broke %%variables in extra fields
  - fts-tika: Don't crash if it returns 500 error
  - dict-redis: Fixed timeout handling
  - SEARCH INTHREAD was crashing
  - stats: Only a single fifo_listeners was supported, making it impossible to
    use both auth_stats=yes and mail stats plugin
  - SSL errors were logged in separate "Stacked error" log lines instead of as
    part of the disconnection reason
  - MIME body parser didn't handle properly when a child MIME part's --boundary
    had the same prefix as the parent
- Update pigeonhole to 0.4.14
  - The address test now allows specifying the X-Original-To header
  - Implemented the Sieve imapsieve extension and its IMAP counterpart
    (RFC 6785) as a set of plugins, which allows running Sieve scripts at IMAP
    activity, rather than at delivery
  - Adjusted the Sieve ihave extension to allow capability tests to be
    performed at runtime; this way, scripts can be written that work both at
    delivery and from IMAP
  - Implemented support for runtime trace debugging, which works much like the
    Dovecot rawlog facility
  - Added a "sieve_user_email" setting that configures the user's primary email
    address; this is mainly useful to have a user email address available in
    IMAP, where envelope data is unavailable
  - Implemented the dovecot-specific "vnd.dovecot.report" extension, which
    allows sending report messages in the Message Abuse Reporting Format
    (RFC 5965)
  - extprograms plugin: Fixed epoll() panic caused by closing the output FD
    before the output stream
  - Made sure that the local part of a mail address is encoded properly using
    quoted string syntax when it is not a dot-atom
- Update fallocate64 patch

* Thu Mar 31 2016 Paul Howarth <paul@city-fan.org> - 1:2.2.23-1.0.cf
- Update dovecot to 2.2.23
  - Various fixes to doveadm; in particular, running commands via
    doveadm-server was broken
  - director: Fixed user weakness getting stuck in some situations
  - director: Fixed a situation where directors keep re-sending different
    states to each other and never becoming synced
  - director: Fixed assert-crash related to a slow "user killed" reply
  - Fixed assert-crash related to istream-concat, which could have been
    triggered at least by a Sieve script
- Update pigeonhole to 0.4.13
  - redirect action: Added the list-id header to the duplicate ID for mail loop
    prevention; this means that the message sent directly to the user and the
    message coming through the mailing list itself are treated as different
    messages by the loop detection of the redirect command, even though their
    Message-ID may be identical
  - Changed the Sieve number type to uint64_t, which means that Sieve numbers
    can now technically range up to 2^64; some other Sieve implementation
    allowed this, making this change necessary for successful migration
  - Implemented the sieve_implicit_extensions setting; the extensions listed in
    this setting do not need to be enabled explicitly using the Sieve "require"
    command (this behavior directly violates the standard, but can be necessary
    for compatibility with some existing implementations of Sieve - do not use
    this setting unless you really need to!)
  - redirect action: Made mail loop detection more robust by forcibly adding a
    Message-ID header if it is missing
  - Prevent logging a useless "script not found" error message for LDAP scripts
    for which the entry exists but no attribute containing a script; this is not
    necessarily an error
  - extprograms plugin: Changed the communication channel between parent and
    child process for a directly forked program from a socketpair to a double
    pipe; Linux does not support /dev/stdin, /dev/stdout and friends for
    sockets, which for some shell program authors may be confusing, so that is
    why it is changed - when using the script service, these device nodes are
    still not usable though

* Wed Mar 16 2016 Paul Howarth <paul@city-fan.org> - 1:2.2.22-1.0.cf
- Update dovecot to 2.2.22
  - Added doveadm HTTP API: see
    http://wiki2.dovecot.org/Design/DoveadmProtocol/HTTP
  - virtual plugin: Mailbox filtering can now be done based on the mailbox
    metadata - see http://wiki2.dovecot.org/Plugins/Virtual
  - stats: Added doveadm stats reset to reset global stats
  - stats: Added authentication statistics if auth_stats=yes
  - dsync, imapc, pop3c and pop3-migration: Many optimizations, improvements
    and error handling fixes
  - doveadm: Most commands now stop soon after SIGINT/SIGTERM
  - auth: Auth caching was done too aggressively when %%variables were used in
    default_fields, override_fields or LDAP pass/user_attrs; userdb result_*
    were also ignored when user was found from cache
  - imap: Fixed various assert-crashes caused v2.2.20+; some of them caught
    actual hangs or otherwise unwanted behavior towards IMAP clients
  - Expunges were forgotten in some situations, for example when pipelining
    multiple IMAP MOVE commands
  - quota: Per-namespaces quota were broken for dict and count backends in
    v2.2.20+
  - fts-solr: Search queries were using OR instead of AND as the separator for
    multi-token search queries in v2.2.20+
  - Single instance storage support wasn't really working in v2.2.16+
  - dbox: POP3 message ordering wasn't working correctly
  - virtual plugin: Fixed crashes related to backend mailbox deletions
- Update systemd unit file patches
- Use systemd ProtectSystem=full from Fedora 22 onwards

* Thu Feb 11 2016 Paul Howarth <paul@city-fan.org> - 1:2.2.21-4.0.cf
- Update pigeonhole to 0.4.12
  - Implemented the Sieve extracttext extension (RFC 5703; Section 7); it is
    now possible to extract body text from a message into a variable
  - Increased ABI version due to changes in the Sieve interpreter's object
    definitions
  - multiscript: Fixed bug in handling of (implicit) keep; final keep action
    was always executed as though there was a failure, which caused the keep
    action to revert back to the initial message, int turn causing editheader
    actions to be ignored
  - managesieve-login: Fixed proxy to allow SASL mechanisms other than PLAIN;
    previously, the proxy would fail if the server did not support the PLAIN
    mechanism
  - ldap storage: Prevent segfault occurring when assigning certain (global)
    configuration options

* Thu Feb  4 2016 Paul Howarth <paul@city-fan.org> - 1:2.2.21-3.0.cf
- Update pigeonhole to 0.4.11
  - Sieve mime extension: Fixed the header :mime :anychild test to work
    properly outside a foreverypart loop
  - Several fixes in message body part handling:
    - Fixed assert failure occurring when text extraction is attempted on an
      empty or broken text part
    - Fixed assert failure in handling of body parts that are converted to text
    - Fixed header unfolding for (mime) headers parsed from any mime part
    - Fixed trimming for (mime) headers parsed from any mime part
    - Fixed erroneous changes to the message part tree structure performed when
      re-parsing the message
  - LDA Sieve plugin: Fixed logging of actions; sometimes the configured log
    format was not followed
  - LDA Sieve plugin: Fixed bug in error handling of script storage
    initialization
  - Sieve Extprograms plugin: Ignored ENOTCONN error in shutdown(fd, SHUT_WR)
    call
  - Fixed duplication of discard actions in the script result; each discard was
    counted as a separate action, which means that action limit would be
    crossed too early
  - Made sure that quota errors never get logged as errors in syslog
  - Fixed handling of implicit keep for a partially executed transaction that
    yielded a temporary failure
  - Fixed handling of global errors; if master and user error handler were
    identical, in some cases the log message could be lost
  - Fixed AIX compile issue in message body parser

* Mon Dec 14 2015 Paul Howarth <paul@city-fan.org> - 1:2.2.21-1.0.cf
- Update dovecot to 2.2.21
  - doveadm mailbox list (and some others) were broken in v2.2.20
  - director: Fixed making backend changes when running with only a single
    director server
  - virtual plugin: Fixed crash when trying to open nonexistent autocreated
    backend mailbox
- Update pigeonhole to 0.4.10
  - Implemented the Sieve mime and foreverypart extensions (RFC 5703); the
    interaction with the editheader extension needs some work, but this should
    not influence most uses, i.e., changes by the editheader extension are not
    always visible using foreverypart/mime
  - Sieve body extension: Properly implemented the `:text' body transform; it
    now extracts text for HTML message parts
  - Sieve enotify extension: mailto method: Implemented the
    sieve_notify_mailto_envelope_from setting, which allows configuring the
    source of the notification sender address for e-mail notifications; this is
    similar to what already can be configured for redirect
  - Added a sieve_enabled (defaults to 'yes') setting that allows explicitly
    disabling Sieve processing for particular users; this used to be possible
    by setting 'sieve=', but ever since the sieve_before, sieve_after and
    sieve_default settings were added, this method was no longer reliable
  - variables extension: Fixed handling of empty string by the ':length' set
    modifier; an empty string yielded an empty string rather than "0"
  - Fixed memory leak in the Sieve script byte code dumping facility; extension
    contexts were never actually freed
  - Fixed handling of implicit keep when the last Sieve script is a global one;
    in that case the implicit keep action was executed in global context, which
    could mean that trivial (quota) errors ended up in the system log file,
    rather than the user log file
  - doveadm sieve plugin: Fixed crashes caused by incorrect context allocation
    in the sieve command implementations

* Tue Dec  8 2015 Paul Howarth <paul@city-fan.org> - 1:2.2.20-1.0.cf
- Update dovecot to 2.2.20
  - Added mailbox { autoexpunge=<time> } setting; see
    http://wiki2.dovecot.org/MailboxSettings for details
  - ssl_options: Added support for no_ticket
  - imap/pop3/managesieve-login: Added postlogin_socket=path passdb extra
    field; this allows replacing the default service imap/pop3/managesieve {}
    settings for specific users (e.g. running their imap process via valgrind
    or strace)
  - doveadm fetch: Added date.sent/received/saved.unixtime
  - fs-posix: Added mode=auto parameter to set the created files' and
    directories' mode based on the parent dir if it has setgid-bit
  - director: Support backends having hostnames, which makes it possible to
    verify their SSL certificates
  - director: Directors' state became desynchronized if doveadm director
    commands were used to modify the same backend in multiple directors at the
    same time with conflicting changes; this fix includes some extra checks,
    which makes sure that if such a conflict still happens it's automatically
    fixed, though in some situations such an automatic fix may now be
    unnecessarily triggered and an error logged
  - director: Backend tags weren't working correctly
  - ldap: tls_* settings weren't used for ldaps URIs
  - ldap, mysql: Fixed setting connect timeout
  - auth: userdb lookups via auth-worker couldn't change username
  - dsync: Fixed handling deleted directories; make sure we don't go to
    infinite mailbox renaming loop
  - imap: Fixed crash in NOTIFY when there were watched namespaces that didn't
    support NOTIFY
  - imap: After SETMETADATA was used, various commands (especially FETCH)
    could have started hanging when their output was large
  - stats: Idle sessions weren't refreshed often enough, causing stats process
    to forget them and log errors about unknown sessions when they were updated
    later
  - stats: Fixed "Duplicate session ID" errors when LMTP delivered to multiple
    recipients and fts_autoindex=yes
  - zlib plugin: Fixed copying causing cache corruption when zlib_save wasn't
    set, but the source message was compressed
  - fts-solr: Fixed escaping Solr query parameters
  - lmtp: quota_full_tempfail=yes was ignored with lmtp_rcpt_check_quota=yes

* Mon Oct  5 2015 Paul Howarth <paul@city-fan.org> - 1:2.2.19-1.0.cf
- Update dovecot to 2.2.19
  - pop3_deleted_flag has been broken since v2.2.10, and using it would cause
    buffer overflows, which could be exploitable; however, this bug would have
    become visible quite soon after users had deleted some POP3 mails, because
    the pop3 processes would have started crashing all the time even in normal
    use
  - "doveadm director flush" command has a changed meaning now: it safely
    moves users to their wanted backends, instead of simply forgetting the
    mapping entirely and leaving the existing connections untouched; use the
    -F parameter to get the original unsafe behavior
  - Added imap-hibernate processes (see imap_hibernate_timeout setting);
    IDLEing IMAP connections can be hibernated, which saves memory
  - Optimized tracking mailboxes' vsizes (= sum of all messages' sizes); if
    mailbox_list_index=yes, it's also stored in there, which makes it very
    efficient to look up vsizes for all mailboxes
  - Added a quota "count" backend, which uses the mailbox vsizes to get the
    current quota usage; it requires using the new quota_vsizes=yes setting,
    which tracks the messages' "virtual sizes" rather than "physical sizes"
    (their distinction is minor and mostly irrelevant nowadays - if mail sizes
    should be counted with LF or CRLF newlines)
  - "doveadm director up/down" commands added; the monitoring script should be
    using these commands instead of changing the vhost count, which allows
    admin to manually disable a server by changing the vhost count to 0 without
    the monitoring script changing it back
  - Added support for HAProxy protocol: http://wiki2.dovecot.org/HAProxy
  - Added push-notification plugin framework, which can be used to easily
    implement push notifications to various backends; implemented "ox" backend
    for notifying Open-Xchange via HTTP/json
  - imap_logout_format supports more variables now, e.g. number of deleted
    messages
  - pop3: Added pop3_delete_type setting (related to pop3_deleted_flag)
  - plugin { fts_enforced=yes } setting now fails body searches unless it can
    be done via the full text search engine
  - Added %%{passdb:*} and %%{userdb:*} variables to various places
  - auth: Added ":protected" suffix for passdb and userdb fields; if used, the
    field doesn't overwrite an existing field
  - IMAP/POP3 proxy: If a backend server dies, avoid client reconnection spikes
    by slowly disconnecting clients over time; this is enabled by setting
    login_proxy_max_disconnect_delay=secs passdb extra field
  - imap: Added new read-only METADATA entries: /private/specialuse,
    /shared/comment, /shared/admin
  - imap: If client disconnects in the middle of a command, log how long the
    command had been running
  - mdbox: Rebuilding could have caused message's reference count to overflow
    the 16bit number in some situations, causing problems when trying to
    expunge the duplicates
  - Various search fixes (fts, solr, tika, lib-charset, indexer)
  - Various virtual plugin fixes
  - Various fixes and optimizations to dsync, imapc and pop3-migration
  - imap: Various RFC compliancy and crash fixes to NOTIFY
- Update pigeonhole to 0.4.9
  - Properly implemented checking of ABI version for Sieve interpreter plugins,
    much like Dovecot itself does for plugins; this will prevent plugin ABI
    mismatches
  - Implemented a vnd.dovecot.environment extension; this builds upon the
    standard environment extension and adds a few more environment items, such
    as username and default mailbox, and also creates a variables namespace so
    that environment items can be accessed directly
  - Sieve extprograms plugin: Made line endings of the input passed to the
    external programs configurable; this can be configured separately for each
    of the three extensions
  - ManageSieve: Implemented proxy XCLIENT support; this allows the proxy to
    pass client information to the back-end
  - ManageSieve: Fixed an assert failure occurring when a client disconnects
    during the GETSCRIPT command
  - doveadm sieve plugin: Fixed incorrect initialization of mail user; this
    caused a few memory leaks
  - sieve-filter command line tool: Fixed handling of failure-related implicit
    keep when there is an explicit default destination folder; this caused
    message duplication
  - lib-sieve: Fixed bug in RFC5322 header folding, in which words longer than
    the optimal line length caused empty lines in the output, which would break
    the resulting message header; this surfaced in References: headers with
    very long message IDs
- Work around internal compiler error in test-timing.c on x86_64 + Fedora < 9
- Update patches as needed

* Mon Aug 31 2015 Paul Howarth <paul@city-fan.org> - 1:2.2.18-5.0.cf
- Use the system crypto policy from F-21 onwards (#1109114)

* Fri Jun 19 2015 Paul Howarth <paul@city-fan.org> - 1:2.2.18-4.0.cf
- Fix build for s390x and ppc64 (#1232650)

* Tue May 19 2015 Paul Howarth <paul@city-fan.org> - 1:2.2.18-2.0.cf
- Rebuild

* Mon May 18 2015 Paul Howarth <paul@city-fan.org> - 1:2.2.18-1.0.cf
- Update dovecot to 2.2.18
  - director: Login UNIX sockets were normally detected as doveadm or director
    ring sockets, causing it to break in existing installations
  - sdbox: When copying a mail in alt storage, place the destination to alt
    storage as well
- Update pigeonhole to 0.4.8
  - LDA Sieve plugin: Dovecot changed the deliver_log_format setting to include
    %%{delivery_time}; this prompted changes in Pigeonhole that make this
    release dependent on Dovecot ≥ v2.2.17
  - Implemented magic to make sieve_default script visible from ManageSieve
    under a configurable name, so users can see the default rules, edit them
    and store a private adjusted version; this could also be achieved by
    copying the default script into the user's script storage, but updates to
    the global sieve_default script would be ignored that way
  - ManageSieve: Implemented support for reporting command statistics at
    disconnect; statistics include the number of bytes and scripts uploaded/
    downloaded/checked and the number of scripts deleted/renamed
  - Fixed problem in address test: erroneously decoded mime-encoded words in
    address headers
  - extprograms plugin: Fixed failure occurring when connecting to script
    service without the need to read back the output from the external program
  - Fixed bug in script storage path normalization occurring with relative
    symbolic links below root
  - Fixed and updated various parts of the documentation
  - ManageSieve: Used "managesieve" rather than "sieve" as login service name,
    which means that all managesieve-specific settings were ignored
  - Managesieve: Storage quota was not always enforced properly for scripts
    uploaded as quoted string; nobody uses that, but it is allowed in the
    specification and we support it, so it should work properly
- Update fallocate64 patch

* Thu May 14 2015 Paul Howarth <paul@city-fan.org> - 1:2.2.17-1.0.cf
- Update dovecot to 2.2.17
  - Dovecot no longer checks or warns if a mountpoint is removed
  - Make sure that all the mountpoints that Dovecot accesses aren't writable
    by mail processes when they're unmounted
  - dict server wasn't properly escaping/unescaping data; fixing this broke
    backwards compatibility with data that contains line feeds, and hopefully
    affects only very few installations: if you're using dict to save
    multiline data (Sieve scripts to SQL), you may be affected
  - imap: SPECIAL-USE capability is no longer advertised if there are no
    special_use flags specified for any mailboxes
  - lmtp: Added lmtp_hdr_delivery_address setting to specify whether to
    include email address in Delivered-To: and Received: headers
  - Added initial version of full text search library, which includes
    language-specific text normalization and filtering; this is still in
    development, but it's already possible to use for testing with fts-lucene
    and fts-solr
  - lda, lmtp: deliver_log_format can now include %%{delivery_time}, which
    expands to how many milliseconds it took to deliver the mail
  - With LMTP, %%{session_time} also expands to how many milliseconds the LMTP
    session took, not including the delivery time
  - lmtp proxy: Mail delivery logging includes timing information
  - imap: Most IMAP commands now include in the tagged reply how many
    milliseconds it took to run the command (not counting the time spent on
    waiting for the IMAP client to read/write data)
  - director: Implemented director_proxy_maybe passdb extra field to be able
    to run director and backend in the same Dovecot instance (LMTP doesn't
    support mixed proxy/non-proxy destinations currently)
  - doveadm: Added -F <file> parameter to read a list of users from the given
    file and run the command for all the users; this is similar to -A
    parameter reading the list of users from userdb lookup
  - Implemented initial Cassandra CQL support as lib-sql backend; it's only
    usable as dict backend currently
  - Added quota-clone plugin to copy current quota usage to a dict
  - auth: If auth_master_user_separator was set, auth process could be crashed
    by trying to log in with empty master username
  - imap-login, pop3-login: Fixed crash on handshake failures with new OpenSSL
    versions (v1.0.2) when SSLv3 was disabled
  - auth: If one passdb fails allow_nets check, it shouldn't have failed all
    the other passdb checks later on
  - imap: Server METADATA couldn't be accessed
  - imapc: Fixed \Muted label handling in gmail-migration
  - imapc: Various bugfixes and improvements
  - Trash plugin fixes by Alexei Gradinari
  - mbox: Fixed crash/corruption in some situations
- Update pigeonhole to 0.4.7
  - editheader extension: Made protection against addition and deletion of
    headers configurable separately; also, the 'Received' and 'Auto-Submitted'
    headers are no longer protected against addition by default
  - Turned message envelope address parse errors into warnings
  - The interpreter now accepts non-standard domain names, e.g. containing '_'
  - Implemented the Sieve index extension (RFC 5260)
  - Implemented support for the mboxmetadata and servermetadata extensions
    (RFC 5490)
  - Implemented new sieve commands for the doveadm command line utility; these
    commands are currently limited to ManageSieve operations, but the other
    current sieve tools will be migrated to doveadm in the near future as well
  - Added more debug output about binary up-to-date checking
  - Added script metadata to binary dump output
  - Fixed Sieve script binary up-to-date checking by normalizing the script
    location
  - The Sieve interpreter now flushes the duplicate database during start phase
    of result execution rather than commit phase; this makes sure locks on the
    duplicate database are released as soon as possible, preventing contention
  - Performed a few optimizations in the lexical scanner of the language
  - Fixed bug in ':matches' match-type that made a pattern without wildcards
    match as if there were a '*' at the beginning
  - Fixed crash in validation of the string parameter of the comparator tag
  - extprograms extension: Made sure supplemental group privileges are also
    dropped; this was a problem reported by Debian lintian
  - Fixed bug in handling of binary errors for action side-effects and message
    overrides
  - file script storage: Restructured storage initialization to address
    backwards compatibility issues
  - dict script storage: Fixed small memory allocation bug

* Thu Apr 30 2015 Paul Howarth <paul@city-fan.org> - 1:2.2.16-2.0.cf
- Fix CVE-2015-3420: SSL/TLS handshake failures leading to a crash of the login
  process

* Fri Mar 13 2015 Paul Howarth <paul@city-fan.org> - 1:2.2.16-1.0.cf
- Update dovecot to 2.2.16
  - dbox: Resyncing (e.g. doveadm force-resync) no longer deletes the
    dovecot.index.cache file; the cache file was rarely the problem so this
    just caused unnecessary slowness
  - Mailbox name limits changed during mailbox creation: each part of a
    hierarchical name (e.g. "x" or "y" in "x/y") can now be up to 255 chars
    long (instead of 200)
    This also reduces the max number of hierarchical levels to 16 (instead of
    20) to keep the maximum name length 4096 (a common PATH_MAX limit); the
    255 char limit is hopefully large enough for migrations from all existing
    systems and it's also the limit on many filesystems
  - director: Added director_consistent_hashing setting to enable consistent
    hashing (instead of the mostly-random MD5 hashing); this causes fewer user
    moves between backends when backend counts are changed, which may improve
    performance (mainly due to caching)
  - director: Added support for "tags", which allows one director ring to
    serve multiple backend clusters with different sets of users
  - LMTP server: Added lmtp_user_concurrency_limit setting to limit how many
    LMTP deliveries can be done concurrently for a single user
  - LMTP server: Added support for STARTTLS command
  - If logging data is generated faster than it can be written, log a warning
    about it and show information about it in log process's process title in
    ps output; also don't allow a single service to flood too long at the cost
    of delaying other services' logging
  - stats: Added support for getting global statistics
  - stats: Use the same session IDs as the rest of Dovecot
  - stats: Plugins can now create their own statistics fields
  - doveadm server: Non-mail related commands can now also be used via doveadm
    server (TCP socket)
  - doveadm proxying: passdb lookup can now override doveadm_port and change
    the username
  - doveadm: Search query supports now "oldestonly" parameter to stop
    immediately on the first non-match; this can be used to optimize:
    doveadm expunge mailbox Trash savedbefore 30d oldestonly
  - doveadm: Added "save" command to directly save mails to specified mailbox
    (bypassing Sieve)
  - doveadm fetch: Added body.snippet field, which returns the first 100 chars
    of a message without whitespace or HTML tags; the result is stored into
    dovecot.index.cache, so it can be fetched efficiently
  - dsync: Added -t <timestamp> parameter to sync only mails newer than the
    given received-timestamp
  - dsync: Added -F [-]<flag> parameter to sync only mails with[out] the given
    flag/keyword
  - dsync: Added -a <mailbox> parameter to specify the virtual mailbox
    containing user's mails; if this mailbox is already found to contain the
    wanted mail (by its GUID), the message is copied from there instead of
    being re-saved (this isn't efficient enough yet for incremental
    replication)
  - dsync: -m parameter can now specify \Special-use names for mailboxes
  - imapc: Added imapc_features=gmail-migration to help migrations from GMail;
    see http://wiki2.dovecot.org/Migration/Gmail
  - imapc: Added imapc_features=search to support IMAP SEARCH command
    (currently requires ESEARCH support from remote server)
  - expire plugin: Added expire_cache=yes setting to cache most of the database
    lookups in dovecot index files
  - quota: If overquota-flag in userdb doesn't match the current quota usage,
    execute a configured script
  - redis dict: Added support for expiring keys (:expire_secs=n) and specifying
    the database number (:db=n)
  - auth: Don't crash if master user login is attempted without any configured
    master=yes passdbs
  - Parsing UTF-8 text for mails could have caused broken results sometimes if
    buffering was split in the middle of a UTF-8 character; this affected at
    least searching messages
  - String sanitization for some logged output wasn't done properly: UTF-8 text
    could have been truncated wrongly or the truncation may not have happened
    at all
  - fts-lucene: Lookups from virtual mailbox consisting of over 32 physical
    mailboxes could have caused crashes

* Mon Feb  9 2015 Paul Howarth <paul@city-fan.org> - 1:2.2.15-3.0.cf
- Fix mbox istream crashes (#1189198, #1186504)

* Wed Jan  7 2015 Paul Howarth <paul@city-fan.org> - 1:2.2.15-2.0.cf
- Fix crash related to logging BYE notifications (#1176282)
- Pigeonhole updated to 0.4.6
  - Added support for Japanese mail addresses with dots at non-standard places
    in localpart
  - Changed handling of ENOSPACE into a normal temporary failure and added
    handling of ENOQUOTA as a user error
  - Restructured result execution, so that all actions that involve mail
    storage are always committed before all others
  - Implemented support for generic Sieve storages; using alternative storages
    is also now possible for sieve_before/sieve_after
  - Implemented storage driver for retrieving Sieve scripts from LDAP; this
    cannot currently be used with ManageSieve
  - Implemented sieve_redirect_envelope_from setting, which allows configuring
    the envelope sender of redirected messages
  - Fixed handling of mail storage errors occurring while evaluating the input
    message
  - managesieve-login:
    - Removed bogus ALERT response code returned for AUTHENTICATE command
    - Fixed handling of invalid initial response argument to AUTHENTICATE
      command
  - Fixed handling of stream errors in lexical scanner
  - Fixed handling of SMTP errors; permanent and temporary errors were mixed up
  - Fixed several problems reported by CLang 3.4
  - duplicate extension: fixed erroneous compile error about conflicting tags
    when ':handle' argument was used last
  - relational extension: fixed error handling of `:value' match
  - editheader extension: fixed header unfolding and header iteration
  - mailbox extension: fixed the ':create' tag, which erroneously subscribed an
    existing folder
  - extprograms plugin: fixed handling of error codes
  - doveadm-sieve plugin: fixed several bugs; synchronization of symbolic link
    in the file storage should now also work properly
  - Added a Pigeonhole version banner to doveconf output; this way, future bug
    reports will also include Pigeonhole version information
  - Fixed handling of implicit keep; the last version erroneously reported that
    implicit keep succeeded after an earlier failure, while it in fact had
    failed (particularly occurred for mailbox quota errors)
  - Fixed segfault occurring on SunOS systems when there is no active script
  - After make distclean the distributed tarball would fail to recompile, which
    caused problems for some distribution builds

* Mon Oct 27 2014 Paul Howarth <paul@city-fan.org> 1:2.2.15-1.0.cf
- dovecot updated to 2.2.15
  - plugins can now print a banner comment in doveconf output (typically the
    plugin version)
  - replication plugin now triggers low (instead of high) priority for mail
    copying operations
  - IMAP/POP3/ManageSieve proxy: if destination server can't be connected to,
    retry connecting once per second up to the value of proxy_timeout; this
    allows quick restarts/upgrades on the backend server without returning
    login failures
  - internal passdb lookups (e.g. done by lmtp/doveadm proxy) weren't
    returning failure in some situations where they should have (e.g.
    allow_nets mismatch)
  - LMTP uses mail_log_prefix now for logging mail deliveries instead of a
    hardcoded prefix; the non-delivery log prefix is still hardcoded though
  - passdb allow_nets=local matches lookups that don't contain an IP address
    (internally done by Dovecot services)
  - various debug logging and error logging improvements
  - various race condition fixes to LAYOUT=index
  - v2.2.14 virtual plugin crashed in some situations
- pigeonhole updated to 0.4.3
  - editheader extension: made control characters allowed for editheader,
    except NUL; before, this would cause a runtime error
  - upgraded Dovecot-specific Sieve "vnd.dovecot.duplicate" extension to match
    the new draft "duplicate" extension
  - fixed sieve_result_global_log_error to log only as i_info in administrator
    log (syslog) if executed from multiscript context
  - Sieve redirect extension: adjusted loop detection to show leniency to
    resent messages
  - Sieve include extension: fixed problem with handling of duplicate includes
    with different parameters :once or :optional
  - Sieve spamtest/virustest extensions: tests were erroneously performed
    against the original message; when used together with extprograms filter to
    add the spam headers, the changes were not being used by the spamtest and
    virustest extensions
  - deprecated Sieve notify extension: fixed segfault problems in message
    string substitution
  - ManageSieve: fixed active link verification to handle redundant path
    slashes correctly
  - Sieve vacation extension:
    - fixed interaction of sieve_vacation_dont_check_recipient with
      sieve_vacation_send_from_recipient setting
    - fixed log message for discarded response
  - Sieve extprograms plugin:
    - forgot to disable the alarm() timeouts set for script execution
    - fixed fd leak and handling of output shutdown
    - fixed 'Bad filedescriptor' error occurring when disconnecting script
      client
    - made sure that programs are never forked with root privileges
- add patch to fix crash in pigeonhole test suite
  (http://www.dovecot.org/list/dovecot/2014-October/098472.html)

* Wed Oct 15 2014 Paul Howarth <paul@city-fan.org> 1:2.2.14-1.0.cf
- dovecot updated to 2.2.14
  - lmtp: Delivered-To: header no longer contains <> around the email address;
    Other MDAs don't have it either
  - "Out of disk space" errors are now treated as temporary errors (not the
    same as "Out of disk quota")
  - replication plugin: use replication only for users who have a non-empty
    mail_replica setting
  - lmtp proxy: log a line about each mail delivery
  - Added login_source_ips setting; this can be used to set the source IP
    address round-robin from a pool of IPs (in case you run out of TCP ports)
  - rawlog settings can use tcp:<host>:<port> as the path
  - virtual plugin: don't keep more than virtual_max_open_mailboxes (default
    64) number of backend mailboxes open
  - SSL/TLS compression can be disabled with ssl_options=no_compression
  - acl: global ACL file now supports "quotes" around patterns
  - Added last-login plugin to set user's last-login timestamp on login
  - LDAP auth: allow passdb credentials lookup also with auth_bind=yes
  - IMAP: MODSEQ was sent in FETCH reply even if CONDSTORE/QRESYNC wasn't
    enabled; This broke at least old Outlooks
  - passdb static treated missing password field the same as an empty password
    field
  - mdbox: fixed potential infinite looping when scanning a broken mdbox file
  - imap-login, pop3-login: fixed potential crashes when client disconnected
    unexpectedly
  - imap proxy: the connection was hanging in some usage patterns; this mainly
    affected older Outlooks
  - lmtp proxy: the proxy sometimes delivered empty mails in error situations
    or potentially delivered truncated mails
  - fts-lucene: if whitespace_chars was set, we may have ended up indexing
    some garbage words, growing the index size unnecessarily
  - -c and -i parameters for dovecot/doveadm commands were ignored if the
    config socket was readable
  - quota: quota recalculation didn't include INBOX in some setups
  - mail headers were sometimes added to dovecot.index.cache in the wrong
    order; the main problem this caused was with dsync+imapc incremental
    syncing when the second sync thought the local mailbox had changed
  - fixed several race conditions with dovecot.index.cache handling that may
    have caused unnecessary "cache is corrupted" errors
  - doveadm backup didn't notice if emails were missing from the middle of the
    destination mailbox; now it deletes and resyncs the mailbox
  - auth: if auth client listed userdb and disconnected before finishing, the
    auth worker process got stuck (and eventually all workers could get used up
    and requests would start failing)
- update fallocate64 patch

* Tue Aug 26 2014 Paul Howarth <paul@city-fan.org> 1:2.2.13-4.0.cf
- use network-online target instead of just network (#1119814)

* Tue Aug 19 2014 Paul Howarth <paul@city-fan.org> 1:2.2.13-3.0.cf
- use %%license where possible

* Mon Jun  9 2014 Paul Howarth <paul@city-fan.org> 1:2.2.13-2.0.cf
- rebuilt for https://fedoraproject.org/wiki/Fedora_21_Mass_Rebuild

* Mon May 12 2014 Paul Howarth <paul@city-fan.org> 1:2.2.13-1.0.cf
- dovecot updated to 2.2.13
  - fixed a DoS attack against imap/pop3-login processes; if SSL/TLS handshake
    was started but wasn't finished, the login process attempted to eventually
    forcibly disconnect the client, but failed to do it correctly, which could
    have left the connections hanging around for a long time (affected
    Dovecot v1.1+)
  - mdbox: added mdbox_purge_preserve_alt setting to keep the file within alt
    storage during purge (should become enforced in v2.3.0?)
  - fts: added support for parsing attachments via Apache Tika; enable with:
    plugin { fts_tika = http://tikahost:9998/tika/ }
  - virtual plugin: delay opening backend mailboxes until it's necessary; this
    requires mailbox_list_index=yes to work (currently IMAP IDLE command still
    causes all backend mailboxes to be opened)
  - mail_never_cache_fields=* means now to disable all caching; this may be a
    useful optimization as doveadm/dsync parameter for some admin tasks that
    shouldn't really update the cache file
  - IMAP: return SPECIAL-USE flags always for LSUB command
  - pop3 server was still crashing in v2.2.12 with some settings
  - maildir: various fixes and improvements to handling compressed mails,
    especially when they have broken/missing S=sizes in filenames
  - fts-lucene, fts-solr: fixed crash on search when the index contained
    duplicate entries
  - many fixes and performance improvements to dsync and replication
  - director was somewhat broken when there were exactly two directors in the
    ring; it caused errors about "weak users" getting stuck
  - mail_attachment_dir: attachments with the last base64-encoded line longer
    than the rest wasn't handled correctly
  - IMAP: SEARCH/SORT PARTIAL was handled completely wrong in v2.2.11+
  - acl: global ACL file handling was broken when multiple entries matched the
    mailbox name (only the first entry was used)

* Mon Mar 31 2014 Paul Howarth <paul@city-fan.org> 1:2.2.12-2.0.cf
- rebuild to sync with Rawhide

* Fri Feb 14 2014 Paul Howarth <paul@city-fan.org> 1:2.2.12-1.0.cf
- dovecot updated to 2.2.12
  - pop3 server was crashing in v2.2.11

* Wed Feb 12 2014 Paul Howarth <paul@city-fan.org> 1:2.2.11-1.0.cf
- dovecot updated to 2.2.11
  - acl plugin: added an alternative global ACL file that can contain mailbox
    patterns; see http://wiki2.dovecot.org/ACL for details
  - imap proxy: added proxy_nopipelining passdb setting to work around other
    IMAP servers' bugs (MS Exchange 2013 especially)
  - added %%{auth_user}, %%{auth_username} and %%{auth_domain} variables; see
    http://wiki2.dovecot.org/Variables for details
  - added support for LZ4 compression
  - stats: track also wall clock time for commands
  - pop3_migration plugin improvements to try harder to match the UIDLs
    correctly
  - imap: SEARCH/SORT PARTIAL reponses may have been too large
  - doveadm backup: fixed assert-crash when syncing mailbox deletion
- drop all support for old distributions prior to FC-5:
  - certs in /usr/share/ssl
  - old pam_stack
  - building without solr or sqlite support
  - fixing up broken mysql_config script output

* Sat Dec 21 2013 Paul Howarth <paul@city-fan.org> 1:2.2.10-1.0.cf
- dovecot updated to 2.2.10
  - auth: passdb/userdb dict rewrite to support much more complex setups; see
    doc/example-config/dovecot-dict-auth.conf.ext (the old settings will
    continue to work)
  - auth: added userdb result_success/failure/tempfail and skip settings,
    similar to passdb's; see http://wiki2.dovecot.org/UserDatabase
  - imap: implemented SETQUOTA command for admin user when quota_set is
    configured; see http://master.wiki2.dovecot.org/Quota/Configuration
  - quota: support "*" and "?" wildcards in mailbox names in quota_rules
  - mysql: added ssl_verify_server_cert=no|yes parameter; this currently
    defaults to "no" to make sure nothing breaks, but likely will become "yes"
    in Dovecot v2.3
  - ldap: added blocking=yes setting to use auth worker processes for ldap
    lookups; this is a workaround for now to be able to use multiple
    simultaneous LDAP connections
  - pop3c+dsync performance improvements
  - quota-status: quota_grace was ignored
  - ldap: fixed memory leak with auth_bind=yes and without auth_bind_userdn
  - imap: don't send HIGHESTMODSEQ any more on SELECT/EXAMINE when
    CONDSTORE/QRESYNC has never before been enabled for the mailbox
  - imap: fixes to handling mailboxes without permanent modseqs (when
    [NOMODSEQ] is returned by SELECT, mainly with in-memory indexes)
  - imap: various fixes to METADATA support
  - stats plugin: processes that only temporarily dropped privileges (e.g.
    indexer-worker) may have been logging errors about not being able to open
    /proc/self/io

* Mon Nov 25 2013 Paul Howarth <paul@city-fan.org> 1:2.2.9-1.0.cf
- dovecot updated to 2.2.9
  - full text search indexing can now be done automatically after
    saving/copying mails by setting plugin { fts_autoindex=yes }
  - replicator: added replication_dsync_parameters setting to pass
    "doveadm sync" parameters (for controlling what to replicate)
  - added mail-filter plugin
  - added liblzma/xz support (zlib_save=xz)
  - v2.2.8's improved cache file handling exposed several old bugs related to
    fetching mail headers
  - v2.2.7's iostream handling changes were causing some connections to be
    disconnected before flushing their output (e.g. POP3 logout message wasn't
    being sent)
- drop upstreamed header whitespace patch
- BR: xz-devel for liblzma/xz support

* Wed Nov 20 2013 Paul Howarth <paul@city-fan.org> 1:2.2.8-1.0.cf
- dovecot updated to 2.2.8
  - mail cache lookups work for the mail being saved, which improves
    performance by avoiding the need to parse the mail multiple times when
    using some plugins (e.g. mail_log)
  - mail cache works for recently cached data also with in-memory indexes
  - imapc: many performance improvements, especially when working with dsync;
    also added imapc_feature=fetch-headers, which allows using
    FETCH BODY.PEEK[HEADER.FIELDS (..)] to avoid reading the entire header
  - mail_location = ..:FULLDIRNAME=dbox-Mails is the same as
    :DIRNAME=dbox-Mails, but it will also be used for :INDEX and :CONTROL
    directories (it should have worked this way from the beginning, but can't
    be changed any more without breaking existing installations)
  - fixed infinite loop in message parsing if message ends with "--boundary"
    and CR (without LF); messages saved via SMTP/LMTP can't trigger this,
    because messages must end with an "LF.", but a user could trigger this for
    him/herself though
  - lmtp: client was sometimes disconnected before all the output was sent to it
  - imap_zlib plugin caused crashes during client disconnection in v2.2.7
  - replicator: database wasn't being exported to disk every 15 minutes as it
    should have; instead it was being imported, causing "doveadm replicator
    remove" commands to not work very well
- drop upstreamed infinite loop patch
- add new patch to fix whitespace removal in headers
- package new manpages for doveadm-batch and doveadm-copy

* Thu Nov 14 2013 Paul Howarth <paul@city-fan.org> 1:2.2.7-2.0.cf
- fix ostream infinite loop (#1029906)

* Tue Nov  5 2013 Paul Howarth <paul@city-fan.org> 1:2.2.7-1.0.cf
- dovecot updated to 2.2.7
  - some usage of passdb checkpassword could have been exploitable by local
    users; you may need to modify your setup to keep it working (see
    http://wiki2.dovecot.org/AuthDatabase/CheckPassword#Security)
  - auth: added ability to truncate values logged by auth_verbose_passwords
    (see 10-logging.conf comment)
  - mdbox: added "mdbox_deleted" storage, which can be used to access
    messages with refcount=0
  - ssl-params: added ssl_dh_parameters_length setting
  - master process was doing a hostname.domain lookup for each created process,
    which may have caused a lot of unnecessary DNS lookups
  - dsync: syncing over 100 messages at once caused problems in some
    situations, causing messages to get new UIDs
  - fts-solr: different Solr hosts for different users didn't work

* Tue Oct  1 2013 Paul Howarth <paul@city-fan.org> 1:2.2.6-1.1.cf
- pigeonhole updated to 0.4.2
  - incompatible change in Sieve doveadm plugin: the root attribute for Sieve
    scripts is changed; make sure that you update both sides of a dsync setup
    simultaneously when Sieve is involved, otherwise synchronization will
    likely fail
  - added support for sending Sieve vacation replies with an actual sender,
    rather than the default <> sender
  - fixed a binary code read problem in the `set' command of the Sieve variables
    extension; using the set command with a modifier and an empty string value
    would cause code corruption problems while running the script
  - various fixes for doveadm-sieve plugin, mostly crashes
  - various fixes for compiler and static analyzer warnings, e.g. as reported
    by CLang and on 32 bit systems
  - fixed the implementation of the new :options flag for the Sieve include
    extension
  - fixed potential segfault bug at deinitialization of the lda-sieve plugin
  - fixed messed up hex output for sieve-dump tool

* Wed Sep 25 2013 Paul Howarth <paul@city-fan.org> 1:2.2.6-1.0.cf
- dovecot updated to 2.2.6
  - acl: if public/shared namespace has a shared subscriptions file for all
    users, don't list subscription entries that are not visible to the user
    accessing it
  - doveadm: added "auth lookup" command for doing passdb lookup
  - login_log_format_elements: added %%{orig_user}, %%{orig_username} and
    %%{orig_domain} expanding to the username exactly as sent by the client
    (before any changes auth process made)
  - added ssl_prefer_server_ciphers setting
  - auth_verbose_passwords: log the password also for unknown users
  - Linux: added optional support for SO_REUSEPORT with
    inet_listener { reuse_port=yes }
  - director: v2.2.5 changes caused "SYNC lost" errors
  - dsync: many fixes and error handling improvements
  - doveadm -A: don't waste CPU by doing a separate config lookup for each user
  - long-running ssl-params process no longer prevents Dovecot restart
  - mbox: fixed mailbox_list_index=yes to work correctly

* Thu Aug  8 2013 Paul Howarth <paul@city-fan.org> 1:2.2.5-2.0.cf
- use unversioned doc-dirs (#993731)

* Tue Aug  6 2013 Paul Howarth <paul@city-fan.org> 1:2.2.5-1.0.cf
- dovecot updated to 2.2.5
  - SSL: added support for ECDH/ECDHE cipher suites
  - added some missing man pages
  - quota-status: added quota_status_toolarge setting
  - director: users near expiration could have been redirected to different
    servers at the same time
  - pop3: avoid assert-crash if client disconnects during LIST
  - mdbox: corrupted index header still wasn't automatically fixed
  - dsync: various fixes to work better with imapc and pop3c storages
  - ldap: sasl_bind=yes caused crashes, because Dovecot's lib-sasl symbols
    conflicted with Cyrus SASL library
  - imap: various error handling fixes to CATENATE
- drop upstreamed saslconflict patch

* Tue Jul 30 2013 Paul Howarth <paul@city-fan.org> 1:2.2.4-3.0.cf
- dovecot pigeonhole updated to 0.4.1
  - added support for handling temporary failures; these are passed back to
    LDA/LMTP to produce an appropriate response towards the MTA
  - Sieve storage: removed PATH_MAX limitation for active symlink, which caused
    problems for GNU/Hurd
  - fixed line endings in X-Sieve headers added by redirect command
  - ManageSieve: fixed '[' ']' stupidity for response codes (only happened
    before login)
  - fixed setting name in example-config/conf.d/20-managesieve.conf
  - Sieve extprograms plugin: fixed interaction between pipe command and remote
    script service
  - fixed assertion failure due to datastack problem in message header
    composition

* Wed Jul 10 2013 Paul Howarth <paul@city-fan.org> 1:2.2.4-2.0.cf
- fix name conflict with cyrus-sasl (#975869)

* Tue Jun 25 2013 Paul Howarth <paul@city-fan.org> 1:2.2.4-1.0.cf
- dovecot updated to 2.2.4
  - doveadm: added "flags" command to modify message flags
  - doveadm: added "deduplicate" command to expunge message duplicates
  - dsync: show the state in process title with verbose_proctitle=yes
  - imap/pop3 proxy: master user logins were broken in v2.2.3
  - sdbox/mdbox: a corrupted index header with wrong size was never
    automatically fixed in v2.2.3
  - mbox: fixed assert-crashes related to locking

* Mon Jun 17 2013 Paul Howarth <paul@city-fan.org> 1:2.2.3-1.0.cf
- dovecot updated to 2.2.3
  - LDA/LMTP: if new mail delivery first fails with "temporary failure",
    tempfail the whole delivery instead of falling back to delivering the mail
    to INBOX
  - doc/solr-schema.xml was updated to Solr v4.x format; also, the default
    analyzers were changed, hopefully for the better (note that the schema
    can't be changed for existing Solr indexes without rebuilding everything)
  - Solr plugin does only soft commits from now on; you'll need a cronjob to
    send a hard commit command to it every few minutes
  - added %%N modifier for variables as %%H-like "new hash"
  - sdbox, mdbox: support POP3 message order field (for migrations)
  - added mailbox { driver } to specify a different mail storage format for the
    mailbox than generally used within the namespace
  - added initial lib-sasl library for client side SASL support; it currently
    supports only PLAIN, LOGIN and plugin, and is used currently by IMAP and
    POP3 proxying when authenticating to the remote server
  - IMAP: if subject contained only whitespace, Dovecot returned an ENVELOPE
    reply with a huge literal value, effectively causing the IMAP client to
    wait for more data forever
  - IMAP: various URLAUTH fixes
  - imapc: various bugfixes and improvements
  - pop3c: various fixes to make it work in dsync (without imapc)
  - dsync: fixes to syncing subscriptions and fixes to syncing mailbox renames
- update fallocate64 patch

* Tue May 21 2013 Paul Howarth <paul@city-fan.org> 1:2.2.2-2.0.cf
- use %%{_tmpfilesdir} macro (#964448)
- drop %%defattr, redundant since rpm 4.4

* Mon May 20 2013 Paul Howarth <paul@city-fan.org> 1:2.2.2-1.0.cf
- dovecot updated to 2.2.2
  - zlib: keep the last mail cached uncompressed in a temp file, which fixes
    performance when doing small partial fetches from a large mail
  - acl: if plugin { acl_defaults_from_inbox = yes } is set, get the default
    ACLs for private and shared namespaces from the user's INBOX (this probably
    will become default in v2.3)
  - pop3: added pop3_deleted_flag setting to switch POP3 deletions to only hide
    the messages from POP3, but still be visible via IMAP
  - ACL plugin: mailbox creation wasn't actually checking any ACLs and always
    succeeded (due to some v2.2 API changes); the created mailbox couldn't have
    been accessed though, so this couldn't have caused any data leak
  - IMAP: Various URLAUTH fixes
  - IMAP: Fixed a hang with invalid APPEND parameters
  - IMAP LIST-EXTENDED: INBOX was never listed with \Subscribed flag
  - mailbox_list_index=yes still caused crashes
  - maildir: fixed a crash after dovecot-keywords file was re-read
  - maildir: if files had reappeared unexpectedly to a Maildir, they were
    ignored until index files were deleted
  - maildir: fixed handling over 26 keywords in a mailbox
  - maildir++: fixed mail_shared_explicit_inbox=no
  - namespace { prefix="" list=no } was listing mailboxes
  - imap/pop3-login proxying: fixed a crash if TCP connection succeeded, but
    the remote login timed out
  - case-insensitive search/sort didn't work correctly for all unicode
    characters, as specified by i;unicode-casemap comparator; If full text
    search indexes were used, they need to be rebuilt for old mails to be
    handled correctly (this bug has existed always in Dovecot)
  - config: added missing auth-dict.conf.ext to distribution
- update fallocate64 patch

* Thu May 16 2013 Paul Howarth <paul@city-fan.org> 1:2.2.1-4.0.cf
- update pigeonhole to 0.4.0
  - added doveadm-sieve plugin that provides the possibility to synch Sieve
    scripts using doveadm sync along with the user's mailboxes
  - added the Sieve extprograms plugin to the main Pigeonhole package; it is
    still a plugin, but it is now included so that a separate compile is no
    longer necessary and distributors are likely to include it
  - added debug message showing Pigeonhole version at initialization, which
    makes it very clear that the plugin is properly loaded
  - finished implementation of the Sieve include extension, which should now
    fully conform to RFC 6609; the main addition is the new :optional tag, which
    makes the include command ignore missing included scripts without an error
  - finished implementation of the Sieve environment extension as much as
    possible; environment items "location", "phase" and "domain" now also
    return a usable value

* Mon Apr 29 2013 Paul Howarth <paul@city-fan.org> 1:2.2.1-3.0.cf
- rebuild to stay in sync with Rawhide

* Fri Apr 19 2013 Paul Howarth <paul@city-fan.org> 1:2.2.1-2.0.cf
- avoid perl doc-file dependencies and provides

* Fri Apr 19 2013 Paul Howarth <paul@city-fan.org> 1:2.2.1-1.0.cf
- dovecot updated to 2.2.1
  - mailbox_list_index=yes was broken
  - LAYOUT=index didn't list subscriptions
  - auth: multiple master passdbs didn't work
  - Message parsing (e.g. during search) crashed when multipart message didn't
    actually contain any parts

* Sat Apr 13 2013 Paul Howarth <paul@city-fan.org> 1:2.2.0-1.0.cf
- dovecot updated to 2.2.0
  - when creating home directories, the permissions are copied from the parent
    directory if it has setgid-bit set; for full details, see
    http://wiki2.dovecot.org/SharedMailboxes/Permissions
  - "doveadm auth" command was renamed to "doveadm auth test"
  - IMAP: ID command now advertises server name as Dovecot by default; it was
    already trivial to guess this from command replies
  - dovecot.index.cache files can be safely accessed only by v2.1.11+; older
    versions may think they're corrupted and delete them
  - LDA/LMTP: if saving a mail brings user from under quota to over quota,
    allow it based on quota_grace setting (default: 10% above quota limit)
  - pop3_lock_session=yes now uses a POP3-only dovecot-pop3-session.lock file
    instead of actually locking the mailbox (and causing IMAP/LDA/LMTP to wait
    for the POP3 session to close)
  - mail_shared_explicit_inbox setting's default switched to "no"
  - ssl_client_ca_dir setting replaced imapc_ssl_ca_dir and pop3c_ssl_ca_dir
    settings
  - implemented IMAP MOVE and BINARY extensions
  - implemented IMAP CATENATE, URLAUTH and URLAUTH=BINARY extensions
  - implemented IMAP NOTIFY extension (requires mailbox_list_index=yes to be
    enabled)
  - redesigned and rewritten dsync, making the syncing faster, more reliable
    and more featureful; the new dsync protocol isn't backwards compatible with
    old dsync versions (but is designed to be forwards compatible with future
    versions)
  - all mailbox formats now support per-user message flags for shared mailboxes
    by using a private index
  - improved mailbox list indexes; they should be usable now, although still
    disabled by default
  - added LAYOUT=index; the mailbox directories are created using their GUIDs
    in the filesystem, while the actual GUID <-> name mapping exists only in
    the index
  - LMTP proxy: implemented XCLIENT extension for passing remote IP address
    through proxy
- include state directory /var/run/dovecot/token-login
- drop support for distributions prior to FC-5, which don't clear out subdirs
  of /var/run at boot time

* Thu Apr 11 2013 Paul Howarth <paul@city-fan.org> 1:2.2-0.7.0.rc7.cf
- dovecot updated to 2.2 RC7
  - checkpasword: AUTH_PASSWORD environment is no longer set
  - running dsync no longer triggers quota warnings
  - dsync: commit large transactions every 100 new messages, so if a large sync
    crashes it doesn't have to be restarted from the beginning
  - replicator: doveadm commands and user list export may have skipped some
    users
  - various fixes to mailbox_list_index=yes
- make sure dovecot executables are hardened

* Mon Apr  8 2013 Paul Howarth <paul@city-fan.org> 1:2.2-0.6.0.rc6.cf
- dovecot updated to 2.2 RC6
  - replicator: Don't create replicator-doveadm socket by default; this way
    doveadm replicator commands don't accidentally start an unconfigured
    replicator server
  - replicator: have remote dsync notify the remote replicator that a user was
    just synced; this way the replicators are kept roughly in sync
  - added ssl_client_ca_file to specify the CA certs as a file; this is needed
    (instead of ssl_client_ca_dir) in RedHat-based systems
  - added "doveadm fs" commands, mainly to debug lib-fs backends
  - mailbox list indexes weren't using proper file permissions based on the
    root directory

* Sun Apr  7 2013 Paul Howarth <paul@city-fan.org> 1:2.2-0.5.0.rc5.cf
- dovecot updated to 2.2 RC5
  - a few small random fixes

* Fri Apr  5 2013 Paul Howarth <paul@city-fan.org> 1:2.2-0.4.0.rc4.cf
- dovecot updated to 2.2 RC4
  - added 'doveadm replicator' commands
  - larger changes to lib-http and lib-ssl-iostream error handling; the API
    caller can now get the exact error message as a string
  - various bugfixes to LDAP changes in rc3

* Wed Mar 27 2013 Paul Howarth <paul@city-fan.org> 1:2.2-0.3.0.rc3.cf
- dovecot updated to 2.2 RC3
  - dsync: support syncing ACLs (and Sieve scripts with Pigeonhole)
  - ldap: support subqueries and value pointers - see
    http://wiki2.dovecot.org/AuthDatabase/LDAP/Userdb
  - postmaster_address setting: expand %%d to recipient's domain
  - fixed a crash when decoding quoted-printable content
  - dsync: various bugfixes
- update fallocate64 patch

* Fri Mar  1 2013 Paul Howarth <paul@city-fan.org> 1:2.2-0.2.0.rc2.cf
- do not print error when NetworkManager is not installed (#916456)

* Wed Feb 27 2013 Paul Howarth <paul@city-fan.org> 1:2.2-0.1.0.rc2.cf
- major update to dovecot 2.2 RC2
- update patches as needed

* Sun Feb 10 2013 Paul Howarth <paul@city-fan.org> 1:2.1.15-1.0.cf
- dovecot updated to 2.1.15:
  - v2.1.14: dovecot.index.cache fixes caused it to use more disk I/O and
    memory than necessary

* Thu Feb  7 2013 Paul Howarth <paul@city-fan.org> 1:2.1.14-2.0.cf
- do relro-hardened build from F-16 onwards
- use %%{_unitdir} macro for systemd unit file directory

* Thu Jan 31 2013 Paul Howarth <paul@city-fan.org> 1:2.1.14-1.0.cf
- dovecot updated to 2.1.14:
  - doveadm acl recalc command added
  - v2.1.11+ had a race condition where it sometimes overwrote data in the
    dovecot.index.cache file, which could have caused Dovecot to return the
    same cached data to two different messages
  - mdbox: fixes for handling of duplicate GUIDs during index rebuild
- update fallocate64 patch

* Mon Jan  7 2013 Paul Howarth <paul@city-fan.org> 1:2.1.13-1.0.cf
- dovecot updated to 2.1.13:
  - some fixes to cache file changes in v2.1.11
  - fts-solr: overlong UTF8 sequences in mails were rejected by Solr and caused
    the mails to not be indexed
  - virtual storage: sorting mailbox by from/to/cc/bcc didn't work

* Fri Nov 30 2012 Paul Howarth <paul@city-fan.org> 1:2.1.12-1.0.cf
- dovecot updated to 2.1.12:
  - dovecot-config in v2.1.11 caused build problems with Pigeonhole

* Thu Nov 29 2012 Paul Howarth <paul@city-fan.org> 1:2.1.11-1.0.cf
- dovecot updated to 2.1.11:
  - lmtp/lda: dovecot.index.cache file is no longer fully mapped to memory,
    allowing mail deliveries to work even if the file is huge
  - auth: userdb passwd lookups are now done by auth worker processes instead
    of auth master process (as it was documented, but accidentally didn't work
    that way)
  - lmtp: lmtp_rcpt_check_quota=yes setting checks quota on RCPT TO
  - lmtp: after successful proxying RCPT TO, the next one to a nonexistent user
    gave tempfail error instead of "user not found"
  - lmtp proxy: fixed hanging if remote server was down
  - imap: fixed crash when SEARCH contained multiple KEYWORD parameters
  - doveadm: various fixes to handling doveadm-server connections
  - -i <instance name> parameter for Dovecot tools didn't work correctly
  - director was somewhat broken in v2.1.10; this version also includes various
    reliability enhancements
  - auth: passdb imap was broken in v2.1.10
- update fallocate64 patch

* Tue Nov 20 2012 Paul Howarth <paul@city-fan.org> 1:2.1.10-4.0.cf
- do not crash during mail search (#861742)
- fix bogus dates in spec changelog entries

* Mon Nov 12 2012 Paul Howarth <paul@city-fan.org> 1:2.1.10-3.0.cf
- fix network still not ready race condition (#871623)

* Sun Nov  4 2012 Paul Howarth <paul@city-fan.org> 1:2.1.10-2.0.cf
- add reload command to service file
- disable PrivateTmp prior to F-18 (#851131)

* Wed Sep 19 2012 Paul Howarth <paul@city-fan.org> 1:2.1.10-1.0.cf
- dovecot updated to 2.1.10:
  - imap: implemented THREAD=ORDEREDSUBJECT extension
  - added "doveadm exec" command to easily execute commands from libexec_dir,
    e.g. "doveadm exec imap -u user@domain"
  - added "doveadm copy" command
  - doveadm copy/move: added optional user parameter to specify the source
    username; this allows easily copying mails between different users
  - added namespace { disabled } setting to quickly enable/disable namespaces;
    this is especially useful when its value is returned by userdb
  - added mailbox_alias plugin, which allows creating mailbox aliases using
    symlinks
  - imapc storage: added imapc_max_idle_time setting to force activity on
    connection
  - fts-solr: expunging multiple messages is now faster
  - director: in some conditions director may have disconnected from another
    director (without logging about it), thinking it was sending invalid data
  - imap: various fixes to listing mailboxes
  - pop3-migration plugin: avoid disconnection from POP3 server due to idling
  - login processes crashed if there were a lot of local {} or remote {}
    settings blocks
- pigeonhole updated to 0.3.3:
  - sieve-refilter tool: improved man page documentation by explicitly
    specifying the syntax used for mailbox arguments
  - sieve: spamtest and virustest extensions: improved trace debugging of score
    calculation
  - sieve: made error messages about exceeding the maximum number of actions
    more verbose
  - sieve tools: fixed problems with running as root: sievec and sieve-dump now
    ignore mail_uid and mail_gid settings when run as root.
  - sieve: fixed bug in action accounting (for limit checking): increase action
    instance count only when an action is actually created
  - sieve: include extension: fixed namespace separation of :global and
    :personal scripts
  - managesieve: fixed segfault bug triggered by CHECKSCRIPT command
  - fixed linking with ld.gold
  - fixed several Clang compile warnings and a few potential bugs

* Sun Aug 19 2012 Paul Howarth <paul@city-fan.org> 1:2.1.9-2.0.cf
- rebuild

* Thu Aug  2 2012 Paul Howarth <paul@city-fan.org> 1:2.1.9-1.0.cf
- dovecot updated to 2.1.9:
  - mail-log plugin: log mailbox names with UTF-8 everywhere (instead of mUTF-7
    in some places and UTF-8 in other places)
  - director: changed director_username_hash setting's default from %%u to %%Lu
    (= lowercase usernames); this doesn't break any existing installations, but
    might fix some of them
  - doveadm: added "auth cache flush [<username>]" command
  - implemented dict passdb/userdb
  - implemented Redis and memcached dict backends, which can be used as auth
    backends; Redis can also be used as dict-quota backend
  - added plugin { quota_ignore_save_errors=yes } setting to allow saving a
    mail when quota lookup fails with temporary failure
  - full text search indexing might have failed for some messages, always
    causing indexer-worker process to run out of memory
  - fts-lucene: fixed handling SEARCH HEADER FROM/TO/SUBJECT/CC/BCC when the
    header wasn't lowercased
  - fts-squat: fixed crash when searching a virtual mailbox
  - pop3: fixed assert crash when doing UIDL on empty mailbox on some setups
  - auth: GSSAPI RFC compliancy and error handling fixes
  - various fixes related to handling shared namespaces

* Tue Jul 24 2012 Paul Howarth <paul@city-fan.org> 1:2.1.8-3.0.cf
- rebuilt for https://fedoraproject.org/wiki/Fedora_18_Mass_Rebuild

* Wed Jul  4 2012 Paul Howarth <paul@city-fan.org> 1:2.1.8-2.1.cf
- move tmpfiles.d config from %%{_sysconfdir} to %%{_prefix}/lib

* Tue Jul  3 2012 Paul Howarth <paul@city-fan.org> 1:2.1.8-2.0.cf
- dovecot updated to 2.1.8:
  - pop3c: added pop3c_master_user setting
  - imap: mailbox names were accidentally sent as UTF-8 instead of mUTF-7 in
    previous v2.1.x releases for STATUS, MYRIGHTS and GETQUOTAROOT commands
  - lmtp proxy: don't timeout connections too early when mail has a lot of
    RCPT TOs
  - director: don't crash if the director is working alone
  - shared mailboxes: avoid doing "@domain" userdb lookups
  - doveadm: fixed crash with proxying some commands
  - fts-squat: fixed handling multiple SEARCH parameters
  - imapc: fixed a crash when message had more than 8 keywords
  - imapc: don't crash on APPEND/COPY if server doesn't support UIDPLUS
- pigeonhole updated to 0.3.1:
  - added support for retrieving Sieve scripts from dict lookup
  - incorporated the sieve_duplicate plugin into main Pigeonhole tree as a
    normal extension (vnd.dovecot.duplicate)
  - added support for specifying multiple sieve_before and sieve_after paths
  - added a "session ID" string for managesieve connections, available in
    %%{session} variable (analogous to Dovecot change)
  - fixed several small issues, including a few potential segfault bugs, based
    on static source code analysis
  - ManageSieve: changed use of EPROTO error to EIO in ManageSieve string stream
    implementation because it is apparently not known in BSD
  - gave stamp.h.in (needed for autotools) some content to prevent it from
    disappearing in patch files
  - fixed bug that caused a SunStudio CC compile failure
- update fallocate64 patch

* Mon Jul  2 2012 Paul Howarth <paul@city-fan.org> 1:2.1.7-5.0.cf
- make quota work with NFS-mounted mailboxes (F-10, EL-6 onwards)

* Fri Jun 22 2012 Paul Howarth <paul@city-fan.org> 1:2.1.7-4.0.cf
- do not let dovecot run during upgrade (#134325)

* Wed May 30 2012 Paul Howarth <paul@city-fan.org> 1:2.1.7-2.0.cf
- dovecot updated to 2.1.7:
  - LDAP: compatibility fix for v2.0 - if attributes contain
    ldapAttr=key=template%$ and ldapAttr doesn't exist, skip the key instead
    of using "template" value with empty %$ part for the key
  - pop3: added pop3_uidl_duplicates setting for changing the behavior for
    duplicate UIDLs
  - director: added "doveadm director ring remove" command
  - director: don't crash with quickly disconnecting incoming director
    connections
  - mdbox: if mail was originally saved to non-INBOX, and namespace prefix is
    non-empty, don't assert-crash when rebuilding indexes
  - sdbox: don't use more fds than necessary when copying mails
  - auth: fixed crash with DIGEST-MD5 when attempting to do master user login
    without master passdbs
  - several fixes to mail_shared_explicit_inbox=no
  - imapc: use imapc_list_prefix also for listing subscriptions
- drop upstreamed systemd patch

* Wed May  9 2012 Paul Howarth <paul@city-fan.org> 1:2.1.6-2.0.cf
- fix socket activation again; fix in 2.1.6 is incomplete

* Tue May  8 2012 Paul Howarth <paul@city-fan.org> 1:2.1.6-1.0.cf
- dovecot updated to 2.1.6:
  - session ID is now included by default in auth and login process log lines;
    it can be added to mail processes also by adding %%{session} to
    mail_log_prefix
  - added ssl_require_crl setting, which specifies if CRL check must be
    successful when verifying client certificates
  - added mail_shared_explicit_inbox setting to specify if a shared INBOX
    should be accessible as "shared/$user" or "shared/$user/INBOX"
  - v2.1.5: using "~/" as mail_location or elsewhere failed to actually expand
    it to home directory
  - dbox: fixed potential assert-crash when reading dbox files
  - trash plugin: fixed behavior when quota is already over limit
  - mail_log plugin: logging "copy" event didn't work
  - proxying to backend server with SSL: verifying server certificate name
    always failed, because it was compared to an IP address
- drop systemd patch, now included in upstream release
- update SSLDIR patch

* Tue Apr 24 2012 Paul Howarth <paul@city-fan.org> 1:2.1.5-1.0.cf
- dovecot updated to 2.1.5:
  - IMAP: when neither the session nor the mailbox has modseq tracking enabled,
    return the mailbox as having NOMODSEQ in SELECT/EXAMINE reply (old versions
    in this situation always simply returned HIGHESTMODSEQ as 1, which could
    have broken some clients)
  - dict file: added optional fcntl/flock locking (default is dotlock)
  - fts-solr: doveadm fts rescan now resets indexes, which allows reindexing
    mails (this isn't a full rescan implementation like fts-lucene has)
  - doveadm expunge: added -d parameter to delete mailbox if it's empty after
    expunging
  - IMAP: several fixes related to mailbox listing in some configs
  - director: a lot of fixes and performance improvements
  - v2.1.4 didn't work without a mail home directory set
  - mbox: deleting a mailbox didn't delete its index files
  - pop3c: TOP command was sent incorrectly
  - trash plugin didn't work properly
  - LMTP: don't add a duplicate Return-Path: header when proxying
  - listescape: don't unescape namespace prefixes
- drop 2.1.4 post-release patch, now included in upstream release
- add patch to close systemd extra sockets that are not configured

* Tue Apr 10 2012 Paul Howarth <paul@city-fan.org> 1:2.1.4-1.1.cf
- add post-release fix for lib-storage

* Tue Apr 10 2012 Paul Howarth <paul@city-fan.org> 1:2.1.4-1.0.cf
- dovecot updated to 2.1.4:
  - added mail_temp_scan_interval setting and changed its default value from
    8 hours to 1 week
  - added pop3-migration plugin for easily doing a transparent IMAP+POP3
    migration to Dovecot: http://wiki2.dovecot.org/Migration/Dsync
  - doveadm user: added -m parameter to show some of the mail settings
  - proxying SSL connections crashed in v2.1.[23]
  - fts-solr: indexing mail bodies was broken
  - director: several changes to significantly improve error handling
  - doveadm import didn't import messages' flags
  - mail_full_filesystem_access=yes was broken
  - make sure IMAP clients can't create directories when accessing non-existent
    users' mailboxes via shared namespace
  - dovecot auth clients authenticating via TCP socket could have failed with
    bogus "PID already in use" errors
- package new pop3 migration plugin

* Mon Mar 19 2012 Paul Howarth <paul@city-fan.org> 1:2.1.3-1.0.cf
- dovecot updated to 2.1.3:
  - mdbox was broken in v2.1.2

* Fri Mar 16 2012 Paul Howarth <paul@city-fan.org> 1:2.1.2-1.0.cf
- dovecot updated to 2.1.2:
  - initial implementation of dsync-based replication; for now this should be
    used only on non-critical systems
  - proxying: POP3 now supports sending remote IP+port from proxy to backend
    server via Dovecot-specific XCLIENT extension
  - proxying: proxy_maybe=yes with host=<hostname> (instead of IP) now works
    properly
  - proxying: added auth_proxy_self setting
  - proxying: added proxy_always extra field (see wiki docs)
  - added director_username_hash setting to specify what part of the username
    is hashed; this can be used to implement per-domain backends (which allows
    safely accessing shared mailboxes within domain)
  - added a "session ID" string for imap/pop3 connections, available in
    %%{session} variable; the session ID passes through Dovecot IMAP/POP3
    proxying to backend server (the same session ID is can be reused after a
    long time, currently a little under 9 years)
  - passdb checkpassword: support "credentials lookups" (for non-plaintext
    auth and for lmtp_proxy lookups)
  - fts: added fts_index_timeout setting to abort search if indexing hasn't
    finished by then (default is to wait forever)
  - doveadm sync: if mailbox was expunged empty, messages may have come back
    instead of also being expunged in the other side
  - director: if user logged into two directors while near user expiration,
    the directors might have redirected the user to two different backends
  - imap_id_* settings were ignored before login
  - several fixes to mailbox_list_index=yes
  - previous v2.1.x didn't log all messages at shutdown
  - mbox: fixed accessing Dovecot v1.x mbox index files without errors
- package new replicator plugin and aggregator/replicator binaries
- drop support for distributions prior to FC-3:
  - unconditionally build with GSSAPI support
  - don't need to work around GNU ld not always having --as-needed
  - don't need to support systems with 2.4 kernels and no epoll

* Fri Mar  2 2012 Paul Howarth <paul@city-fan.org> 1:2.1.1-2.0.cf
- enable fts_lucene plugin for F-16 onwards (#798661)

* Thu Feb 23 2012 Paul Howarth <paul@city-fan.org> 1:2.1.1-1.0.cf
- dovecot updated to 2.1.1:
  - dsync: if message with same GUID is saved multiple times in session, copy
    it instead of re-saving
  - acl plugin + autocreated mailboxes crashed when listing mailboxes
  - doveadm force-resync: don't skip autocreated mailboxes (especially INBOX)
  - if process runs out of fds, stop listening for new connections only
    temporarily, not permanently (avoids hangs with process_limit=1 services)
  - auth: passdb imap crashed for non-login authentication (e.g. smtp)
- package new manpages for doveadm-instance and doveadm-mount
- add dependency on openssl for mkcert.sh

* Wed Feb 22 2012 Paul Howarth <paul@city-fan.org> 1:2.1.0-1.1.cf
- include pigeonhole doc files (NEWS, README, etc.)
- move libdovecot-ssl.so to devel package
- own directory /etc/pki/dovecot/ and its subdirectories
- systemd builds don't need chkconfig
- use absolute path for OPENSSLCONFIG in mkcert.sh

* Fri Feb 17 2012 Paul Howarth <paul@city-fan.org> 1:2.1.0-1.0.cf
- dovecot updated to 2.1.0:
  - added ignore_on_failure setting for namespaces: if namespace initialization
    fails with this enabled (e.g. permission denied), the namespace is silently
    skipped for the user
- pigeonhole updated to 0.3.0:
  - renamed sieve_global_path setting to sieve_default for clarity (old name
    is still recognized for backwards compatibility)
  - added means to prohibit use of redirect action: setting sieve_max_redirects
    to 0 now means that redirect is disallowed instead of unlimited
  - fixed interaction of Sieve include extension with ManageSieve: it is
    updated to match new requirements in the draft include specification, and
    missing included scripts are no longer an error at upload time
  - updated RFC2822 header field body verification to exclude non-printing
    characters (RFC5322)
  - completed sieve-filter tool to a useful state: the sieve-filter tool
    provides a means to (re)filter messages in a mailbox through a Sieve script
  - implemented the Sieve editheader extension: it is now possible to add and
    remove message headers from within Sieve
  - manageSieve: added support for reading quoted and literal strings as a
    stream, which fixes support for handing large SASL responses (analogous to
    similar changes in Dovecot)
  - added code to cleanup tmp directory in Sieve storage directory (sieve_dir)
    every once in a while
  - added support for substituting the entire message during Sieve processing:
    this is used for the filter action provided by the new sieve_extprograms
    plugin (provided separately for now) - the filter action allows passing the
    message through an external program
  - added support for restricting certain Sieve language extensions to
    (admin-controlled) global scripts: restricted extensions can be configured
    using the new sieve_global_extensions setting (this is particularly useful
    for some of the Dovecot-specific Sieve extensions, which can be somewhat
    hazardous when under direct control of users, e.g. sieve_extprograms)

* Tue Feb 14 2012 Paul Howarth <paul@city-fan.org> 1:2.1-0.7.0.rc6.cf
- dovecot updated to 2.1.rc6:
  - added automatic mountpoint tracking and doveadm mount commands to manage
    the list; if a mountpoint is unmounted, error handling is done by assuming
    that the files are only temporarily lost, which is especially helpful if
    dbox alt storage becomes unmounted
  - expire plugin: only go through users listed by userdb iteration; delete
    dict rows for nonexistent users, unless expire_keep_nonexistent_users=yes
  - LDA's out-of-quota and Sieve's reject mails now include DSN report instead
    of MDN report
  - LDAP: allow building passdb/userdb extra fields from multiple LDAP
    attributes by using %%{ldap:attributeName} variables in the template
  - doveadm log errors shows the last 1000 warnings and errors since Dovecot
    was started
  - improved multi-instance support: track automatically which instances are
    started up and manage the list with doveadm instance commands; all dovecot
    commands now support -i <instance_name> parameter to select the instance
    (instead of having to use -c <config path>)
  - doveadm mailbox delete: added -r parameter to delete recursively
  - doveadm acl: added "add" and "remove" commands
  - updated to Unicode v6.1
  - mdbox: when saving to alt storage, Dovecot didn't append as much data to
    m.* files as it could have
  - dbox: fixed error handling when saving failed or was aborted
  - IMAP: using COMPRESS extension may have caused assert-crashes
  - IMAP: THREAD REFS sometimes returned invalid (0) nodes
  - dsync: fixed handling non-ASCII characters in mailbox names
- update fallocate64 patch

* Thu Feb  9 2012 Paul Howarth <paul@city-fan.org> 1:2.1-0.6.0.rc5.cf
- dovecot updated to 2.1.rc5:
  - temporary authentication failures sent to IMAP/POP3 clients now include
    the server's hostname and timestamp, making it easier to find the error
    message from logs
  - auth: implemented support for Postfix's "TCP map" sockets for user
    existence lookups
  - director: with >2 directors, ring syncing might have stalled during
    director connect/disconnect, causing logins to fail
  - LMTP client/proxy: fixed potential hanging when sending (big) mails
  - compressed mails with external attachments (dbox + SIS + zlib) failed
    sometimes with bogus "cached message size wrong" errors
- pigeonhole updated to latest snapshot
- use private /tmp from Fedora 17

* Mon Jan  9 2012 Paul Howarth <paul@city-fan.org> 1:2.1-0.4.0.rc3.cf
- dovecot updated to 2.1.rc3:
  - dsync was merged into doveadm (there is still "dsync" symlink pointing to
    "doveadm", which you can use the old way for now); the preferred ways to
    run dsync are "doveadm sync" (for old "dsync mirror") and "doveadm backup"
  - IMAP SPECIAL-USE extension to describe mailboxes
  - added mailbox {} sections, which deprecate autocreate plugin
  - lib-fs: added "mode" parameter to "posix" backend to specify mode for
    created files/dirs (for mail_attachment_dir)
  - inet_listener names are now used to figure out what type the socket is
    when useful, e.g. naming service auth { inet_listener } to auth-client vs.
    auth-userdb has different behaviour
  - added pop3c (= POP3 client) storage backend
  - LMTP proxying code was simplified, hopefully fixing its problems
  - dsync: don't remove user's subscriptions for subscriptions=no namespaces

* Wed Dec 14 2011 Paul Howarth <paul@city-fan.org> 1:2.1-0.3.0.rc1.cf
- allow imap+TLS and pop3+TLS by default

* Thu Dec  1 2011 Paul Howarth <paul@city-fan.org> 1:2.1-0.2.0.rc1.cf
- only do systemctl daemon-reload in %%postun for systemd-based distros

* Wed Nov 30 2011 Paul Howarth <paul@city-fan.org> 1:2.1-0.1.0.rc1.cf
- dovecot updated to 2.1.rc1:
  - plugins now use UTF-8 mailbox names rather than mUTF-7
  - auth_username_format default changed to %%Lu
  - solr full text search backend changed to use mailbox GUIDs instead of
    mailbox names, requiring reindexing everything
- reinstate code for fixing up pigeonhole snapshots
- update fallocate64() patch
- do systemctl daemon-reload in %%postun to update systemd on upgrade
- patch out use of --as-needed linker option on old distributions where it's
  not supported

* Thu Nov 17 2011 Paul Howarth <paul@city-fan.org> 1:2.0.16-1.0.cf
- dovecot updated to 2.0.16:
  - VSZ limits weren't being enforced for any processes; on a server with large
    mailboxes you may now see errors about it if the limits aren't high enough
  - proxying: if using ssl=yes or starttls=yes with a hostname (not IP) as
    proxy destination, require that the certificate matches the given hostname
  - LMTP: changed default client_limit to 1, which should improve LMTP
    throughput with default settings
  - dsync: quota is no longer enforced (i.e. dsync can't fail because user is
    over quota)
  - added "auto" mail storage driver, which can be used to autodetect mailbox
    location and format
  - checkpassword: export all auth %%variables to AUTH_* environment
- package manpage for doveadm-move(1)

* Sat Oct 29 2011 Paul Howarth <paul@city-fan.org> 1:2.0.15-2.0.cf
- do not use obsolete settings in default configuration (#743444)

* Mon Sep 19 2011 Paul Howarth <paul@city-fan.org> 1:2.0.15-1.0.cf
- dovecot updated to 2.0.15:
  - doveadm altmove: added -r parameter to move mails back to primary storage
  - v2.0.14: index reading could have eaten a lot of memory in some situations
  - doveadm index no longer affects future caching decisions
  - mbox: fixed crash during mail delivery when mailbox didn't yet have GUID
    assigned to it
  - zlib+mbox: fetching last message from compressed mailboxes crashed
  - lib-sql: fixed load balancing and error handling when multiple hosts are
    used

* Tue Sep 13 2011 Paul Howarth <paul@city-fan.org> 1:2.0.14-2.0.cf
- do not enable insecure connections by default

* Mon Sep  5 2011 Paul Howarth <paul@city-fan.org> 1:2.0.14-1.0.cf
- dovecot updated to 2.0.14:
  - doveadm: added support for running mail commands by proxying to another
    doveadm server
  - added "doveadm proxy list" and "doveadm proxy kick" commands to list/kick
    proxy connections (via a new "ipc" service)
  - added "doveadm director move" to assign user from one server to another,
    killing any existing connections
  - added "doveadm director ring status" command
  - userdb extra fields can now return name+=value to append to an existing
    name, e.g. "mail_plugins+= quota"
  - script-login attempted an unnecessary config lookup, which usually failed
    with "Permission denied"
  - lmtp: fixed parsing quoted strings with spaces as local-part for
    MAIL FROM and RCPT TO
  - imap: FETCH BODY[HEADER.FIELDS (..)] may have crashed or not returned all
    data sometimes
  - ldap: fixed random assert-crashing with with sasl_bind=yes
  - fixes to handling mail chroots
  - fixed renaming mailboxes under different parent with FS layout when using
    separate ALT, INDEX or CONTROL paths
  - zlib: fixed reading concatenated .gz files
- update fallocate64() patch
- package %%{_libexecdir}/dovecot/ipc

* Fri May 27 2011 Paul Howarth <paul@city-fan.org> 1:2.0.13-2.0.cf
- don't include the SysV initscript for systemd-using distributions

* Thu May 12 2011 Paul Howarth <paul@city-fan.org> 1:2.0.13-1.0.cf
- dovecot updated to 2.0.13:
  - added "doveadm index" command to add unindexed messages into index/cache;
    if full text search is enabled, it also adds unindexed messages to the fts
    database
  - added "doveadm director dump" command
  - pop3: added support for showing messages in "POP3 order", which can be
    different from IMAP message order; this can be useful for migrations from
    other servers
  - doveconf: fixed a wrong "subsection has ssl=yes" warning
  - mdbox purge: fixed wrong warning about corrupted extrefs
  - sdbox: INBOX GUID changed when INBOX was autocreated, leading to trouble
    with dsync
  - script-login binary wasn't actually dropping privileges to the
    user/group/chroot specified by its service settings
  - fixed potential crashes and other problems when parsing header names that
    contained NUL characters
- add manpage doveadm-index(1)

* Fri Apr 15 2011 Paul Howarth <paul@city-fan.org> 1:2.0.12-2.0.cf
- pigeonhole updated to 0.2.3:
  - managesieve: fixed bug in UTF-8 checking of string values
  - sieve command line tools now avoid initializing the mail store unless
    necessary
  - removed header MIME-decoding to fix erroneous address parsing
  - fixed segfault in extension configuration, triggered when unknown
    extension is mentioned in sieve_extensions setting

* Wed Apr 13 2011 Paul Howarth <paul@city-fan.org> 1:2.0.12-1.0.cf
- dovecot updated to 2.0.12:
  - doveadm: added "move" command for moving mails between mailboxes
  - virtual: added support for "+mailbox" entries that clear \Recent flag from
    messages (default is to preserve them)
  - dbox: fixes to handling of external attachments
  - dsync: more fixes to avoid hanging with remote syncs
  - dsync: many other syncing/correctness fixes
  - doveconf: v2.0.10 and v2.0.11 didn't output plugin {} section right
- drop upstreamed patch for config file parsing (#690401)
- nobody else likes macros for commands

* Mon Mar 28 2011 Paul Howarth <paul@city-fan.org> 1:2.0.11-5.0.cf
- fix regression in config file parsing (#690401)

* Wed Mar 23 2011 Paul Howarth <paul@city-fan.org> 1:2.0.11-3.0.cf
- resync with Rawhide (sigh)

* Wed Mar 23 2011 Paul Howarth <paul@city-fan.org> 1:2.0.11-2.0.cf
- rebuild for new MySQL client library in Rawhide

* Sun Mar  6 2011 Paul Howarth <paul@city-fan.org> 1:2.0.11-1.0.cf
- dovecot updated to 2.0.11:
  - dotlock_use_excl setting's default was accidentally "no" in all v2.0.x
    releases, instead of "yes" as in v1.1 and v1.2; changed it back to "yes"
  - v2.0.10: LDAP support was broken
  - v2.0.10: dsyncing to remote often hanged (timed out in 15 mins)
- drop upstream LDAP auth crash patch

* Sat Mar  5 2011 Paul Howarth <paul@city-fan.org> 1:2.0.10-2.0.cf
- add upstream fix for LDAP auth crash

* Sat Mar  5 2011 Paul Howarth <paul@city-fan.org> 1:2.0.10-1.0.cf
- dovecot updated to 2.0.10:
  - LMTP: For user+detail@domain deliveries, the +detail is again written to
    Delivered-To: header
  - Skip auth penalty checks from IPs in login_trusted_networks
  - Added import_environment setting
  - Added submission_host setting to send mails via SMTP instead of via
    sendmail binary
  - Added doveadm acl get/set/delete commands for ACL manipulation, similar to
    how IMAP ACL extension works
  - Added doveadm acl debug command to help debug and fix problems with why
    shared mailboxes aren't working as expected
  - IMAP: Fixed hangs with COMPRESS extension
  - IMAP: Fixed a hang when trying to COPY to a non-existent mailbox
  - IMAP: Fixed hang/crash with SEARCHRES + pipelining $
  - IMAP: Fixed assert-crash if IDLE+DONE is sent in same TCP packet
  - LMTP: Fixed sending multiple messages in a session
  - doveadm: Fixed giving parameters to mail commands
  - doveadm import: Settings weren't correctly used for the import storage
  - dsync: Fixed somewhat random failures with saving messages to remote dsync
  - v2.0.9: Config reload didn't notify running processes with
    shutdown_clients=no, so they could have kept serving new clients with old
    settings
- drop upstreamed systemd patch

* Thu Feb 17 2011 Paul Howarth <paul@city-fan.org> 1:2.0.9-3.0.cf
- add missing section to dovecot's systemd service file

* Tue Feb  8 2011 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> 1:2.0.9-2.0.cf
- rebuilt for https://fedoraproject.org/wiki/Fedora_15_Mass_Rebuild

* Thu Jan 13 2011 Paul Howarth <paul@city-fan.org> 1:2.0.9-1.0.cf
- dovecot updated to 2.0.9:
  - Fix a high system CPU usage/high context switch count performance problem
  - lda: Fix a crash when trying to send "out of quota" reply

* Mon Dec 20 2010 Paul Howarth <paul@city-fan.org> 1:2.0.8-3.0.cf
- resync with rawhide

* Tue Dec  7 2010 Paul Howarth <paul@city-fan.org> 1:2.0.8-2.0.cf
- pigeonhole updated to 0.2.2
- use systemd activation from Fedora 15 onwards

* Mon Dec  6 2010 Paul Howarth <paul@city-fan.org> 1:2.0.8-1.0.cf
- dovecot updated to 2.0.8:
  - Services' default vsz_limits weren't being enforced correctly in earlier
    v2.0 releases. Now that they are enforced, you might notice that the
    default limits are too low and you need to increase them. This problem
    will show up in logs as "out of memory" errors. See default_vsz_limit and
    service { vsz_limit } settings.
  - LMTP: In earlier versions if mail was delivered to user+detail@domain
    address, LMTP server always attempted to deliver the mail to mailbox named
    "detail". This was rather unintentional and shouldn't have been the
    default. lmtp_save_to_detail_mailbox=yes setting now preserves this
    behavior (default is no).
  - Added systemd support (configure --with-systemdsystemunitdir).
  - Replaced broken mbox-snarf plugin with a new more generic snarf plugin.
  - dbox: Fixes to handling external mail attachments
  - verbose_proctitle=yes didn't work for all processes in v2.0.7
  - imap, pop3: When service { client_count } was larger than 1, the log
    messages didn't use the correct prefix. Last logged in user's prefix was
    always used, regardless of what user's session actually logged it. Now the
    proper log prefix is always used.
  - MySQL: Only the first specified host was ever used
- lib20_mbox_snarf_plugin replaced by lib05_snarf_plugin.so

* Mon Nov 29 2010 Paul Howarth <paul@city-fan.org> 1:2.0.7-3.0.cf
- make it work with /var/run on tmpfs (#656577)

* Tue Nov 23 2010 Paul Howarth <paul@city-fan.org> 1:2.0.7-2.0.cf
- fix regression with valid_chroot_dirs being ignored (#654083)

* Tue Nov  9 2010 Paul Howarth <paul@city-fan.org> 1:2.0.7-1.0.cf
- dovecot updated to 2.0.7:
  - IMAP: fixed LIST-STATUS for subscriptions with subscriptions=no namespaces
  - IMAP: fixed SELECT QRESYNC not to crash on mailbox close
  - quota: don't count virtual mailboxes in quota
  - doveadm expunge didn't always actually do the physical expunging
  - fixed some index reading optimizations introduced by v2.0.5
  - LMTP proxying fixes
- pigeonhole updated to current snapshot

* Fri Oct 22 2010 Paul Howarth <paul@city-fan.org> 1:2.0.6-1.0.cf
- dovecot updated to 2.0.6:
  - pre-login CAPABILITY includes IDLE again
  - auth: auth_cache_negative_ttl default restored from 0 to 1h as per 1.x
  - dbox: added initial support for saving mail attachments to external files
  - doveadm: added import command for importing mails from other storages
  - reduced NFS I/O operations for index file accesses
  - dbox, Maildir: when copying messages, copy also already cached index fields
  - mdbox: added mdbox_preallocate_space setting (Linux+ext3/XFS only)
  - Maildir: LDA/LMTP assert-crashed sometimes when saving a mail
  - fixed leaking fds when writing to dovecot.mailbox.log
  - fixed rare dovecot.index.cache corruption
  - IMAP: SEARCH YOUNGER/OLDER wasn't working correctly
- pigeonhole updated to current snapshot
- add patch to work around broken fallocate with glibc 2.10 32-bit (#500487)

* Mon Oct  4 2010 Paul Howarth <paul@city-fan.org> 1:2.0.5-1.0.cf
- dovecot updated to 2.0.5:
  - acl: fix the logic of merging multiple ACL entries
  - virtual: allow opening virtual mailboxes referring to non-existing mailboxes
  - add some disk I/O optimizations to Maildir and index code
  - pop3: add pop3_fast_size_lookups setting
  - doveconf sometimes failed with complaining about missing ssl_key setting
  - lda: dovecot exits with EX_TEMPFAIL if there's an error in configuration
  - sdbox: fix memory leak when copying messages with hard links
  - zlib + sdbox combination didn't work
  - zlib: fixed several crashes, which mainly showed up with mbox
  - quota: don't crash if user has quota disabled, but plugin loaded
  - doveadm fetch uid was actually returning sequence, not uid
  - v2.0.4's subscription listing could ignore 'subscriptions=no namespaces'
  - acl: fix crashing when sometimes listing shared mailboxes via dict proxy
- pigeonhole updated to current snapshot

* Thu Sep 30 2010 Paul Howarth <paul@city-fan.org> 1:2.0.4-2.0.cf
- rebuild for gcc bug (#634757)

* Tue Sep 28 2010 Paul Howarth <paul@city-fan.org> 1:2.0.4-1.1.cf
- pigeonhole updated to 0.2.1 snapshot

* Mon Sep 27 2010 Paul Howarth <paul@city-fan.org> 1:2.0.4-1.0.cf
- dovecot updated to 2.0.4:
  - multi-dbox: honour :INDEX=path more completely
  - Maildir: fix copying with hard links
  - Maildir: v2.0.3 broke expunging copied messages sometimes
  - Maildir: INBOX whose tmp/ directory was lost couldn't be opened
  - single-dbox: messages weren't copied with hard links
  - vpopmail support is hopefully working again
  - dsync: POP3 UIDLs weren't copied with Maildir
  - dict file: fixed fd leak (showed up easily with LMTP + quota)

* Mon Sep 20 2010 Paul Howarth <paul@city-fan.org> 1:2.0.3-1.0.cf
- dovecot updated to 2.0.3; pigeonhole updated to today's snapshot
  - dovecot-lda: removed use of non-standard Envelope-To: header as a default
    for -a (set lda_original_recipient_header=Envelope-To to return to the old
    behaviour)
  - added support for reverse quota warnings (i.e. when quota goes back under
    the limit), enabled by adding '-' to beginning of quota_warning value
  - dovecot-lda: added lda_original_recipient_header setting, which is used for
    getting original recipient if -a isn't used
  - dovecot-lda: added -r parameter to specify final recipient address, which
    may differ from the original address due to e.g. aliases
  - Maildir: uidlist file can now override message's GUID, making it possible
    for multiple messages in a mailbox to have the same GUID (this also fixes
    dsync's message conflict resolution)
  - dovecot-lda: if destination user isn't found, exit with EX_NOUSER, not
    EX_TEMPFAIL
  - dsync: fixed handling \Noselect mailboxes
  - fixed an infinite loop introduced by v2.0.2's message parser changes
  - fixed a crash introduced by v2.0.2's istream-crlf changes

* Thu Sep 16 2010 Paul Howarth <paul@city-fan.org> 1:2.0.2-1.1.cf
- pigeonhole updated (now 0.2.0 rather than 0.2.UNSTABLE)
- dropped redundant patch for pigeonhole build from cooked tarball

* Thu Sep  9 2010 Paul Howarth <paul@city-fan.org> 1:2.0.2-1.0.cf
- dovecot updated to 2.0.2
  - vpopmail support is disabled for now, since it's broken
  - maildir: fixed "duplicate uidlist entry" errors
  - deleting ACLs didn't cause entries to be removed from acl_shared_dict
  - mail_max_lock_timeout setting wasn't working with all locks
  - auth_cache_size setting's old-style value wasn't autoconverted properly

* Wed Aug 25 2010 Paul Howarth <paul@city-fan.org> 1:2.0.1-1.0.cf
- dovecot updated to 2.0.1
  - dsync doesn't drop privileges when started as root
  - imap: QRESYNC parameters for SELECT weren't handled correctly
  - UTF-8 string validity checking wasn't done correctly
  - dsync: fixed a random assert-crash with remote dsyncing
- pigeonhole updated
  - sieved renamed to sieve-dump
  - ship manpage for pigeonhole(7)
- add patch to fix pigeonhole build from cooked tarball

* Wed Aug 18 2010 Paul Howarth <paul@city-fan.org> 1:2.0.0-1.1.cf
- pigeonhole updated

* Tue Aug 17 2010 Paul Howarth <paul@city-fan.org> 1:2.0.0-1.0.cf
- dovecot 2.0.0 release
  - dict quota didn't always decrease quota when messages were expunged
  - shared INBOX wasn't always listed with FS layout
- drop kludges for nightly builds

* Wed Aug 11 2010 Paul Howarth <paul@city-fan.org> 1:2.0-0.21.0.rc5.cf
- dovecot and pigeonhole updated
  - using more than 2 plugins could have caused broken behavior
  - listescape plugin fixes
  - mbox: fixed a couple of assert-crashes
  - mdbox: fixed potential assert-crash when saving multiple messages

* Thu Aug  5 2010 Paul Howarth <paul@city-fan.org> 1:2.0-0.20.0.rc4.cf
- dovecot updated to 2.0.rc4, pigeonhole to 20100805 build
  - doveadm mailbox status: fixed listing non-ASCII mailbox names
  - doveadm fetch: fixed output when fetching message header or body
  - doveadm director map/add/remove: fixed handling IP address as parameter
  - dsync: a few more fixes
- package doveadm-server

* Wed Jul 21 2010 Paul Howarth <paul@city-fan.org> 1:2.0-0.19.0.rc3.cf
- dovecot updated to 2.0.rc3, pigeonhole to 20100721 build
  - fixed lda + sieve crash
  - added mail_temp_dir setting; default is /tmp
  - imap: fixed checking if list=children namespace has children
  - mdbox: race condition fixes related to copying and purging
- completely remove betahotfix patch
- pigeonhole test suite now uses "make check" rather than "make test"

* Mon Jul 19 2010 Paul Howarth <paul@city-fan.org> 1:2.0-0.18.1.rc1.20100716.cf
- dovecot and pigeonhole updated to 20100716 build
  - acl: fixed crash on FS layout with non-default hierarchy separator
  - dbox renamed to sdbox
  - dsync fixes and improvements
  - fixed a crash with empty mail_plugins
  - fixed sharing INBOX to other users
  - director+LMTP proxy wasn't working correctly
  - v1.x config parser failed with some settings if pigeonhole wasn't installed
  - virtual: fix expunging of non-matching messages
- enabled pigeonhole's build time test suite
- drop betahotfix patch again
- don't try to use Linux 2.6 epoll for targets that use Linux 2.4 kernels

* Wed Jul  7 2010 Paul Howarth <paul@city-fan.org> 1:2.0-0.16.1.rc1.20100707.cf
- updated dovecot and pigeonhole to 20100707 build
- update betahotfix patch
- package new manpage for doveadm-config(1)

* Tue Jun 29 2010 Paul Howarth <paul@city-fan.org> 1:2.0-0.16.0.rc1.cf
- updated dovecot to 2.0.rc1
 - added man pages, mostly written by Pascal Volk
 - dsync syntax changed, although it's still compatible with old syntax
 - dsync backup command added
 - dsync should now be stable
 - LMTP proxying supports director
 - director should now be stable
 - single-dbox should now be stable
 - mdbox locking behavior modified to avoid deadlocks
 - fsync_disable=no was renamed to mail_fsync = optimized (default)
 - fsync_disable=yes was renamed to mail_fsync = never
 - added a new mail_fsync = always
- manpages now integrated into main dovecot tarball
- no longer need to recode auth-protocol.txt as UTF-8

* Mon Jun 28 2010 Paul Howarth <paul@city-fan.org> 1:2.0-0.15.0.beta6.20100626.cf
- updated dovecot, pigeonhole and man pages to 20100626 build
  - moved disable_plaintext_auth to 10-auth.conf
  - mdbox: fixed assert-crash on storage rebuild if file got lost
  - lib-charset: don't assert-crash when iconv() skips lots of invalid input
  - master: fixed crash on deinit (maybe also on reload)

* Thu Jun 10 2010 Paul Howarth <paul@city-fan.org> 1:2.0-0.14.0.beta5.20100610.cf
- dovecot updated to 20100610 build
  - lib-storage: fixed accessing uncommitted saved mails with dsync
  - example-config: moved ACL and quota settings to a separate .conf files
  - dbox, mdbox: fixed race conditions when creating mailboxes
- package %%{_libexecdir}/dovecot/script-login

* Tue Jun  1 2010 Paul Howarth <paul@city-fan.org> 1:2.0-0.13.0.beta5.20100529.cf
- dovecot and pigeonhole updated
  - master: fixed crash on config reload
  - lib-storage: don't assert-crash when copying a mail fails
- enable Solr fulltext search where possible
- buildreq libcurl-devel and expat-devel for Solr support
- package %%{_libexecdir}/dovecot/director
- package %%{_libdir}/dovecot/doveadm/lib10_doveadm_expire_plugin.so
- move %%{_libdir}/dovecot/doveadm/lib10_doveadm_quota_plugin.so to main package
- %%{_libexecdir}/dovecot/expire-tool no longer included
- use -fno-strict-aliasing

* Tue May 18 2010 Paul Howarth <paul@city-fan.org> 1:2.0-0.12.0.beta5.20100515.cf
- pigeonhole and dovecot updated to snapshot 20100515
  - fixed crash for THREAD command
  - removed imap-utf7 binary (doveadm mailbox convert replaced it)
- create dovenull user account for login process

* Wed May 12 2010 Paul Howarth <paul@city-fan.org> 1:2.0-0.9.0.beta5.20100512.cf
- pigeonhole and dovecot updated to snapshot 20100512
- betahotfix patch upstreamed
- fix dist tag for RHEL-6 Beta
- script-ify procedure for fixing up the pigeonhole snapshot tarball

* Wed May  5 2010 Paul Howarth <paul@city-fan.org> 1:2.0-0.8.0.beta4.20100505.cf
- pigeonhole and dovecot updated to snapshot 20100505
  - mdbox: avoid rebuilding storage if another process already did it
  - lib-storage: fixed () sublists in IMAP SEARCH parser
  - example-config: auth-checkpassword include wasn't listed in 10-auth.conf
  - doveadm: added search command
  - lib-master: don't crash after timing out an auth-master request
  - master: inet listener listens on all addresses from a DNS name
- update snapshot fixups patch

* Wed Apr 28 2010 Paul Howarth <paul@city-fan.org> 1:2.0-0.7.0.beta4.20100427.cf
- updated to snapshot 20100427
  - doveconf <setting name> now prints only the one setting's value
  - mdbox: automatically delete old temp.* files from storage/ directory
  - mdbox: use flock locking by default

* Thu Apr 22 2010 Paul Howarth <paul@city-fan.org> 1:2.0-0.6.0.beta4.20100421.cf
- updated to snapshot 20100421
  - mdbox: purge crashed if it purged all messages from a file
  - lib-storage: shared namespace's prefix_len updated after prefix truncated
  - imap-quota: iterate quota roots only once when replying to GETQUOTAROOT
  - idle: do cork/uncork when sending "OK Still here" notification
  - login: if proxy returns ssl=yes and no port, switch port to imaps/pop3s
- new managesieve patch for dovecot API change

* Wed Apr 14 2010 Paul Howarth <paul@city-fan.org> 1:2.0-0.5.0.beta4.20100414.cf
- dovecot updated to snapshot 20100414
  - config: add nn- prefix to *.conf files so sort ordering makes more sense
  - lib-master: log an error if login client disconnects too early
  - mdbox: if purging finds corrupted files, auto-rebuild storage
  - lib-storage: add support for searching save date
  - and more...
- pigeonhole updated to snapshot ece958a18920
  - mailbox extension: fix memory leak in the mailboxexists test
  - add login failure handler
- add make check
- tweak %%configure options
- fix patches for renamed files
- re-enable default-settings patch
- managesieve patch for dovecot API change no longer needed

* Tue Apr  6 2010 Paul Howarth <paul@city-fan.org> 1:2.0-0.4.0.beta4.20100406.cf
- updated to 20100406 nightly build
  - auth: if userdb lookup fails internally, don't cache the result
  - added support for userdb lookup to fail with a reason
  - sdbox: mailbox_update() could have changed UIDVALIDITY incorrectly
  - layout=maildir++: fixed deleting mailboxes with mailbox=file storages
  - fixed potential problems with parsing invalid address groups
  - dsync: don't repeatedly try to keep opening the same failing mailbox
  - lib-storage: don't crash if root mail directory isn't given
- fix managesieve for API change in dovecot

* Thu Apr  1 2010 Paul Howarth <paul@city-fan.org> 1:2.0-0.3.0.beta4.20100330.cf
- update to 20100330 nightly build
- drop snapshot patch, no longer needed
- work around absence of --docdir option in configure scripts generated using
  autoconf 2.59 as in the nightly builds

* Tue Mar 30 2010 Paul Howarth <paul@city-fan.org> 1:2.0-0.2.0.beta4.cf
- update to 2.0.beta4
- drop documentation relating to migration from UW-IMAP
- leave DH parameter generation to dovecot
- bump epoch of sieve and managesieve provides as their version number has
  gone backwards to 0.1.13

* Tue Mar 23 2010 Paul Howarth <paul@city-fan.org> 1:1.2.11-3.0.cf
- drop mbox bzip support as it's broken and upstream does not plan to fix it in
  dovecot 1.2 (http://www.dovecot.org/list/dovecot/2010-February/046789.html)
- use managesieve patch for dovecot 1.2.11

* Fri Mar 12 2010 Paul Howarth <paul@city-fan.org> 1:1.2.11-2.0.cf
- rebuild: Fedora version didn't have bzip2 support (#572797)

* Tue Mar  9 2010 Paul Howarth <paul@city-fan.org> 1:1.2.11-1.0.cf
- updated dovecot to 1.2.11
  - mbox: message header reading was unnecessarily slow and CPU-intensive
  - mbox, dbox, cydir: fix mail root directory permissions
  - maildir: reading uidlist could have ended up in an infinite loop
  - IMAP IDLE: v1.2.7+ caused extra load by checking changes too often

* Wed Feb 24 2010 Paul Howarth <paul@city-fan.org> 1:1.2.10-4.0.cf
- merged dovecot-sieve and dovecot-managesieve into dovecot-pigeonhole
- merged dovecot-sqlite, dovecot-gssapi and dovecot-ldap into dovecot

* Thu Jan 28 2010 Paul Howarth <paul@city-fan.org> 1:1.2.10-2.0.cf
- rebuild

* Mon Jan 25 2010 Paul Howarth <paul@city-fan.org> 1:1.2.10-1.0.cf
- dovecot updated to 1.2.10
  - %%variables now support %%{host}, %%{pid} and %%{env:VAR_NAME} everywhere
  - LIST-STATUS capability is now advertised
  - maildir: Fixed several assert-crashes.
  - imap: LIST "" inbox shouldn't crash if using namespace with "INBOX." prefix
  - lazy_expunge now ignores non-private namespaces
- sieve updated to 0.1.15
  - enotify: adjusted notify method API for addition of new methods
  - enotify: set default importance level to 'normal' (was 'high')
  - include: updated implementation towards most recent specification
  - envelope path parser allows addresses that have no domain part
  - preliminary support for Sieve plugins
  - support for installing Sieve development headers
  - deprecated notify extension: implemented denotify command
  - variables extension: added support for variable namespaces
  - added configurable script size limit
  - testsuite enhancements
  - fixed a bug in the i;ascii-numeric comparator (see NEWS)
  - imap4flags: fixed bug in removeflag (see NEWS)
  - improved some error messages
  - fixed typo in runtime log message for vacation extension
  - fixed parser recovery
- managesieve updated to 0.11.11
  - adjustments to match changes in the Sieve API
  - implement ManageSieve QUOTA enforcement
  - added MAXREDIRECTS capability after login
  - implement ew script name rules specified in most recent ManageSieve draft
  - fix assertion failure occuring with challenge-response SASL mechanisms

* Tue Dec 22 2009 Paul Howarth <paul@city-fan.org> 1:1.2.9-2.0.cf
- dovecot updated to 1.2.9
  - maildir: when saving, filenames now always contain ,S=<size>
  - maildir: fix assert-crashes in v1.2.7 and v1.2.8
  - maildir_copy_preserve_filename=yes could have caused crashes
  - maildir++ quota: update %% limits from maildirsize
  - virtual: v1.2.8 didn't fully fix the "lots of mailboxes" bug
  - virtual: fixed updating virtual mailbox based on flag changes
  - fts-squat: fixed searching multi-byte characters
- sieve updated to 0.1.14
  - limits of redirects and actions now configurable
  - extension handling no longer needs to maintain global state
  - made LDA Sieve plugin recognize the deliver_log_format setting
  - outgoing message headers now RFC2047-encoded
  - add support for the $text$ substitution in the deprecated notify extension
  - recipient_delimiter is now an alias for sieve_subaddress_sep
  - fixed logging of mailbox names (uses UTF8)
  - fix a minor memory leak in the multiscript support
  - fix a bug in the recompilation of Sieve scripts (only done when needed)
- managesieve updated to 0.11.10
  - adjustments to match changes in the Pigeonhole Sieve API (requires 0.1.14)
  - fix compilation of ManageSieve against CMUSieve

* Wed Nov 25 2009 Paul Howarth <paul@city-fan.org> 1:1.2.8-4.0.cf
- fix dovecot's restart after update (#518753)

* Tue Nov 24 2009 Paul Howarth <paul@city-fan.org> 1:1.2.8-2.0.cf
- use managesieve patch for dovecot 1.2.8

* Fri Nov 20 2009 Paul Howarth <paul@city-fan.org> 1:1.2.8-1.0.cf
- dovecot updated to 1.2.8
  - fix base_dir's permissions from 0777 to 0755 (see NEWS)
  - merge acls from multiple groups
  - virtual: fix OOM when using a lot of mailboxes
  - return RFC 2231 "key*" fields correctly in FETCH BODYSTRUCTURE

* Mon Nov 16 2009 Paul Howarth <paul@city-fan.org> 1:1.2.7-3.0.cf
- use upstream managesieve patch for dovecot 1.2.7
- rawhide dist tag no longer needs special-casing

* Fri Nov 13 2009 Paul Howarth <paul@city-fan.org> 1:1.2.7-2.0.cf
- add default config copy in %%{docdir}
- add manpages for dovecot(8), dovecot.conf(5), dovecotpw(1)

* Tue Nov 10 2009 Paul Howarth <paul@city-fan.org> 1:1.2.7-1.0.cf
- dovecot updated to 1.2.7
  - imap: send "still here" notifications for user's connections simultaneously
  - imap: if imap_capability is set, show it in the login banner
  - imap: implemented SORT=DISPLAY extension
  - login: fix process creation epoll_ctl() errors
  - maildir: fix some performance issues
  - maildir: fix crash when using a lot of keywords
  - several fixes to QRESYNC extension and modseq handling
  - mbox: make sure failed saves get rolled back with NFS
  - dbox: several fixes
- update managesieve patch locally to apply against dovecot 1.2.7
- drop upstreamed imap_capability patch
- drop SSL compression patch; issue resolved upstream

* Mon Nov  2 2009 Paul Howarth <paul@city-fan.org> 1:1.2.6-5.0.cf
- minor spec clean-up

* Thu Oct 22 2009 Paul Howarth <paul@city-fan.org> 1:1.2.6-4.0.cf
- imap-login: if imap_capability is set, show it in the banner instead of the
  default (#524485)

* Thu Oct 22 2009 Paul Howarth <paul@city-fan.org> 1:1.2.6-3.0.cf
- fix initscript for case when no action was specified

* Mon Oct 19 2009 Paul Howarth <paul@city-fan.org> 1:1.2.6-1.1.cf
- sieve updated to 0.1.13
  - body extension: proper handling of the :raw transform
  - body extension: added various new tests to the test suite
  - body extension: don't give SKIP_BODY_BLOCK flag to message parser
  - fix race condition when multiple instances are saving the same binary
  - multiscript: subsequent keep actions merged correctly
  - multiscript: implicit side effects handled correctly
  - sieve-test: fix segfault when compile fails
  - fix segfault in action processing when merging side effects
  - fix sieve plugin to not stat() a NULL path, yielding a 'Bad address' error

* Tue Oct  6 2009 Paul Howarth <paul@city-fan.org> 1:1.2.6-1.0.cf
- dovecot updated to 1.2.6
  - added authtest utility for doing passdb and userdb lookups
  - login: ssl_security string now also shows the used compression
  - quota: Don't crash with non-Maildir++ quota backend
  - imap proxy: Fixed crashing with some specific password characters
  - dovecot --exec-mail was broken
  - avoid assert-crashing when two processes try to create index simultaneously
- update managesieve patch to 1.2.6 version
- add patch to revert ssl_proxy_get_security_string() to the dovecot-1.2.5
  version if we have openssl < 0.9.8, which does not have the required
  functions SSL_COMP_get_name and SSL_get_current_compression

* Wed Sep 30 2009 Paul Howarth <paul@city-fan.org> 1:1.2.5-2.0.cf
- use password-auth common PAM configuration instead of system-auth
- use %%{_initddir} rather than %%{_initrddir}
- add some UID=0 checks in the initscript

* Mon Sep 14 2009 Paul Howarth <paul@city-fan.org> 1:1.2.5-1.0.cf
- dovecot updated to 1.2.5
- authentication: DIGEST-MD5 and RPA mechanisms no longer require
  user's login realm to be listed in auth_realms; it only made
  configuration more difficult without really providing extra security
- zlib plugin: don't allow clients to save compressed data directly;
  this prevents users from exploiting (most of the) potential security
  holes in zlib/bzlib
- fix index file handling that could have caused an assert-crash
- IMAP: fixes to QRESYNC extension
- deliver: don't send rejects to any messages that have Auto-Submitted
  header; this avoids emails loops

* Mon Aug 31 2009 Paul Howarth <paul@city-fan.org> 1:1.2.4-2.0.cf
- rebuild for openssl 1.0 in Rawhide

* Fri Aug 21 2009 Paul Howarth <paul@city-fan.org> 1:1.2.4-1.1.cf
- sieve updated to 0.1.12
- managesieve updated to 0.11.9
- drop dovecot-1.2.4-managesieve-0.11.8 patch, no longer needed

* Tue Aug 18 2009 Paul Howarth <paul@city-fan.org> 1:1.2.4-1.0.cf
- dovecot updated to 1.2.4
- sieve updated to 0.1.11
- add http://pigeonhole.dovecot.org/ URL for sieve and managesieve packages
- add manpage for sieve-filter
- add patch to fix managesieve build against dovecot-1.2.4

* Mon Aug 10 2009 Paul Howarth <paul@city-fan.org> 1:1.2.3-1.0.cf
- dovecot updated to 1.2.3
- managesieve updated to 0.11.8
- drop GSSAPI patch, in upstream release

* Thu Jul 30 2009 Paul Howarth <paul@city-fan.org> 1:1.2.2-2.0.cf
- apply fix from 20090728 post-release snapshot to fix GSSAPI (#506782)
- merge default-settings patch from Fedora
- add --with-unfinished-features to sieve %%configure to build sieve-filter

* Tue Jul 28 2009 Paul Howarth <paul@city-fan.org> 1:1.2.2-1.0.cf
- dovecot updated to 1.2.2
- managesieve updated to 0.11.7
- drop managesieve SASL patch, no longer needed
- sieve plugin changed from CMU to Dovecot Sieve (0.1.9, epoch bumped to 2)
- license for sieve subpackage now just LGPL v2.1 or later

* Fri Jul 10 2009 Paul Howarth <paul@city-fan.org> 1:1.2.1-1.0.cf
- dovecot updated to 1.2.1
- managesieve updated to 0.11.6
- remove managesieve timeout patch, now upstream
- add patch to managesieve for SASL changes in 1.2.1

* Thu Jul  2 2009 Paul Howarth <paul@city-fan.org> 1:1.2.0-1.0.cf
- dovecot updated to 1.2.0

* Wed Jul  1 2009 Paul Howarth <paul@city-fan.org> 1:1.2-0.6.0.rc8.cf
- dovecot updated to 1.2.rc8
- remove upstreamed ldap-plugin patch
- remove autotools patch - we're not changing any autotools input files

* Mon Jun 29 2009 Paul Howarth <paul@city-fan.org> 1:1.2-0.5.0.rc7.cf
- dovecot updated to 1.2.rc7
- autotools patch rebuilt
- add buildreq libcap-devel for capabilities-dropping support
- add patch to fix configure script for LDAP auth plugin

* Thu Jun 25 2009 Paul Howarth <paul@city-fan.org> 1:1.2-0.4.0.rc6.cf
- dovecot updated to 1.2.rc6
- add patch for timeout sanity check in managesieve that needed inverting
- imap_utf7 renamed to imap-utf7

* Wed Jun 24 2009 Paul Howarth <paul@city-fan.org> 1:1.2-0.3.0.rc5.cf
- dovecot updated to 1.2.rc5
- managesieve updated to 0.11.5
- dovecot-1.2-ldap.patch dropped
- dovecot-1.2-default-settings.patch updated from Fedora's
  dovecot-1.1-default-settings.patch
- autotools patch rebuilt
- re-enable parallel make

* Thu Apr  2 2009 Paul Howarth <paul@city-fan.org> 1:1.2-0.2.0.beta4.cf
- dovecot updated to 1.2.beta4
- managesieve updated to 0.11.3
- dovecot-1.2-ldap.patch added from Fedora
- dovecot-1.1-default-settings.patch updated from Fedora and properly named as
  dovecot-1.2-default-settings.patch
- autotools patch rebuilt
- update login-dir patch
- Fedora 9 onwards clear out /var/run in a different way to older releases;
  bear this in mind when deciding whether to move the login-dir
- make PAM configuration %%config(noreplace)
- disable parallel make (build failure on rhel3.64)

* Fri Mar 20 2009 Paul Howarth <paul@city-fan.org> 1:1.1.13-1.0.cf
- dovecot updated to 1.1.13
- update autotools patch

* Sat Mar 14 2009 Paul Howarth <paul@city-fan.org> 1:1.1.12-1.0.cf
- dovecot updated to 1.1.12
- update autotools patch

* Mon Mar  2 2009 Paul Howarth <paul@city-fan.org> 1:1.1.11-2.0.cf
- rebuild for https://fedoraproject.org/wiki/Fedora_11_Mass_Rebuild

* Wed Feb  4 2009 Paul Howarth <paul@city-fan.org> 1:1.1.11-1.0.CF
- dovecot updated to 1.1.11
- update managesieve to 0.10.5
- update autotools patch

* Tue Jan 27 2009 Paul Howarth <paul@city-fan.org> 1:1.1.10-1.0.CF
- dovecot updated to 1.1.10
- locally update managesieve patch
- update autotools patch

* Mon Jan 26 2009 Paul Howarth <paul@city-fan.org> 1:1.1.9-1.0.CF
- dovecot updated to 1.1.9
- locally update managesieve patch
- update autotools patch
- inotify and docs support enabled by default, drop configure options

* Fri Jan 23 2009 Paul Howarth <paul@city-fan.org> 1:1.1.8-3.0.CF
- rebuild for new MySQL in Rawhide

* Thu Jan 15 2009 Paul Howarth <paul@city-fan.org> 1:1.1.8-2.0.CF
- dovecot updated to 1.1.8
- added managesieve support (thanks Helmut K. C. Tessarek)
- add individual epochs for dovecot, sieve, and manage_sieve since Fedora
  uses the same EVR for all three and I stick to upstream version numbers
- update autotools patch

* Mon Dec 22 2008 Paul Howarth <paul@city-fan.org> 1:1.1.7-2.1.CF
- update dovecot-sieve to 1.1.6

* Wed Dec  3 2008 Paul Howarth <paul@city-fan.org> 1:1.1.7-2.0.CF
- revert changes from 1:1.1.6-2.0.CF; password can be stored in different file
  readable only for root via !include_try directive if required

* Mon Nov 24 2008 Paul Howarth <paul@city-fan.org> 1:1.1.7-1.0.CF
- update to 1.1.7
- remove dovecot-1.1-default-settings-passwd.patch, no longer needed
- tweak default-settings and SSLDIR patches to apply without fuzz

* Wed Nov  5 2008 Paul Howarth <paul@city-fan.org> 1:1.1.6-2.0.CF
- changed comment in sysconfig to match actual state
- change permissions of deliver (now sgid) and dovecot.conf to prevent
  possible password exposure

* Thu Oct 30 2008 Paul Howarth <paul@city-fan.org> 1:1.1.6-1.0.CF
- update to 1.1.6

* Thu Oct 23 2008 Paul Howarth <paul@city-fan.org> 1:1.1.5-1.0.CF
- update to 1.1.5

* Mon Oct  6 2008 Paul Howarth <paul@city-fan.org> 1:1.1.4-1.0.CF
- update to 1.1.4

* Tue Sep  2 2008 Paul Howarth <paul@city-fan.org> 1:1.1.3-1.0.CF
- update to 1.1.3
- update autotools patch

* Wed Jul 30 2008 Paul Howarth <paul@city-fan.org> 1:1.1.2-2.0.CF
- add option from Rawhide to prompt for SSL key password at startup

* Mon Jul 28 2008 Paul Howarth <paul@city-fan.org> 1:1.1.2-1.0.CF
- update to 1.1.2
- update autotools patch
- de-fuzz SSLDIR and login-dir patches
- explicitly specify version and release for all subpackages, in the hope of
  getting rpmbuild to use the correct buildroot directory name
- new sample config: dovecot-db-example.conf
- new plugin: zlib_plugin.so
- new utility: maildirlock
- new buildreq bzip2-devel

* Fri Jun 27 2008 Paul Howarth <paul@city-fan.org> 1:1.1.1-2.0.CF
- update default settings to listen on both IPv4 and IPv6 instead of IPv6 only
- tweak dist tag macros to work on current Rawhide with three-part releasenum

* Sun Jun 22 2008 Paul Howarth <paul@city-fan.org> 1:1.1.1-1.0.CF
- update to 1.1.1

* Sat Jun 21 2008 Paul Howarth <paul@city-fan.org> 1:1.1.0-1.0.CF
- update to upstream version 1.1.0 (with new source URL)
- update sieve plugin to 1.1.5
- remove unnecessary patches
- enable ldap and gssapi (where possible) plugins
- change ownership of dovecot.conf (resolves #452088)

* Wed Jun 18 2008 Paul Howarth <paul@city-fan.org> 1:1.0.14-9.0.CF
- update init script (resolves #451838); big release bump keeps up with
  Fedora 8 and 9 updates to maintain upgrade path

* Thu Jun  5 2008 Paul Howarth <paul@city-fan.org> 1:1.0.14-2.0.CF
- install convert-tool (resolves #450010)

* Tue Jun  3 2008 Paul Howarth <paul@city-fan.org> 1:1.0.14-1.0.CF
- update to 1.0.14
- update autotools patch

* Wed May 21 2008 Paul Howarth <paul@city-fan.org> 1:1.0.13-8.0.CF
- LSB-ize initscript (#238018)
- install dovecot.conf not world-readable (#445200)
- merge misc spec file cleanups from Rawhide
- rationalize scriptlets (#225708)

* Mon May 19 2008 Paul Howarth <paul@city-fan.org> 1:1.0.13-6.1.CF
- update sieve to 1.0.3

* Mon Mar 10 2008 Paul Howarth <paul@city-fan.org> 1:1.0.13-6.0.CF
- update to 1.0.13

* Wed Mar  5 2008 Paul Howarth <paul@city-fan.org> 1:1.0.12-1.0.CF
- update to 1.0.12

* Tue Mar  4 2008 Paul Howarth <paul@city-fan.org> 1:1.0.11-1.0.CF
- update to 1.0.11

* Tue Feb 26 2008 Paul Howarth <paul@city-fan.org> 1:1.0.10-5.0.CF
- rebuild for gcc 4.3.0 on Fedora 9

* Fri Jan 11 2008 Paul Howarth <paul@city-fan.org> 1:1.0.10-4.0.CF
- rebuild

* Wed Jan  2 2008 Paul Howarth <paul@city-fan.org> 1:1.0.10-1.0.CF
- Update to 1.0.10

* Wed Dec 12 2007 Paul Howarth <paul@city-fan.org> 1:1.0.9-1.0.CF
- Update to 1.0.9

* Fri Dec  7 2007 Paul Howarth <paul@city-fan.org> 1:1.0.8-1.1.CF
- Rebuild for new openldap and openssl in Rawhide

* Thu Nov 29 2007 Paul Howarth <paul@city-fan.org> 1:1.0.8-1.0.CF
- Update to 1.0.8

* Tue Nov  6 2007 Paul Howarth <paul@city-fan.org> 1:1.0.7-2.1.CF
- Add the winbind patch (#286351)
- Update autotools patch

* Wed Oct 31 2007 Paul Howarth <paul@city-fan.org> 1:1.0.7-1.1.CF
- Update to 1.0.7

* Mon Oct 29 2007 Paul Howarth <paul@city-fan.org> 1:1.0.6-1.1.CF
- Update to 1.0.6
- Update autotools patch
- Wiki snapshot now installed in correct directory upstream, so no need to
  move it in %%install

* Mon Oct  1 2007 Paul Howarth <paul@city-fan.org> 1:1.0.5-1.1.CF
- Fedora version has epoch bump, so mine must do too (grr...)

* Mon Sep 10 2007 Paul Howarth <paul@city-fan.org> 1.0.5-20.CF
- update to 1.0.5
- update download URL for dovecot
- update license tags
- make sure all documentation is UTF8

* Tue Aug  7 2007 Paul Howarth <paul@city-fan.org> 1.0.3-20.CF
- update to 1.0.3
- update autotools patch
- add quota-warning patch

* Fri Jul 20 2007 Paul Howarth <paul@city-fan.org> 1.0.2-22.CF
- update dovecot-sieve to 1.0.2

* Mon Jul 16 2007 Paul Howarth <paul@city-fan.org> 1.0.2-21.CF
- update to 1.0.2

* Mon Jun 18 2007 Paul Howarth <paul@city-fan.org> 1.0.1-20.CF
- update to 1.0.1
- specfile merge from Rawhide
  - new SQL split patch
  - split SQL libraries to separate packages

* Mon Apr 16 2007 Paul Howarth <paul@city-fan.org> 1.0.0-11.CF
- update to 1.0.0 (at last!)

* Fri Apr 13 2007 Paul Howarth <paul@city-fan.org> 1.0-0.10.CF.rc32
- update to 1.0.rc32

* Tue Apr 10 2007 Paul Howarth <paul@city-fan.org> 1.0-0.9.CF.rc31
- update to 1.0.rc31
- use --disable-dependency-tracking with configure script for faster builds
- add devel subpackage with headers for plugin writers

* Mon Apr  2 2007 Paul Howarth <paul@city-fan.org> 1.0-0.9.CF.rc29
- update to 1.0.rc29
- only rename the login dir on old distributions (FC4, RHEL4 and older) that
  don't clean up /var/run/dovecot properly
- build sieve plugin and package it in sieve subpackage
- preserve timestamps in installed data files where possible
- add --with-{doc,gssapi,inotify} configure options where appropriate
- package REDHAT-FAQ.txt
- move certificate generation script from %%{docdir} to %%{_libexecdir}

* Mon Mar 26 2007 Paul Howarth <paul@city-fan.org> 1.0-0.8.CF.rc28
- update to 1.0.rc28
- put example configurations in %%{docdir} rather than %%{_sysconfdir}

* Thu Mar 15 2007 Paul Howarth <paul@city-fan.org> 1.0-0.8.CF.rc27
- update to 1.0.rc27

* Wed Mar  7 2007 Paul Howarth <paul@city-fan.org> 1.0-0.8.CF.rc26
- update to 1.0.rc26

* Fri Mar  2 2007 Paul Howarth <paul@city-fan.org> 1.0-0.8.CF.rc25
- update to 1.0.rc25

* Fri Feb 23 2007 Paul Howarth <paul@city-fan.org> 1.0-0.8.CF.rc24
- update to 1.0.rc24

* Wed Feb 21 2007 Paul Howarth <paul@city-fan.org> 1.0-0.8.CF.rc23
- update to 1.0.rc23

* Wed Feb  7 2007 Paul Howarth <paul@city-fan.org> 1.0-0.8.CF.rc22
- update to 1.0.rc22

* Mon Feb  5 2007 Paul Howarth <paul@city-fan.org> 1.0-0.8.CF.rc21
- update to 1.0.rc21
- fix dist tag for fc7 onwards

* Wed Jan 24 2007 Paul Howarth <paul@city-fan.org> 1.0-0.8.CF.rc19
- update to 1.0.rc19

* Mon Jan  8 2007 Paul Howarth <paul@city-fan.org> 1.0-0.8.CF.rc17
- update to 1.0.rc17

* Wed Dec 13 2006 Paul Howarth <paul@city-fan.org> 1.0-0.7.CF.rc15
- update to 1.0.rc15

* Mon Oct 16 2006 Paul Howarth <paul@city-fan.org> 1.0-0.6.CF.rc9
- update to 1.0.rc9

* Tue Oct 10 2006 Paul Howarth <paul@city-fan.org> 1.0-0.5.CF.rc8
- update to 1.0.rc8
- update default-settings patch

* Tue Oct  3 2006 Paul Howarth <paul@city-fan.org> 1.0-0.4.CF.rc7
- rebuilt for unwind info generation, broken in gcc-4.1.1-21

* Wed Sep 27 2006 Paul Howarth <paul@city-fan.org> 1.0-0.3.CF.rc7
- do not run over symlinked certificates in new locations on upgrade

* Thu Sep  7 2006 Paul Howarth <paul@city-fan.org> 1.0-0.2.CF.rc7
- fix distribution tags for development releases

* Fri Aug 18 2006 Paul Howarth <paul@city-fan.org> 1.0-0.1.CF.rc7
- update to 1.0.rc7

* Tue Aug  8 2006 Paul Howarth <paul@city-fan.org> 1.0-0.1.CF.rc6
- update to 1.0.rc6

* Thu Aug  3 2006 Paul Howarth <paul@city-fan.org> 1.0-0.1.CF.rc5
- update to 1.0.rc5
- update default-settings patch

* Wed Jul  5 2006 Paul Howarth <paul@city-fan.org> 1.0-0.1.CF.rc2
- update to 1.0.rc2
- update default-settings patch

* Wed Jun 28 2006 Paul Howarth <paul@city-fan.org> 1.0-0.1.CF.rc1
- update to 1.0.rc1
- update default-settings patch
- shuffle bits of release tag around for saner upgrade path
- note that parts (dovecot-auth, lib-sql and lib-ntlm) are now MIT licensed
- DH parameters generated in new %%{_localstatedir}/lib/dovecot directory

* Wed Jun 14 2006 Paul Howarth <paul@city-fan.org> 1.0-0.beta9.CF.1
- update to 1.0.beta9
- update default-settings patch
- don't apply pam-setcred patch as it should no longer be needed

* Fri May 12 2006 Paul Howarth <paul@city-fan.org> 1.0-0.beta8.1
- update to 1.0.beta8
- drop lib64 patch, should no longer be needed

* Wed May  3 2006 Paul Howarth <paul@city-fan.org> 1.0-0.beta7.1
- update to 1.0.beta7
- update default settings and lib64 patches to apply against beta7

* Fri Mar  3 2006 Paul Howarth <paul@city-fan.org> 1.0-0.beta3.2
- fix #182240 by looking in lib64 for libs first and then lib
  (more complete fix than rawhide beta2 patch; also, this package was not
  affected by the missing sample configuration files issue)

* Fri Feb 10 2006 Paul Howarth <paul@city-fan.org> 1.0-0.beta3.1
- update to 1.0.beta3
- move %%{_localstatedir}/run/dovecot/login back to
  %%{_localstatedir}/run/dovecot-login to avoid spurious boot-time error
  messages about not being able to clear %%{_localstatedir}/run/dovecot
- use complete Fedora patch set and then apply our own patches
- change the compiled-in defaults and adjust the default's configfile
  commented-out example settings to match compiled-in defaults,
  instead of changing the defaults only in the configfile, as per #179432
- fix #179574 by providing a default uidl_format for pop3
- half-fix #179620 by having plaintext auth enabled by default... this
  needs more thinking (which one we really want) and documentation
  either way
- don't fiddle with autotools input files, work around install issues
  manually; this removes the dependencies on autotools and allows the package
  to build on much older distributions
- change %%post as main dovecot binary no longer generates DH SSL parameters

* Wed Feb  1 2006 Paul Howarth <paul@city-fan.org> 1.0-0.beta2.3
- move /var/run/dovecot-login to %%{_localstatedir}/run/dovecot/login
- call dovecot --build-ssl-parameters in postinst (#179430)

* Tue Jan 31 2006 Paul Howarth <paul@city-fan.org> 1.0-0.beta2.2
- sort out gettext buildreq to enable builds on older distributions
  (still work to do to get autotools working though)
- update distribution-detection code to enable builds on CentOS
- update URL

* Mon Jan 23 2006 Paul Howarth <paul@city-fan.org> 1.0-0.beta2.1
- update to 1.0.beta2

* Tue Jan 17 2006 Paul Howarth <paul@city-fan.org> 1.0-0.beta1.1
- update to 1.0.beta1

* Tue Jan 10 2006 Paul Howarth <paul@city-fan.org> 1.0-0.alpha5.1
- update to 1.0.alpha5
- update dovecot.conf patch to apply against 1.0.alpha5
- include plugins

* Wed Dec 14 2005 Paul Howarth <paul@city-fan.org> 1.0-0.alpha4.1
- general spec file rewrite
- don't require specific openssl version
- determine ssldir at build time for compatibility with more distro versions
- use --with options for mysql and postgresql rather than regular macros
- initscript is not %%config
- %%{docdir}/examples/mkcert.sh is used in %%post and cannot therefore be %%doc

* Thu Nov 24 2005 Willem Riede <wriede@riede.org>
- merge from fc5t1 dovecot 0.99.14 srpm

* Sat Oct 22 2005 Willem Riede <wriede@riede.org>
- use newly released alpha4

* Thu Aug 18 2005 Willem Riede <wriede@riede.org>
- use newly released alpha1

* Sun Jul 24 2005 Willem Riede <wriede@riede.org>
- Merge FC4 .spec with ATRPM and use latest stable

* Fri Apr 22 2005 John Dennis <jdennis@redhat.com> 0.99.14-4.fc4
- openssl moved its certs, CA, etc. from /usr/share/ssl to /etc/pki

* Tue Apr 12 2005 Tom Lane <tgl@redhat.com> 0.99.14-3.fc4
- Rebuild for Postgres 8.0.2 (new libpq major version).

* Mon Mar  7 2005 John Dennis <jdennis@redhat.com> 0.99.14-2.fc4
- bump rev for gcc4 build

* Mon Feb 14 2005 John Dennis <jdennis@redhat.com> 0.99.14-1.fc4
- fix bug #147874, update to 0.99.14 release

* Wed Feb  2 2005 John Dennis <jdennis@redhat.com> 0.99.13-4.devel
- fix bug #146198, clean up temp kerberos tickets

* Mon Jan 17 2005 John Dennis <jdennis@redhat.com> 0.99.13-3.devel
- fix bug #145214, force mbox_locks to fcntl only
- fix bug #145241, remove prereq on postgres and mysql, allow rpm auto
  dependency generator to pick up client lib dependency if needed.

* Thu Jan 13 2005 John Dennis <jdennis@redhat.com> 0.99.13-2.devel
- make postgres & mysql conditional build
- remove execute bit on migration example scripts so rpm does not pull
  in additional dependences on perl and perl modules that are not present
  in dovecot proper.
- add REDHAT-FAQ.txt to doc directory

* Thu Jan  6 2005 John Dennis <jdennis@redhat.com> 0.99.13-1.devel
- bring up to date with latest upstream, 0.99.13, bug #143707
  also fix bug #14462, bad dovecot-uid macro name

* Thu Jan  6 2005 John Dennis <jdennis@redhat.com> 0.99.11-10.devel
- fix bug #133618, removed LITERAL+ capability from capability string

* Wed Jan  5 2005 John Dennis <jdennis@redhat.com> 0.99.11-9.devel
- fix bug #134325, stop dovecot during installation

* Wed Jan  5 2005 John Dennis <jdennis@redhat.com> 0.99.11-8.devel
- fix bug #129539, dovecot starts too early,
  set chkconfig to 65 35 to match cyrus-imapd
- also delete some old commented out code from SSL certificate creation

* Thu Dec 23 2004 John Dennis <jdennis@redhat.com> 0.99.11-7.devel
- add UW to Dovecot migration documentation and scripts, bug #139954
  fix SSL documentation and scripts, add missing documentation, bug #139276

* Fri Dec 17 2004 Axel Thimm <Axel.Thimm@ATrpms.net>
- Update to 1.0-test58.

* Tue Dec  7 2004 Axel Thimm <Axel.Thimm@ATrpms.net>
- Update to 1.0-test56.

* Mon Nov 15 2004 Warren Togami <wtogami@redhat.com> 0.99.11-2.FC4.1
- rebuild against MySQL4

* Thu Oct 21 2004 John Dennis <jdennis@redhat.com>
- fix bug #136623
  Change License field from GPL to LGPL to reflect actual license

* Thu Sep 30 2004 John Dennis <jdennis@redhat.com> 0.99.11-1.FC3.3
- fix bug #124786, listen to ipv6 as well as ipv4

* Wed Sep  8 2004 John Dennis <jdennis@redhat.com> 0.99.11-1.FC3.1
- bring up to latest upstream,

* Wed Aug  4 2004 John Dennis <jdennis@redhat.com>
- change release field separator from comma to dot, bump build number

* Mon Aug  2 2004 John Dennis <jdennis@redhat.com> 0.99.10.9-1.FC3.1
- bring up to date with latest upstream, fixes include:
- LDAP support compiles now with Solaris LDAP library
- IMAP BODY and BODYSTRUCTURE replies were wrong for MIME parts which
  didn't contain Content-Type header.
- MySQL and PostgreSQL auth didn't reconnect if connection was lost
  to SQL server
- Linking fixes for dovecot-auth with some systems
- Last fix for disconnecting client when downloading mail longer than
  30 seconds actually made it never disconnect client. Now it works
  properly: disconnect when client hasn't read _any_ data for 30
  seconds.
- MySQL compiling got broken in last release
- More PostgreSQL reconnection fixing

* Mon Jul 26 2004 John Dennis <jdennis@redhat.com> 0.99.10.7-1,FC3,1
- enable postgres and mySQL in build
- fix configure to look for mysql in alternate locations
- nuke configure script in tar file, recreate from configure.in using autoconf

- bring up to latest upstream, which included:
- Added outlook-pop3-no-nuls workaround to fix Outlook hang in mails with NULs.
- Config file lines can now contain quoted strings ("value ")
- If client didn't finish downloading a single mail in 30 seconds,
  Dovecot closed the connection. This was supposed to work so that
  if client hasn't read data at all in 30 seconds, it's disconnected.
- Maildir: LIST now doesn't skip symlinks


* Wed Jun 30 2004 John Dennis <jdennis@redhat.com>
- bump rev for build
- change rev for FC3 build

* Fri Jun 25 2004 John Dennis <jdennis@redhat.com> 0.99.10.6-1
- bring up to date with upstream,
  recent change log comments from Timo Sirainen were:
  SHA1 password support using OpenSSL crypto library
  mail_extra_groups setting
  maildir_stat_dirs setting
  Added NAMESPACE capability and command
  Autocreate missing maildirs (instead of crashing)
  Fixed occasional crash in maildir synchronization
  Fixed occasional assertion crash in ioloop.c
  Fixed FreeBSD compiling issue
  Fixed issues with 64bit Solaris binary

* Tue Jun 15 2004 Elliot Lee <sopwith@redhat.com>
- rebuilt

* Thu May 27 2004 David Woodhouse <dwmw2@redhat.com> 0.99.10.5-1
- Update to 0.99.10.5 to fix maildir segfaults (#123022)

* Fri May 07 2004 Warren Togami <wtogami@redhat.com> 0.99.10.4-4
- default auth config that is actually usable
- Timo Sirainen (author) suggested functionality fixes
  maildir, imap-fetch-body-section, customflags-fix

* Mon Feb 23 2004 Tim Waugh <twaugh@redhat.com>
- Use ':' instead of '.' as separator for chown.

* Tue Feb 17 2004 Jeremy Katz <katzj@redhat.com> 0.99.10.4-3
- restart properly if it dies (#115594)

* Fri Feb 13 2004 Elliot Lee <sopwith@redhat.com>
- rebuilt

* Mon Nov 24 2003 Jeremy Katz <katzj@redhat.com> 0.99.10.4-1
- update to 0.99.10.4

* Mon Oct  6 2003 Jeremy Katz <katzj@redhat.com> 0.99.10-7
- another patch from upstream to fix returning invalid data on partial
  BODY[part] fetches
- patch to avoid confusion of draft/deleted in indexes

* Tue Sep 23 2003 Jeremy Katz <katzj@redhat.com> 0.99.10-6
- add some patches from upstream (#104288)

* Thu Sep  4 2003 Jeremy Katz <katzj@redhat.com> 0.99.10-5
- fix startup with 2.6 with patch from upstream (#103801)

* Tue Sep  2 2003 Jeremy Katz <katzj@redhat.com> 0.99.10-4
- fix assert in search code (#103383)

* Tue Jul 22 2003 Nalin Dahyabhai <nalin@redhat.com> 0.99.10-3
- rebuild

* Thu Jul 17 2003 Bill Nottingham <notting@redhat.com> 0.99.10-2
- don't run by default

* Thu Jun 26 2003 Jeremy Katz <katzj@redhat.com> 0.99.10-1
- 0.99.10

* Mon Jun 23 2003 Jeremy Katz <katzj@redhat.com> 0.99.10-0.2
- 0.99.10-rc2 (includes ssl detection fix)
- a few tweaks from fedora
  - noreplace the config file
  - configure --with-ldap to get LDAP enabled

* Mon Jun 23 2003 Jeremy Katz <katzj@redhat.com> 0.99.10-0.1
- 0.99.10-rc1
- add fix for ssl detection
- add zlib-devel to BuildRequires
- change pam service name to dovecot
- include pam config

* Thu May  8 2003 Jeremy Katz <katzj@redhat.com> 0.99.9.1-1
- update to 0.99.9.1
- add patch from upstream to fix potential bug when fetching with
  CR+LF linefeeds
- tweak some things in the initscript and config file noticed by the
  fedora folks

* Sun Mar 16 2003 Jeremy Katz <katzj@redhat.com> 0.99.8.1-2
- fix ssl dir
- own /var/run/dovecot/login with the correct perms
- fix chmod/chown in post

* Fri Mar 14 2003 Jeremy Katz <katzj@redhat.com> 0.99.8.1-1
- update to 0.99.8.1

* Tue Mar 11 2003 Jeremy Katz <katzj@redhat.com> 0.99.8-2
- add a patch to fix quoting problem from CVS

* Mon Mar 10 2003 Jeremy Katz <katzj@redhat.com> 0.99.8-1
- 0.99.8
- add some buildrequires
- fixup to build with openssl 0.9.7
- now includes a pop3 daemon (off by default)
- clean up description and %%preun
- add dovecot user (uid/gid of 97)
- add some buildrequires
- move the ssl cert to %%{_datadir}/ssl/certs
- create a dummy ssl cert in %%post
- own /var/run/dovecot
- make the config file a source so we get default mbox locks of fcntl

* Sun Dec  1 2002 Seth Vidal <skvidal@phy.duke.edu>
- 0.99.4 and fix startup so it starts imap-master not vsftpd :)

* Tue Nov 26 2002 Seth Vidal <skvidal@phy.duke.edu>
- first build
